"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module AccuDraw
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AccuDrawDialog = void 0;
require("./AccuDrawDialog.scss");
const classnames = require("classnames");
const React = require("react");
const ui_core_1 = require("@bentley/ui-core");
const UiFramework_1 = require("../UiFramework");
const ModelessDialog_1 = require("../dialog/ModelessDialog");
const AccuDrawFieldContainer_1 = require("./AccuDrawFieldContainer");
const KeyboardShortcut_1 = require("../keyboardshortcut/KeyboardShortcut");
/** @alpha */
function AccuDrawDialog(props) {
    const title = React.useRef(UiFramework_1.UiFramework.translate("accuDraw.dialogTitle"));
    const [opened, setOpened] = React.useState(props.opened);
    const closeDialog = React.useCallback(() => {
        setOpened(false);
        props.onClose && props.onClose();
    }, [props]);
    const handleClose = React.useCallback(() => {
        closeDialog();
    }, [closeDialog]);
    const handleEscape = React.useCallback(() => {
        KeyboardShortcut_1.KeyboardShortcutManager.setFocusToHome();
    }, []);
    const classNames = classnames("uifw-accudraw-dialog", props.className);
    const orientation = (props.orientation !== undefined) ? props.orientation : ui_core_1.Orientation.Vertical;
    const dialogWidth = (orientation === ui_core_1.Orientation.Horizontal) ? 500 : 250;
    return (React.createElement(ModelessDialog_1.ModelessDialog, { className: classNames, style: props.style, title: title.current, opened: opened, dialogId: props.dialogId, width: dialogWidth, minHeight: 75, inset: false, movable: true, onClose: handleClose, onEscape: handleEscape },
        React.createElement(AccuDrawFieldContainer_1.AccuDrawFieldContainer, { orientation: orientation })));
}
exports.AccuDrawDialog = AccuDrawDialog;
//# sourceMappingURL=AccuDrawDialog.js.map