"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module AccuDraw
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AccuDrawFieldContainer = void 0;
require("./AccuDrawFieldContainer.scss");
const classnames = require("classnames");
const React = require("react");
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const AccuDrawInputField_1 = require("./AccuDrawInputField");
const imodeljs_frontend_1 = require("@bentley/imodeljs-frontend");
const KeyboardShortcut_1 = require("../keyboardshortcut/KeyboardShortcut");
const angle_svg_sprite_1 = require("./angle.svg?sprite");
const distance_svg_sprite_1 = require("./distance.svg?sprite");
const FrameworkAccuDraw_1 = require("./FrameworkAccuDraw");
const ui_components_1 = require("@bentley/ui-components");
let AccuDrawContainerIndex = 0;
function determineShowZ(vp) {
    const showZ = (vp !== undefined) ? /* istanbul ignore next */ vp.view.is3d() : false;
    return showZ;
}
const defaultXLabel = "X";
const defaultYLabel = "Y";
const defaultZLabel = "Z";
const defaultAngleIcon = ui_abstract_1.IconSpecUtilities.createSvgIconSpec(angle_svg_sprite_1.default);
const defaultDistanceIcon = ui_abstract_1.IconSpecUtilities.createSvgIconSpec(distance_svg_sprite_1.default);
/** @alpha */
function AccuDrawFieldContainer(props) {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    const { className, style, orientation, uiSettingsStorage, showZOverride } = props, otherProps = __rest(props, ["className", "style", "orientation", "uiSettingsStorage", "showZOverride"]);
    const [containerIndex] = React.useState(() => ++AccuDrawContainerIndex);
    const xInputRef = React.useRef(null);
    const yInputRef = React.useRef(null);
    const zInputRef = React.useRef(null);
    const angleInputRef = React.useRef(null);
    const distanceInputRef = React.useRef(null);
    const focusField = React.useRef(undefined);
    const [mode, setMode] = React.useState(ui_abstract_1.AccuDrawMode.Rectangular);
    const [xLock, setXLock] = React.useState(false);
    const [yLock, setYLock] = React.useState(false);
    const [zLock, setZLock] = React.useState(false);
    const [angleLock, setAngleLock] = React.useState(false);
    const [distanceLock, setDistanceLock] = React.useState(false);
    const [showZ, setShowZ] = React.useState(true);
    const [xLabel, setXLabel] = React.useState(defaultXLabel);
    const [yLabel, setYLabel] = React.useState(defaultYLabel);
    const [zLabel, setZLabel] = React.useState(defaultZLabel);
    const [angleLabel, setAngleLabel] = React.useState(undefined);
    const [distanceLabel, setDistanceLabel] = React.useState(undefined);
    const [xIcon, setXIcon] = React.useState(undefined);
    const [yIcon, setYIcon] = React.useState(undefined);
    const [zIcon, setZIcon] = React.useState(undefined);
    const [angleIcon, setAngleIcon] = React.useState(defaultAngleIcon);
    const [distanceIcon, setDistanceIcon] = React.useState(defaultDistanceIcon);
    const [xStyle, setXStyle] = React.useState(undefined);
    const [yStyle, setYStyle] = React.useState(undefined);
    const [zStyle, setZStyle] = React.useState(undefined);
    const [angleStyle, setAngleStyle] = React.useState(undefined);
    const [distanceStyle, setDistanceStyle] = React.useState(undefined);
    const getInputRef = (field) => {
        let inputRef;
        switch (field) {
            case ui_abstract_1.AccuDrawField.X:
                inputRef = xInputRef;
                break;
            case ui_abstract_1.AccuDrawField.Y:
                inputRef = yInputRef;
                break;
            case ui_abstract_1.AccuDrawField.Z:
                inputRef = zInputRef;
                break;
            case ui_abstract_1.AccuDrawField.Angle:
                inputRef = angleInputRef;
                break;
            case ui_abstract_1.AccuDrawField.Distance:
                inputRef = distanceInputRef;
                break;
        }
        return inputRef;
    };
    React.useEffect(() => {
        setXLock(imodeljs_frontend_1.IModelApp.accuDraw.getFieldLock(imodeljs_frontend_1.ItemField.X_Item));
        setYLock(imodeljs_frontend_1.IModelApp.accuDraw.getFieldLock(imodeljs_frontend_1.ItemField.Y_Item));
        setZLock(imodeljs_frontend_1.IModelApp.accuDraw.getFieldLock(imodeljs_frontend_1.ItemField.Z_Item));
        setAngleLock(imodeljs_frontend_1.IModelApp.accuDraw.getFieldLock(imodeljs_frontend_1.ItemField.ANGLE_Item));
        setDistanceLock(imodeljs_frontend_1.IModelApp.accuDraw.getFieldLock(imodeljs_frontend_1.ItemField.DIST_Item));
        const handleSetFieldLock = (args) => {
            switch (args.field) {
                case ui_abstract_1.AccuDrawField.X:
                    setXLock(args.lock);
                    break;
                case ui_abstract_1.AccuDrawField.Y:
                    setYLock(args.lock);
                    break;
                case ui_abstract_1.AccuDrawField.Z:
                    setZLock(args.lock);
                    break;
                case ui_abstract_1.AccuDrawField.Angle:
                    setAngleLock(args.lock);
                    break;
                case ui_abstract_1.AccuDrawField.Distance:
                    setDistanceLock(args.lock);
                    break;
            }
        };
        return ui_abstract_1.AccuDrawUiAdmin.onAccuDrawSetFieldLockEvent.addListener(handleSetFieldLock);
    }, []);
    const setFocusToField = React.useCallback((field) => {
        const inputRef = getInputRef(field);
        // istanbul ignore else
        if (inputRef.current && document.activeElement !== inputRef.current) {
            inputRef.current.focus();
            inputRef.current.select();
        }
    }, []);
    React.useEffect(() => {
        const handleSetFieldFocus = (args) => {
            focusField.current = args.field;
            setFocusToField(focusField.current);
        };
        return ui_abstract_1.AccuDrawUiAdmin.onAccuDrawSetFieldFocusEvent.addListener(handleSetFieldFocus);
    }, [setFocusToField]);
    React.useEffect(() => {
        const handleGrabInputFocus = () => {
            // istanbul ignore else
            if (focusField.current)
                setFocusToField(focusField.current);
        };
        return ui_abstract_1.AccuDrawUiAdmin.onAccuDrawGrabInputFocusEvent.addListener(handleGrabInputFocus);
    }, [setFocusToField]);
    React.useEffect(() => {
        const compassMode = imodeljs_frontend_1.IModelApp.accuDraw.compassMode;
        const accuDrawMode = compassMode === imodeljs_frontend_1.CompassMode.Rectangular ? ui_abstract_1.AccuDrawMode.Rectangular : ui_abstract_1.AccuDrawMode.Polar;
        setMode(accuDrawMode);
        const handleSetMode = (args) => {
            setMode(args.mode);
        };
        return ui_abstract_1.AccuDrawUiAdmin.onAccuDrawSetModeEvent.addListener(handleSetMode);
    }, []);
    const handleValueChanged = React.useCallback((field, stringValue) => {
        imodeljs_frontend_1.IModelApp.uiAdmin.accuDrawUi.setFieldValueFromUi(field, stringValue);
    }, []);
    const handleEscPressed = React.useCallback(() => {
        KeyboardShortcut_1.KeyboardShortcutManager.setFocusToHome();
    }, []);
    React.useEffect(() => {
        setShowZ(showZOverride || determineShowZ(imodeljs_frontend_1.IModelApp.viewManager.selectedView));
        // istanbul ignore next
        const handleSelectedViewportChanged = (args) => {
            setShowZ(determineShowZ(args.current));
        };
        return imodeljs_frontend_1.IModelApp.viewManager.onSelectedViewportChanged.addListener(handleSelectedViewportChanged);
    }, [showZOverride]);
    React.useEffect(() => {
        const createFieldStyle = (inStyle, backgroundColor, foregroundColor) => {
            let fieldStyle;
            let rgbaString = "";
            if (inStyle || backgroundColor || foregroundColor) {
                fieldStyle = inStyle ? inStyle : {};
                if (backgroundColor) {
                    rgbaString = typeof backgroundColor === "string" ? backgroundColor : ui_components_1.getCSSColorFromDef(backgroundColor);
                    fieldStyle = Object.assign(Object.assign({}, fieldStyle), { backgroundColor: rgbaString });
                }
                if (foregroundColor) {
                    rgbaString = typeof foregroundColor === "string" ? foregroundColor : ui_components_1.getCSSColorFromDef(foregroundColor);
                    fieldStyle = Object.assign(Object.assign({}, fieldStyle), { color: rgbaString });
                }
            }
            return fieldStyle;
        };
        const processAccuDrawUiSettings = (settings) => {
            setXStyle(settings ? createFieldStyle(settings.xStyle, settings.xBackgroundColor, settings.xForegroundColor) : undefined);
            setYStyle(settings ? createFieldStyle(settings.yStyle, settings.yBackgroundColor, settings.yForegroundColor) : undefined);
            setZStyle(settings ? createFieldStyle(settings.zStyle, settings.zBackgroundColor, settings.zForegroundColor) : undefined);
            setAngleStyle(settings ? createFieldStyle(settings.angleStyle, settings.angleBackgroundColor, settings.angleForegroundColor) : undefined);
            setDistanceStyle(settings ? createFieldStyle(settings.distanceStyle, settings.distanceBackgroundColor, settings.distanceForegroundColor) : undefined);
            setXLabel(settings && settings.xLabel !== undefined ? settings.xLabel : defaultXLabel);
            setYLabel(settings && settings.yLabel !== undefined ? settings.yLabel : defaultYLabel);
            setZLabel(settings && settings.zLabel !== undefined ? settings.zLabel : defaultZLabel);
            setAngleLabel(settings && settings.angleLabel !== undefined ? settings.angleLabel : undefined);
            setDistanceLabel(settings && settings.distanceLabel !== undefined ? settings.distanceLabel : undefined);
            setXIcon(settings && settings.xIcon !== undefined ? settings.xIcon : undefined);
            setYIcon(settings && settings.yIcon !== undefined ? settings.yIcon : undefined);
            setZIcon(settings && settings.zIcon !== undefined ? settings.zIcon : undefined);
            setAngleIcon(settings && settings.angleIcon !== undefined ? settings.angleIcon : defaultAngleIcon);
            setDistanceIcon(settings && settings.distanceIcon !== undefined ? settings.distanceIcon : defaultDistanceIcon);
        };
        if (FrameworkAccuDraw_1.FrameworkAccuDraw.uiSettings)
            processAccuDrawUiSettings(FrameworkAccuDraw_1.FrameworkAccuDraw.uiSettings);
        // istanbul ignore next
        const handleAccuDrawUiSettingsChanged = () => {
            processAccuDrawUiSettings(FrameworkAccuDraw_1.FrameworkAccuDraw.uiSettings);
        };
        return FrameworkAccuDraw_1.FrameworkAccuDraw.onAccuDrawUiSettingsChangedEvent.addListener(handleAccuDrawUiSettingsChanged);
    }, []);
    const classNames = classnames("uifw-accudraw-field-container", (orientation === ui_core_1.Orientation.Vertical) ? "uifw-accudraw-field-container-vertical" : "uifw-accudraw-field-container-horizontal", className);
    const delay = 250;
    const labelCentered = (xLabel !== undefined && xLabel.length === 1 && yLabel !== undefined && yLabel.length === 1 && zLabel !== undefined && zLabel.length === 1);
    return (React.createElement("div", Object.assign({ className: classNames, style: style }, otherProps),
        mode === ui_abstract_1.AccuDrawMode.Rectangular &&
            React.createElement(React.Fragment, null,
                React.createElement(AccuDrawInputField_1.AccuDrawInputField, { ref: xInputRef, isLocked: xLock, className: "uifw-accudraw-x-value", style: xStyle, field: ui_abstract_1.AccuDrawField.X, id: `uifw-accudraw-x-${containerIndex}`, "data-testid": "uifw-accudraw-x", label: xLabel, iconSpec: xIcon, labelCentered: labelCentered, valueChangedDelay: delay, onValueChanged: (stringValue) => handleValueChanged(ui_abstract_1.AccuDrawField.X, stringValue), onEscPressed: handleEscPressed }),
                React.createElement(AccuDrawInputField_1.AccuDrawInputField, { ref: yInputRef, isLocked: yLock, className: "uifw-accudraw-y-value", style: yStyle, field: ui_abstract_1.AccuDrawField.Y, id: `uifw-accudraw-y-${containerIndex}`, "data-testid": "uifw-accudraw-y", label: yLabel, iconSpec: yIcon, labelCentered: labelCentered, valueChangedDelay: delay, onValueChanged: (stringValue) => handleValueChanged(ui_abstract_1.AccuDrawField.Y, stringValue), onEscPressed: handleEscPressed }),
                showZ &&
                    React.createElement(AccuDrawInputField_1.AccuDrawInputField, { ref: zInputRef, isLocked: zLock, className: "uifw-accudraw-z-value", style: zStyle, field: ui_abstract_1.AccuDrawField.Z, id: `uifw-accudraw-z-${containerIndex}`, "data-testid": "uifw-accudraw-z", label: zLabel, iconSpec: zIcon, labelCentered: labelCentered, valueChangedDelay: delay, onValueChanged: (stringValue) => handleValueChanged(ui_abstract_1.AccuDrawField.Z, stringValue), onEscPressed: handleEscPressed })),
        mode === ui_abstract_1.AccuDrawMode.Polar &&
            React.createElement(React.Fragment, null,
                React.createElement(AccuDrawInputField_1.AccuDrawInputField, { ref: angleInputRef, isLocked: angleLock, className: "uifw-accudraw-angle-value", style: angleStyle, field: ui_abstract_1.AccuDrawField.Angle, id: `uifw-accudraw-angle-${containerIndex}`, "data-testid": "uifw-accudraw-angle", label: angleLabel, iconSpec: angleIcon, valueChangedDelay: delay, onValueChanged: (stringValue) => handleValueChanged(ui_abstract_1.AccuDrawField.Angle, stringValue), onEscPressed: handleEscPressed }),
                React.createElement(AccuDrawInputField_1.AccuDrawInputField, { ref: distanceInputRef, isLocked: distanceLock, className: "uifw-accudraw-distance-value", style: distanceStyle, field: ui_abstract_1.AccuDrawField.Distance, id: `uifw-accudraw-distance-${containerIndex}`, "data-testid": "uifw-accudraw-distance", label: distanceLabel, iconSpec: distanceIcon, valueChangedDelay: delay, onValueChanged: (stringValue) => handleValueChanged(ui_abstract_1.AccuDrawField.Distance, stringValue), onEscPressed: handleEscPressed }))));
}
exports.AccuDrawFieldContainer = AccuDrawFieldContainer;
//# sourceMappingURL=AccuDrawFieldContainer.js.map