/** @packageDocumentation
 * @module AccuDraw
 */
import "./AccuDrawInputField.scss";
import * as React from "react";
import { CommonProps, IconSpec } from "@bentley/ui-core";
import { AccuDrawField } from "@bentley/ui-abstract";
/** Properties for [[AccuDrawInputField]] component
 * @internal
 */
export interface AccuDrawInputFieldProps extends CommonProps {
    /** Which AccuDraw field this represents */
    field: AccuDrawField;
    /** id for the input element */
    id: string;
    /** Indicates whether field is locked */
    isLocked?: boolean;
    /** label for the input element */
    label?: string;
    /** icon for the input element */
    iconSpec?: IconSpec;
    /** Custom CSS class name for the label */
    labelClassName?: string;
    /** Custom CSS Style for the label */
    labelStyle?: React.CSSProperties;
    /** Center justified label */
    labelCentered?: boolean;
    /** Triggered when the content is changed */
    onValueChanged: (stringValue: string) => void;
    /** Frequency to poll for changes in value, in milliseconds */
    valueChangedDelay?: number;
    /** Listens for <Enter> keypress */
    onEnterPressed?: () => void;
    /** Listens for <Esc> keypress */
    onEscPressed?: () => void;
    /** Provides ability to return reference to HTMLInputElement */
    ref?: React.Ref<HTMLInputElement>;
}
/** Input field for AccuDraw
 * @internal
 */
export declare const AccuDrawInputField: (props: AccuDrawInputFieldProps) => JSX.Element | null;
//# sourceMappingURL=AccuDrawInputField.d.ts.map