"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module AccuDraw
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AccuDrawKeyboardShortcuts = void 0;
const AccuDrawCommandItems_1 = require("./AccuDrawCommandItems");
const FrameworkAccuDraw_1 = require("./FrameworkAccuDraw");
/** Default AccuDraw Keyboard Shortcuts
 * @alpha
 */
class AccuDrawKeyboardShortcuts {
    /** Get default AccuDraw Keyboard Shortcuts list.
     */
    static getDefaultShortcuts() {
        const keyboardShortcutList = [
            {
                key: "a",
                labelKey: "UiFramework:accuDraw.subMenu",
                shortcuts: [
                    {
                        key: "s",
                        item: AccuDrawCommandItems_1.AccuDrawCommandItems.lockSmart,
                    },
                    {
                        key: "r",
                        item: AccuDrawCommandItems_1.AccuDrawCommandItems.setOrigin,
                    },
                    {
                        key: "t",
                        item: AccuDrawCommandItems_1.AccuDrawCommandItems.changeCompassMode,
                    },
                    {
                        key: "x",
                        item: AccuDrawCommandItems_1.AccuDrawCommandItems.lockX,
                        isHidden: FrameworkAccuDraw_1.FrameworkAccuDraw.isPolarModeConditional,
                    },
                    {
                        key: "y",
                        item: AccuDrawCommandItems_1.AccuDrawCommandItems.lockY,
                        isHidden: FrameworkAccuDraw_1.FrameworkAccuDraw.isPolarModeConditional,
                    },
                    {
                        key: "z",
                        item: AccuDrawCommandItems_1.AccuDrawCommandItems.lockZ,
                        isHidden: FrameworkAccuDraw_1.FrameworkAccuDraw.isPolarModeConditional,
                    },
                    {
                        key: "a",
                        item: AccuDrawCommandItems_1.AccuDrawCommandItems.lockAngle,
                        isHidden: FrameworkAccuDraw_1.FrameworkAccuDraw.isRectangularModeConditional,
                    },
                    {
                        key: "d",
                        item: AccuDrawCommandItems_1.AccuDrawCommandItems.lockDistance,
                        isHidden: FrameworkAccuDraw_1.FrameworkAccuDraw.isRectangularModeConditional,
                    },
                    {
                        key: "b",
                        item: AccuDrawCommandItems_1.AccuDrawCommandItems.bumpToolSetting,
                    },
                ],
            },
            {
                key: "r",
                labelKey: "UiFramework:accuDraw.rotateSubMenu",
                shortcuts: [
                    {
                        key: "t",
                        item: AccuDrawCommandItems_1.AccuDrawCommandItems.rotateTop,
                        isDisabled: FrameworkAccuDraw_1.FrameworkAccuDraw.isTopRotationConditional,
                    },
                    {
                        key: "s",
                        item: AccuDrawCommandItems_1.AccuDrawCommandItems.rotateSide,
                        isDisabled: FrameworkAccuDraw_1.FrameworkAccuDraw.isSideRotationConditional,
                    },
                    {
                        key: "f",
                        item: AccuDrawCommandItems_1.AccuDrawCommandItems.rotateFront,
                        isDisabled: FrameworkAccuDraw_1.FrameworkAccuDraw.isFrontRotationConditional,
                    },
                    {
                        key: "v",
                        item: AccuDrawCommandItems_1.AccuDrawCommandItems.rotateView,
                        isDisabled: FrameworkAccuDraw_1.FrameworkAccuDraw.isViewRotationConditional,
                    },
                    {
                        key: "c",
                        item: AccuDrawCommandItems_1.AccuDrawCommandItems.rotateCycle,
                    },
                    {
                        key: "a",
                        item: AccuDrawCommandItems_1.AccuDrawCommandItems.rotateAxes,
                    },
                    {
                        key: "e",
                        item: AccuDrawCommandItems_1.AccuDrawCommandItems.rotateToElement,
                    },
                ],
            },
        ];
        return keyboardShortcutList;
    }
}
exports.AccuDrawKeyboardShortcuts = AccuDrawKeyboardShortcuts;
//# sourceMappingURL=AccuDrawKeyboardShortcuts.js.map