"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module AccuDraw
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AccuDrawPopupManager = void 0;
const React = require("react");
const imodeljs_frontend_1 = require("@bentley/imodeljs-frontend");
const ui_abstract_1 = require("@bentley/ui-abstract");
const PopupManager_1 = require("../popup/PopupManager");
const MenuItem_1 = require("../shared/MenuItem");
const angle_svg_sprite_1 = require("./angle.svg?sprite");
const CalculatorPopup_1 = require("./CalculatorPopup");
const distance_svg_sprite_1 = require("./distance.svg?sprite");
const height_2_svg_sprite_1 = require("./height-2.svg?sprite");
const MenuButtonPopup_1 = require("./MenuButtonPopup");
/** AccuDraw Popup Manager class
 * @alpha
 */
class AccuDrawPopupManager {
    static showMenuButton(id, el, pt, menuItemsProps) {
        const menuItems = MenuItem_1.MenuItemHelpers.createMenuItems(menuItemsProps);
        const menuContent = MenuItem_1.MenuItemHelpers.createMenuItemNodes(menuItems);
        const component = (React.createElement(MenuButtonPopup_1.MenuButtonPopup, { id: id, el: el, pt: pt, offset: PopupManager_1.PopupManager.defaultOffset, content: menuContent }));
        const popupInfo = {
            id, pt, component, parentDocument: el.ownerDocument,
        };
        PopupManager_1.PopupManager.addOrUpdatePopup(popupInfo);
        return true;
    }
    static hideMenuButton(id) {
        return PopupManager_1.PopupManager.removePopup(id);
    }
    static showCalculator(el, pt, initialValue, resultIcon, onOk, onCancel) {
        const id = AccuDrawPopupManager._calculatorId;
        const component = (React.createElement(CalculatorPopup_1.CalculatorPopup, { id: id, el: el, pt: pt, offset: PopupManager_1.PopupManager.defaultOffset, initialValue: initialValue, resultIcon: resultIcon, onOk: onOk, onCancel: onCancel }));
        const popupInfo = {
            id, pt, component, parentDocument: el.ownerDocument,
        };
        PopupManager_1.PopupManager.addOrUpdatePopup(popupInfo);
        return true;
    }
    static hideCalculator() {
        return PopupManager_1.PopupManager.removePopup(AccuDrawPopupManager._calculatorId);
    }
    static showAngleEditor(el, pt, value, onCommit, onCancel) {
        const propertyDescription = new imodeljs_frontend_1.AngleDescription(undefined, undefined, ui_abstract_1.IconSpecUtilities.createSvgIconSpec(angle_svg_sprite_1.default));
        return PopupManager_1.PopupManager.showInputEditor(el, pt, value, propertyDescription, onCommit, onCancel);
    }
    static showLengthEditor(el, pt, value, onCommit, onCancel) {
        const propertyDescription = new imodeljs_frontend_1.LengthDescription(undefined, undefined, ui_abstract_1.IconSpecUtilities.createSvgIconSpec(distance_svg_sprite_1.default));
        return PopupManager_1.PopupManager.showInputEditor(el, pt, value, propertyDescription, onCommit, onCancel);
    }
    static showHeightEditor(el, pt, value, onCommit, onCancel) {
        const propertyDescription = new imodeljs_frontend_1.LengthDescription(undefined, undefined, ui_abstract_1.IconSpecUtilities.createSvgIconSpec(height_2_svg_sprite_1.default));
        return PopupManager_1.PopupManager.showInputEditor(el, pt, value, propertyDescription, onCommit, onCancel);
    }
}
exports.AccuDrawPopupManager = AccuDrawPopupManager;
AccuDrawPopupManager._calculatorId = "Calculator";
//# sourceMappingURL=AccuDrawPopupManager.js.map