"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module AccuDraw
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AccuDrawWidget = exports.AccuDrawWidgetControl = void 0;
const React = require("react");
const ui_core_1 = require("@bentley/ui-core");
const AccuDrawFieldContainer_1 = require("./AccuDrawFieldContainer");
const WidgetControl_1 = require("../widgets/WidgetControl");
const UiFramework_1 = require("../UiFramework");
/** AccuDraw Widget Control
 * @alpha
 */
class AccuDrawWidgetControl extends WidgetControl_1.WidgetControl {
    constructor(info, options) {
        super(info, options);
        this.reactNode = React.createElement(AccuDrawWidget, null);
    }
    static get label() {
        return UiFramework_1.UiFramework.translate("accuDraw.dialogTitle");
    }
}
exports.AccuDrawWidgetControl = AccuDrawWidgetControl;
AccuDrawWidgetControl.id = "AccuDrawWidget";
/** AccuDraw Widget
 * @alpha
 */
function AccuDrawWidget() {
    const [orientation, setOrientation] = React.useState(ui_core_1.Orientation.Vertical);
    const breakpoint = 400;
    // istanbul ignore next - currently unable to replicate resizing in unit test
    const handleResize = React.useCallback((w, _h) => {
        setOrientation(w <= breakpoint ? ui_core_1.Orientation.Vertical : ui_core_1.Orientation.Horizontal);
    }, []);
    const ref = ui_core_1.useResizeObserver(handleResize);
    return (React.createElement("div", { ref: ref },
        React.createElement(AccuDrawFieldContainer_1.AccuDrawFieldContainer, { orientation: orientation })));
}
exports.AccuDrawWidget = AccuDrawWidget;
//# sourceMappingURL=AccuDrawWidget.js.map