/** @packageDocumentation
 * @module AccuDraw
 */
import { AccuDraw, BeButtonEvent, ItemField } from "@bentley/imodeljs-frontend";
import { AccuDrawField, ConditionalBooleanValue } from "@bentley/ui-abstract";
import { UserSettingsProvider } from "../UiFramework";
import { AccuDrawUiSettings } from "./AccuDrawUiSettings";
import { BeUiEvent } from "@bentley/bentleyjs-core";
import { UiSettings } from "@bentley/ui-core";
/** @internal */
export declare class AccuDrawUiSettingsChangedEvent extends BeUiEvent<{}> {
}
/** @internal */
export declare class FrameworkAccuDraw extends AccuDraw implements UserSettingsProvider {
    private static _displayNotifications;
    private static _uiSettings;
    private static _settingsNamespace;
    private static _notificationsKey;
    readonly providerId = "FrameworkAccuDraw";
    /** Determines if AccuDraw.rotationMode === RotationMode.Top */
    static readonly isTopRotationConditional: ConditionalBooleanValue;
    /** Determines if AccuDraw.rotationMode === RotationMode.Front */
    static readonly isFrontRotationConditional: ConditionalBooleanValue;
    /** Determines if AccuDraw.rotationMode === RotationMode.Side */
    static readonly isSideRotationConditional: ConditionalBooleanValue;
    /** Determines if AccuDraw.rotationMode === RotationMode.View */
    static readonly isViewRotationConditional: ConditionalBooleanValue;
    /** Determines if AccuDraw.rotationMode === RotationMode.ACS */
    static readonly isACSRotationConditional: ConditionalBooleanValue;
    /** Determines if AccuDraw.rotationMode === RotationMode.Context */
    static readonly isContextRotationConditional: ConditionalBooleanValue;
    /** Determines if AccuDraw.compassMode === CompassMode.Polar */
    static readonly isPolarModeConditional: ConditionalBooleanValue;
    /** Determines if AccuDraw.compassMode === CompassMode.Rectangular */
    static readonly isRectangularModeConditional: ConditionalBooleanValue;
    /** AccuDraw Grab Input Focus event. */
    static readonly onAccuDrawUiSettingsChangedEvent: AccuDrawUiSettingsChangedEvent;
    /** Determines if notifications should be displayed for AccuDraw changes */
    static get displayNotifications(): boolean;
    static set displayNotifications(v: boolean);
    loadUserSettings(storage: UiSettings): Promise<void>;
    /** AccuDraw User Interface settings */
    static get uiSettings(): AccuDrawUiSettings | undefined;
    static set uiSettings(v: AccuDrawUiSettings | undefined);
    constructor();
    private handleSetFieldValueFromUiEvent;
    /** @internal */
    static translateFromItemField(item: ItemField): AccuDrawField;
    /** @internal */
    static translateToItemField(field: AccuDrawField): ItemField;
    /** @internal */
    onCompassModeChange(): void;
    /** @internal */
    onRotationModeChange(): void;
    /** @internal */
    onFieldLockChange(index: ItemField): void;
    /** @internal */
    onFieldValueChange(index: ItemField): void;
    private fieldValuesChanged;
    /** @internal */
    setFocusItem(index: ItemField): void;
    /** Implemented by sub-classes to update ui fields to show current deltas or coordinates when inactive.
     * Should also choose active x or y input field in rectangular mode based on cursor position when
     * axis isn't locked to support "smart lock".
     * @internal
     */
    onMotion(_ev: BeButtonEvent): void;
    /** Determine if the AccuDraw UI has focus
     * @internal
     */
    get hasInputFocus(): boolean;
    /** Implement this method to set focus to the AccuDraw UI.
     * @internal
     */
    grabInputFocus(): void;
    static getFieldDisplayValue(index: ItemField): string;
    private outputInfoMessage;
    private outputCompassModeMessage;
    private outputRotationMessage;
}
//# sourceMappingURL=FrameworkAccuDraw.d.ts.map