"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module AccuDraw
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MenuButton = void 0;
require("./MenuButton.scss");
const React = require("react");
const ui_core_1 = require("@bentley/ui-core");
const SquareButton_1 = require("./SquareButton");
/** @alpha */
class MenuButton extends React.PureComponent {
    constructor(props) {
        super(props);
        this._menu = null;
        this._open = () => {
            this.setState({ expanded: true }, () => {
                // istanbul ignore else
                if (this._menu)
                    this._menu.focus();
            });
        };
        this._handleClick = (event) => {
            if (this.state.expanded) {
                event.stopPropagation();
                this.setState({ expanded: false });
            }
            else {
                this._open();
            }
        };
        // istanbul ignore next
        this._handleClose = () => {
            this.setState({ expanded: false });
        };
        this.state = {
            expanded: false,
        };
    }
    render() {
        const _a = this.props, { point, className, style, onSizeKnown } = _a, buttonProps = __rest(_a, ["point", "className", "style", "onSizeKnown"]); // eslint-disable-line @typescript-eslint/no-unused-vars
        const divStyle = {
            top: point.y,
            left: point.x,
        };
        return (React.createElement("div", { className: "uifw-menu-button", style: divStyle, ref: (e) => this.setDivRef(e) },
            React.createElement(SquareButton_1.SquareButton, Object.assign({}, buttonProps, { className: className, style: style, onClick: this._handleClick }),
                React.createElement(ui_core_1.Icon, { iconSpec: "icon-more-2" })),
            React.createElement(ui_core_1.ContextMenu, { ref: (el) => { this._menu = el; }, selectedIndex: 0, onSelect: this._handleClose, onOutsideClick: this._handleClose, onEsc: this._handleClose, opened: this.state.expanded, autoflip: false }, this.props.children)));
    }
    setDivRef(div) {
        // istanbul ignore else
        if (div) {
            const rect = div.getBoundingClientRect();
            const size = new ui_core_1.Size(rect.width, rect.height);
            // istanbul ignore else
            if (this.props.onSizeKnown)
                this.props.onSizeKnown(size);
        }
    }
}
exports.MenuButton = MenuButton;
//# sourceMappingURL=MenuButton.js.map