/** @packageDocumentation
 * @module Backstage
 */
import * as React from "react";
import { UserInfo } from "@bentley/itwin-client";
import { CommonProps, IconSpec, UiEvent } from "@bentley/ui-core";
/** [[BackstageEvent]] arguments.
 * @public @deprecated use BackstageComposer.
 */
export interface BackstageEventArgs {
    isVisible: boolean;
}
/** Backstage Event class.
 * @public
 */
export declare class BackstageEvent extends UiEvent<BackstageEventArgs> {
}
/** Properties for the [[Backstage]] React component.
 * @public @deprecated use BackstageComposer.
 */
export interface BackstageProps extends CommonProps {
    userInfo?: UserInfo;
    isVisible?: boolean;
    showOverlay?: boolean;
    onClose?: () => void;
    header?: React.ReactNode;
}
/** State for the [[Backstage]] React component.
 * @internal
 */
interface BackstageState {
    isVisible: boolean;
}
/** Backstage React component.
 * @public @deprecated use BackstageComposer.
 */
export declare class Backstage extends React.Component<BackstageProps, BackstageState> {
    static readonly onBackstageEvent: BackstageEvent;
    static isBackstageVisible: boolean;
    /** Shows the Backstage */
    static show(): void;
    /** Hides the Backstage */
    static hide(): void;
    /** Get CommandItemDef that will toggle display of Backstage and allow iconSpec to be overridden */
    static getBackstageToggleCommand(overrideIconSpec?: IconSpec): import("../shared/CommandItemDef").CommandItemDef;
    /** Command that toggles the Backstage */
    static get backstageToggleCommand(): import("../shared/CommandItemDef").CommandItemDef;
    /** @internal */
    readonly state: BackstageState;
    constructor(props: BackstageProps);
    componentDidMount(): void;
    componentWillUnmount(): void;
    private _handleBackstageEvent;
    componentDidUpdate(prevProps: BackstageProps): void;
    private setIsOpen;
    private _onClose;
    render(): React.ReactNode;
}
export {};
//# sourceMappingURL=Backstage.d.ts.map