"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Backstage
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Backstage = exports.BackstageEvent = void 0;
const React = require("react");
const ui_core_1 = require("@bentley/ui-core");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
const SafeAreaContext_1 = require("../safearea/SafeAreaContext");
const UiFramework_1 = require("../UiFramework");
const BackstageManager_1 = require("./BackstageManager");
const UserProfile_1 = require("./UserProfile");
/** Backstage Event class.
 * @public
 */
class BackstageEvent extends ui_core_1.UiEvent {
} // eslint-disable-line deprecation/deprecation
exports.BackstageEvent = BackstageEvent;
/** Backstage React component.
 * @public @deprecated use BackstageComposer.
 */
class Backstage extends React.Component {
    constructor(props) {
        super(props);
        this._handleBackstageEvent = (args) => {
            this.setState({ isVisible: args.isVisible });
        };
        this._onClose = () => {
            Backstage.hide(); // eslint-disable-line deprecation/deprecation
            /* istanbul ignore else */
            if (this.props.onClose)
                this.props.onClose();
        };
        this.setIsOpen(!!this.props.isVisible);
        this.state = {
            isVisible: UiFramework_1.UiFramework.backstageManager.isOpen,
        };
    }
    /** Shows the Backstage */
    static show() {
        UiFramework_1.UiFramework.backstageManager.open();
    }
    /** Hides the Backstage */
    static hide() {
        UiFramework_1.UiFramework.backstageManager.close();
    }
    /** Get CommandItemDef that will toggle display of Backstage and allow iconSpec to be overridden */
    static getBackstageToggleCommand(overrideIconSpec) {
        return BackstageManager_1.BackstageManager.getBackstageToggleCommand(overrideIconSpec);
    }
    /** Command that toggles the Backstage */
    static get backstageToggleCommand() {
        return this.getBackstageToggleCommand();
    }
    componentDidMount() {
        Backstage.onBackstageEvent.addListener(this._handleBackstageEvent); // eslint-disable-line deprecation/deprecation
    }
    componentWillUnmount() {
        Backstage.onBackstageEvent.removeListener(this._handleBackstageEvent); // eslint-disable-line deprecation/deprecation
    }
    componentDidUpdate(prevProps) {
        if (this.props.isVisible !== prevProps.isVisible)
            this.setIsOpen(!!this.props.isVisible);
    }
    setIsOpen(isOpen) {
        if (isOpen) {
            UiFramework_1.UiFramework.backstageManager.open();
        }
        else {
            UiFramework_1.UiFramework.backstageManager.close();
        }
    }
    render() {
        Backstage.isBackstageVisible = this.state.isVisible; // eslint-disable-line deprecation/deprecation
        let header = null;
        if (this.props.header)
            header = this.props.header;
        else if (this.props.userInfo !== undefined)
            header = React.createElement(UserProfile_1.UserProfileBackstageItem, { userInfo: this.props.userInfo });
        return (React.createElement(SafeAreaContext_1.SafeAreaContext.Consumer, null, (safeAreaInsets) => (React.createElement(ui_ninezone_1.Backstage, { className: this.props.className, header: header, isOpen: this.state.isVisible, onClose: this._onClose, safeAreaInsets: safeAreaInsets, showOverlay: this.props.showOverlay, style: this.props.style }, this.props.children))));
    }
}
exports.Backstage = Backstage;
Backstage.onBackstageEvent = new BackstageEvent();
//# sourceMappingURL=Backstage.js.map