"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Backstage
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.BackstageComposerItem = exports.BackstageComposerStageLauncher = exports.BackstageComposerActionItem = void 0;
const React = require("react");
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
const Frontstage_1 = require("../frontstage/Frontstage");
const FrontstageManager_1 = require("../frontstage/FrontstageManager");
const BackstageManager_1 = require("./BackstageManager");
/** @internal */
function BackstageComposerActionItem({ item }) {
    const manager = BackstageManager_1.useBackstageManager();
    const handleClick = React.useCallback(() => {
        manager.close();
        item.execute();
    }, [manager, item]);
    return (React.createElement(ui_ninezone_1.BackstageItem, { icon: React.createElement(ui_core_1.Icon, { iconSpec: ui_abstract_1.ConditionalStringValue.getValue(item.icon) }), isActive: ui_abstract_1.ConditionalBooleanValue.getValue(item.isActive), isDisabled: ui_abstract_1.ConditionalBooleanValue.getValue(item.isDisabled), onClick: handleClick, subtitle: ui_abstract_1.ConditionalStringValue.getValue(item.subtitle), badge: ui_core_1.BadgeUtilities.getComponentForBadgeType(item.badgeType) }, ui_abstract_1.ConditionalStringValue.getValue(item.label)));
}
exports.BackstageComposerActionItem = BackstageComposerActionItem;
/** @internal */
function BackstageComposerStageLauncher({ item }) {
    var _a;
    const manager = BackstageManager_1.useBackstageManager();
    const handleClick = React.useCallback(() => {
        manager.close();
        const frontstageDef = FrontstageManager_1.FrontstageManager.findFrontstageDef(item.stageId);
        if (!frontstageDef)
            return bentleyjs_core_1.Logger.logError("BackstageComposerStageLauncher", `Frontstage with id '${item.stageId}' not found`);
        FrontstageManager_1.FrontstageManager.setActiveFrontstageDef(frontstageDef); // eslint-disable-line @typescript-eslint/no-floating-promises
    }, [manager, item.stageId]);
    const activeFrontstageId = Frontstage_1.useActiveFrontstageId();
    const isActive = ui_abstract_1.ConditionalBooleanValue.getValue((_a = item.isActive) !== null && _a !== void 0 ? _a : item.stageId === activeFrontstageId);
    return (React.createElement(ui_ninezone_1.BackstageItem, { icon: React.createElement(ui_core_1.Icon, { iconSpec: ui_abstract_1.ConditionalStringValue.getValue(item.icon) }), isActive: isActive, isDisabled: ui_abstract_1.ConditionalBooleanValue.getValue(item.isDisabled), onClick: handleClick, subtitle: ui_abstract_1.ConditionalStringValue.getValue(item.subtitle), badge: ui_core_1.BadgeUtilities.getComponentForBadgeType(item.badgeType) }, ui_abstract_1.ConditionalStringValue.getValue(item.label)));
}
exports.BackstageComposerStageLauncher = BackstageComposerStageLauncher;
/** Item of [[BackstageComposer]].
 * @beta
 */
function BackstageComposerItem({ item }) {
    if (ui_abstract_1.isStageLauncher(item)) {
        return (React.createElement(BackstageComposerStageLauncher, { item: item }));
    }
    return (React.createElement(BackstageComposerActionItem, { item: item }));
}
exports.BackstageComposerItem = BackstageComposerItem;
//# sourceMappingURL=BackstageComposerItem.js.map