"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Backstage
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.BackstageItemUtilities = exports.BackstageItemType = void 0;
const PropsHelper_1 = require("../utils/PropsHelper");
/** Used to specify the item type added to the backstage menu.
 * Deprecated - Use [BackstageItemType]($ui-abstract) in bentley/ui-abstract instead.
 * @beta @deprecated Use BackstageItemType in bentley/ui-abstract instead
 */
var BackstageItemType;
(function (BackstageItemType) {
    /** Item that executes an action function */
    BackstageItemType[BackstageItemType["ActionItem"] = 1] = "ActionItem";
    /** Item that activate a stage. */
    BackstageItemType[BackstageItemType["StageLauncher"] = 2] = "StageLauncher";
})(BackstageItemType = exports.BackstageItemType || (exports.BackstageItemType = {}));
/** Utilities for creating and maintaining backstage items
 * @beta
 */
class BackstageItemUtilities {
}
exports.BackstageItemUtilities = BackstageItemUtilities;
/** Creates a stage launcher backstage item
 * @beta @deprecated Use BackstageItemUtilities.createStageLauncher in bentley/ui-abstract instead
 */
BackstageItemUtilities.createStageLauncher = (frontstageId, groupPriority, itemPriority, label, subtitle, iconSpec, overrides) => (Object.assign({ // eslint-disable-line deprecation/deprecation
    groupPriority, icon: iconSpec, id: frontstageId, itemPriority, type: BackstageItemType.StageLauncher, // eslint-disable-line deprecation/deprecation
    label, stageId: frontstageId, subtitle }, overrides));
/** Creates an action backstage item
 * @beta @deprecated Use BackstageItemUtilities.createActionItem in bentley/ui-abstract instead
 */
BackstageItemUtilities.createActionItem = (itemId, groupPriority, itemPriority, execute, label, subtitle, iconSpec, overrides) => (Object.assign({ // eslint-disable-line deprecation/deprecation
    execute,
    groupPriority, icon: iconSpec, id: itemId, itemPriority, type: BackstageItemType.ActionItem, // eslint-disable-line deprecation/deprecation
    label,
    subtitle }, overrides));
/** Helper method to set backstage item state from props */
BackstageItemUtilities.getBackstageItemStateFromProps = (props) => {
    const labelSpec = PropsHelper_1.PropsHelper.getStringSpec(props.label, props.labelKey);
    const subtitleSpec = PropsHelper_1.PropsHelper.getStringSpec(props.description, props.descriptionKey);
    const tooltipSpec = PropsHelper_1.PropsHelper.getStringSpec(props.tooltip, props.tooltipKey);
    return {
        isEnabled: undefined !== props.isEnabled ? props.isEnabled : /* istanbul ignore next */ false,
        label: PropsHelper_1.PropsHelper.getStringFromSpec(labelSpec),
        subtitle: PropsHelper_1.PropsHelper.getStringFromSpec(subtitleSpec),
        tooltip: PropsHelper_1.PropsHelper.getStringFromSpec(tooltipSpec),
        iconSpec: props.iconSpec,
        isActive: undefined !== props.isActive ? props.isActive : false,
    };
};
//# sourceMappingURL=BackstageItemUtilities.js.map