"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Backstage
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserProfileBackstageItem = void 0;
const React = require("react");
const ui_core_1 = require("@bentley/ui-core");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
const FrontstageManager_1 = require("../frontstage/FrontstageManager");
const SignOut_1 = require("../oidc/SignOut");
const SafeAreaContext_1 = require("../safearea/SafeAreaContext");
const UiFramework_1 = require("../UiFramework");
const Backstage_1 = require("./Backstage");
/** User Profile Backstage React component.
 * @public
 */
class UserProfileBackstageItem extends React.PureComponent {
    constructor() {
        super(...arguments);
        this._onOpenSignOut = () => {
            Backstage_1.Backstage.hide(); // eslint-disable-line deprecation/deprecation
            const manager = UiFramework_1.UiFramework.backstageManager;
            manager.close();
            FrontstageManager_1.FrontstageManager.openModalFrontstage(new SignOut_1.SignOutModalFrontstage(this.props.userInfo));
            // istanbul ignore else
            if (this.props.onOpenSignOut)
                this.props.onOpenSignOut();
        };
    }
    render() {
        let content = null;
        const userInfo = this.props.userInfo;
        // istanbul ignore else
        if (userInfo) {
            let emailId = "";
            if (userInfo.email && userInfo.email.id) {
                if (typeof userInfo.email.id === "string")
                    emailId = userInfo.email.id;
                else {
                    const ids = userInfo.email.id;
                    if (ids.length)
                        emailId = ids[0];
                }
            }
            const firstName = userInfo.profile ? userInfo.profile.firstName : "";
            const lastName = userInfo.profile ? userInfo.profile.lastName : "";
            content = (React.createElement(SafeAreaContext_1.SafeAreaContext.Consumer, null, (safeAreaInsets) => (React.createElement(ui_ninezone_1.UserProfile, { color: ui_core_1.getUserColor(emailId), initials: this._getInitials(firstName, lastName), onClick: this._onOpenSignOut, safeAreaInsets: safeAreaInsets }, this._getFullName(firstName, lastName)))));
        }
        return content;
    }
    _getInitials(firstName, lastName) {
        return `${firstName.charAt(0)}${lastName.charAt(0)}`;
    }
    _getFullName(firstName, lastName) {
        return `${firstName} ${lastName}`;
    }
}
exports.UserProfileBackstageItem = UserProfileBackstageItem;
//# sourceMappingURL=UserProfile.js.map