"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module StatusBar
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.useUiItemsProviderBackstageItems = void 0;
const React = require("react");
const ui_abstract_1 = require("@bentley/ui-abstract");
const useAvailableUiItemsProviders_1 = require("../hooks/useAvailableUiItemsProviders");
// cspell:ignore setxxx
/** Hook that returns items from [[BackstageItemsManager]].
 * @beta
 */
const useUiItemsProviderBackstageItems = (manager) => {
    const uiItemProviderIds = useAvailableUiItemsProviders_1.useAvailableUiItemsProviders();
    const [items, setItems] = React.useState(manager ? manager.items : /* istanbul ignore next */ []);
    const providersRef = React.useRef("");
    // gathers items from registered extensions - dependent on when a UiItemsProvider is register or unregistered and if the
    // current stage's composer allows entries from extensions.
    React.useEffect(() => {
        const uiProviders = uiItemProviderIds.join("-");
        // istanbul ignore else
        if (providersRef.current !== uiProviders) {
            providersRef.current = uiProviders;
            const backstageItems = ui_abstract_1.UiItemsManager.getBackstageItems();
            const updatedBackstageItems = ui_abstract_1.UiItemsArbiter.updateBackstageItems(backstageItems);
            manager.loadItems(updatedBackstageItems);
            setItems(manager.items);
        }
    }, [manager, uiItemProviderIds]);
    // handle item changes caused by calls to UiFramework.addonStatusBarItemsManager.setxxx
    React.useEffect(() => {
        const handleChanged = (args) => {
            setItems(args.items);
        };
        manager.onItemsChanged.addListener(handleChanged);
        return () => {
            manager.onItemsChanged.removeListener(handleChanged);
        };
    }, [manager]);
    return items;
};
exports.useUiItemsProviderBackstageItems = useUiItemsProviderBackstageItems;
//# sourceMappingURL=useUiItemsProviderBackstageItems.js.map