/** @packageDocumentation
 * @module ChildWindowManager
 */
import "./ChildWindowManager.scss";
import * as React from "react";
/** @beta */
export interface OpenChildWindowInfo {
    childWindowId: string;
    window: Window;
    parentWindow: Window;
}
/** @beta */
export interface ChildWindowLocationProps {
    width: number;
    height: number;
    left: number;
    top: number;
}
/** Supports opening a child browser window from the main application window. The child window is managed by the main application
 * and is running in the same security context. The application must deliver the html file iTwinPopup.html along side its index.html.
 * See also: [Child Window Manager]($docs/learning/ui/framework/ChildWindows.md)
 * @beta */
export declare class ChildWindowManager {
    private _openChildWindows;
    get openChildWindows(): OpenChildWindowInfo[];
    findChildWindow(childWindowId: string | undefined): OpenChildWindowInfo | undefined;
    findChildWindowId(contentWindow: Window | undefined | null): string | undefined;
    private renderChildWindowContents;
    /** Close all child/pop-out windows. This typically is called when the frontstage is changed. */
    closeAllChildWindows(): void;
    closeChildWindow: (childWindowId: string, processWindowClose?: boolean) => boolean;
    private adjustWidowLocation;
    openChildWindow(childWindowId: string, title: string, content: React.ReactNode, location: ChildWindowLocationProps, useDefaultPopoutUrl?: boolean): boolean;
}
//# sourceMappingURL=ChildWindowManager.d.ts.map