/** @packageDocumentation
 * @module ClientServices
 */
import { GuidString, OpenMode } from "@bentley/bentleyjs-core";
import { IModelConnection } from "@bentley/imodeljs-frontend";
import { ChangeSetInfo, IModelInfo, IModelServices, IModelUserInfo, VersionInfo } from "./IModelServices";
import { ProjectInfo } from "./ProjectServices";
/**
 * Provides default [[IModelServices]]
 * @internal
 */
export declare class DefaultIModelServices implements IModelServices {
    private _hubClient;
    /** Initialize the iModelHub Api */
    constructor();
    /** Get all iModels in a project */
    getIModels(projectInfo: ProjectInfo, top: number, skip: number): Promise<IModelInfo[]>;
    /** Open the specified version of the IModel */
    openIModel(contextId: string, iModelId: GuidString, openMode?: OpenMode, changeSetId?: string): Promise<IModelConnection>;
    /** Get the thumbnail for the iModel */
    getThumbnail(contextId: string, iModelId: GuidString): Promise<string | undefined>;
    /** Get versions (top 5 for testing) for the iModel */
    getVersions(iModelId: GuidString): Promise<VersionInfo[]>;
    /** Get changesets (top 5 for testing) for the iModel */
    getChangeSets(iModelId: GuidString): Promise<ChangeSetInfo[]>;
    /** Get users that have access to a particular iModel */
    getUsers(iModelId: GuidString): Promise<IModelUserInfo[]>;
    getUser(iModelId: GuidString, userId: string): Promise<IModelUserInfo[]>;
    private createIModelInfo;
    private createVersionInfo;
    private createChangeSetInfo;
    private createUserInfo;
}
//# sourceMappingURL=DefaultIModelServices.d.ts.map