"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module ClientServices
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefaultProjectServices = void 0;
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
const context_registry_client_1 = require("@bentley/context-registry-client");
const imodeljs_frontend_1 = require("@bentley/imodeljs-frontend");
const UiFramework_1 = require("../UiFramework");
const ProjectServices_1 = require("./ProjectServices");
// istanbul ignore next
class ProjectInfoImpl {
    constructor(name, projectNumber, wsgId) {
        this.name = name;
        this.projectNumber = projectNumber;
        this.wsgId = wsgId;
        this.readStatus = ProjectServices_1.ProjectReadStatus.NotRead;
    }
}
/**
 * Provides default [[ProjectServices]]
 * @internal
 */
// istanbul ignore next
class DefaultProjectServices {
    constructor() {
        this._connectClient = new context_registry_client_1.ContextRegistryClient();
    }
    createProjectInfo(thisProject) {
        bentleyjs_core_1.Logger.logTrace(UiFramework_1.UiFramework.loggerCategory(this), `Working on project '${thisProject.name}'`);
        const thisProjectInfo = new ProjectInfoImpl(thisProject.name ? thisProject.name : "", thisProject.number ? thisProject.number : "", thisProject.wsgId);
        return thisProjectInfo;
    }
    /** Get projects accessible to the user based on various scopes/criteria */
    async getProjects(projectScope, top, skip, filter) {
        const requestContext = await imodeljs_frontend_1.AuthorizedFrontendRequestContext.create();
        const queryOptions = {
            $select: "*",
            $top: top,
            $skip: skip,
            $filter: filter,
        };
        let projectList;
        try {
            if (projectScope === ProjectServices_1.ProjectScope.Invited) {
                projectList = await this._connectClient.getInvitedProjects(requestContext, queryOptions);
            }
            else {
                if (projectScope === ProjectServices_1.ProjectScope.Favorites) {
                    queryOptions.isFavorite = true;
                }
                else if (projectScope === ProjectServices_1.ProjectScope.MostRecentlyUsed) {
                    queryOptions.isMRU = true;
                }
                projectList = await this._connectClient.getProjects(requestContext, queryOptions);
            }
        }
        catch (e) {
            alert(JSON.stringify(e));
            throw e;
        }
        const projects = [];
        for (const thisProject of projectList) {
            projects.push(this.createProjectInfo(thisProject));
        }
        return projects;
    }
}
exports.DefaultProjectServices = DefaultProjectServices;
//# sourceMappingURL=DefaultProjectServices.js.map