/** @packageDocumentation
 * @module ClientServices
 */
/** The possible status values for reading ProjectInfo from CONNECT.
 * @internal
 */
export declare enum ProjectReadStatus {
    NotRead = 0,
    Reading = 1,
    DoneReading = 2
}
/** The possible values for Project scope in the iTwin services environment.
 * @internal
 */
export declare enum ProjectScope {
    Favorites = 0,
    MostRecentlyUsed = 1,
    Invited = 2,
    All = 3
}
/** Information required to display an iTwin Project to the user.
 * @internal
 */
export interface ProjectInfo {
    name: string;
    projectNumber: string;
    wsgId: string;
    readStatus: ProjectReadStatus;
}
/** Interface for Project services
 * @internal
 */
export interface ProjectServices {
    /**
     * Retrieve the Projects for the specified ProjectScope to which the logged in user has access.
     * The top and skip arguments are used for paging when there are large numbers of projects.
     */
    getProjects(projectScope: ProjectScope, top: number, skip: number, filter?: string): Promise<ProjectInfo[]>;
}
//# sourceMappingURL=ProjectServices.d.ts.map