/** @packageDocumentation
 * @module State
 */
import { ActionsUnion } from "../redux/redux-ts";
/** Action Ids used by Redux and to send sync UI components. Typically used to refresh visibility or enable state of control.
 *  Since these are also used as sync ids they should be in lowercase.
 * @public
 */
export declare enum ConfigurableUiActionId {
    SetSnapMode = "configurableui:set_snapmode",
    SetTheme = "configurableui:set_theme",
    SetToolPrompt = "configurableui:set_toolprompt",
    SetWidgetOpacity = "configurableui:set_widget_opacity",
    SetDragInteraction = "configurableui:set-drag-interaction",
    SetFrameworkVersion = "configurableui:set-framework-version"
}
/** The portion of state managed by the ConfigurableUiReducer.
 * @public
 */
export interface ConfigurableUiState {
    snapMode: number;
    toolPrompt: string;
    theme: string;
    widgetOpacity: number;
    useDragInteraction: boolean;
    frameworkVersion: string;
}
/** An object with a function that creates each ConfigurableUiReducer that can be handled by our reducer.
 * @public
 */
export declare const ConfigurableUiActions: {
    setSnapMode: (snapMode: number) => import("../redux/redux-ts").ActionWithPayload<ConfigurableUiActionId.SetSnapMode, number>;
    setTheme: (theme: string) => import("../redux/redux-ts").ActionWithPayload<ConfigurableUiActionId.SetTheme, string>;
    setToolPrompt: (toolPrompt: string) => import("../redux/redux-ts").ActionWithPayload<ConfigurableUiActionId.SetToolPrompt, string>;
    setWidgetOpacity: (opacity: number) => import("../redux/redux-ts").ActionWithPayload<ConfigurableUiActionId.SetWidgetOpacity, number>;
    setDragInteraction: (dragInteraction: boolean) => import("../redux/redux-ts").ActionWithPayload<ConfigurableUiActionId.SetDragInteraction, boolean>;
    setFrameworkVersion: (frameworkVersion: string) => import("../redux/redux-ts").ActionWithPayload<ConfigurableUiActionId.SetFrameworkVersion, string>;
};
/** Union of ConfigurableUi Redux actions
 * @public
 */
export declare type ConfigurableUiActionsUnion = ActionsUnion<typeof ConfigurableUiActions>;
/** Handles actions to update ConfigurableUiState.
 * @public
 */
export declare function ConfigurableUiReducer(state: ConfigurableUiState | undefined, action: ConfigurableUiActionsUnion): ConfigurableUiState;
//# sourceMappingURL=state.d.ts.map