"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module State
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConfigurableUiReducer = exports.ConfigurableUiActions = exports.ConfigurableUiActionId = void 0;
const imodeljs_frontend_1 = require("@bentley/imodeljs-frontend");
const redux_ts_1 = require("../redux/redux-ts");
const ThemeManager_1 = require("../theme/ThemeManager");
// cSpell:ignore configurableui snapmode toolprompt
/** Action Ids used by Redux and to send sync UI components. Typically used to refresh visibility or enable state of control.
 *  Since these are also used as sync ids they should be in lowercase.
 * @public
 */
var ConfigurableUiActionId;
(function (ConfigurableUiActionId) {
    ConfigurableUiActionId["SetSnapMode"] = "configurableui:set_snapmode";
    ConfigurableUiActionId["SetTheme"] = "configurableui:set_theme";
    ConfigurableUiActionId["SetToolPrompt"] = "configurableui:set_toolprompt";
    ConfigurableUiActionId["SetWidgetOpacity"] = "configurableui:set_widget_opacity";
    ConfigurableUiActionId["SetDragInteraction"] = "configurableui:set-drag-interaction";
    ConfigurableUiActionId["SetFrameworkVersion"] = "configurableui:set-framework-version";
})(ConfigurableUiActionId = exports.ConfigurableUiActionId || (exports.ConfigurableUiActionId = {}));
/** used on first call of ConfigurableUiReducer */
const initialState = {
    snapMode: imodeljs_frontend_1.SnapMode.NearestKeypoint,
    toolPrompt: "",
    theme: ThemeManager_1.SYSTEM_PREFERRED_COLOR_THEME,
    widgetOpacity: ThemeManager_1.WIDGET_OPACITY_DEFAULT,
    useDragInteraction: false,
    frameworkVersion: "1",
};
/** An object with a function that creates each ConfigurableUiReducer that can be handled by our reducer.
 * @public
 */
exports.ConfigurableUiActions = {
    setSnapMode: (snapMode) => redux_ts_1.createAction(ConfigurableUiActionId.SetSnapMode, snapMode),
    setTheme: 
    // istanbul ignore next
    (theme) => redux_ts_1.createAction(ConfigurableUiActionId.SetTheme, theme),
    setToolPrompt: 
    // istanbul ignore next
    (toolPrompt) => redux_ts_1.createAction(ConfigurableUiActionId.SetToolPrompt, toolPrompt),
    setWidgetOpacity: 
    // istanbul ignore next
    (opacity) => redux_ts_1.createAction(ConfigurableUiActionId.SetWidgetOpacity, opacity),
    setDragInteraction: (dragInteraction) => redux_ts_1.createAction(ConfigurableUiActionId.SetDragInteraction, dragInteraction),
    setFrameworkVersion: (frameworkVersion) => redux_ts_1.createAction(ConfigurableUiActionId.SetFrameworkVersion, frameworkVersion),
};
/** Handles actions to update ConfigurableUiState.
 * @public
 */
function ConfigurableUiReducer(state = initialState, action) {
    const outState = state;
    switch (action.type) {
        case ConfigurableUiActionId.SetSnapMode: {
            return Object.assign(Object.assign({}, state), { snapMode: action.payload });
        }
        case ConfigurableUiActionId.SetToolPrompt: {
            return Object.assign(Object.assign({}, state), { toolPrompt: action.payload });
        }
        case ConfigurableUiActionId.SetTheme: {
            return Object.assign(Object.assign({}, state), { theme: action.payload });
        }
        case ConfigurableUiActionId.SetWidgetOpacity: {
            return Object.assign(Object.assign({}, state), { widgetOpacity: action.payload });
        }
        case ConfigurableUiActionId.SetDragInteraction: {
            return Object.assign(Object.assign({}, state), { useDragInteraction: action.payload });
        }
        case ConfigurableUiActionId.SetFrameworkVersion: {
            return Object.assign(Object.assign({}, state), { frameworkVersion: action.payload });
        }
    }
    return outState;
}
exports.ConfigurableUiReducer = ConfigurableUiReducer;
//# sourceMappingURL=state.js.map