/** @packageDocumentation
 * @module ContentView
 */
import { ContentGroup } from "./ContentGroup";
import { ContentLayoutDef } from "./ContentLayout";
import { ContentLayoutProps } from "./ContentLayoutProps";
/** ContentLayout Manager class.
 * @public
 */
export declare class ContentLayoutManager {
    private static _layoutDefs;
    /** Loads one or more Content Layouts.
     * @param layoutPropsList  the list of Content Layout properties to load
     */
    static loadLayouts(layoutPropsList: ContentLayoutProps[]): void;
    /** Loads a Content Layout.
     * @param layoutProps  the properties of the Content Layout to load
     */
    static loadLayout(layoutProps: ContentLayoutProps): void;
    /** Finds a Content Layout with a given id.
     * @param layoutId  the id of the Content Layout to find
     * @returns the [[ContentLayoutDef]] if found, or undefined otherwise
     */
    static findLayout(layoutId: string): ContentLayoutDef | undefined;
    /** Adds a Content Layout.
     * @param layoutId  the id of the Content Layout to add
     * @param layoutDef  the Content Layout definition to add
     */
    static addLayout(layoutId: string, layoutDef: ContentLayoutDef): void;
    /** Gets the active Content Layout */
    static get activeLayout(): ContentLayoutDef | undefined;
    /** Gets the active Content Group */
    static get activeContentGroup(): ContentGroup | undefined;
    /** Sets the active Content Layout, Content Group and Content Control.
     * @param contentLayoutDef  Content layout to make active
     * @param contentGroup  Content Group to make active
     */
    static setActiveLayout(contentLayoutDef: ContentLayoutDef, contentGroup: ContentGroup): Promise<void>;
    /** Refreshes the active layout and content group.
     */
    static refreshActiveLayout(): void;
}
//# sourceMappingURL=ContentLayoutManager.d.ts.map