/** @packageDocumentation
 * @module ContentView
 */
import * as React from "react";
import { UiEvent } from "@bentley/ui-core";
import { ContentControl } from "./ContentControl";
/** [[MouseDownChangedEvent]] Args interface.
 * @public
 */
export interface MouseDownChangedEventArgs {
    /** Indicates whether the mouse is down */
    mouseDown: boolean;
}
/** Mouse Down Changed Event class.
 * @public
 */
export declare class MouseDownChangedEvent extends UiEvent<MouseDownChangedEventArgs> {
}
/** [[ActiveContentChangedEvent]] Args interface.
 * @public
 */
export interface ActiveContentChangedEventArgs {
    /** React node of the old content */
    oldContent?: React.ReactNode;
    /** React node of the newly active content */
    activeContent?: React.ReactNode;
}
/** Active Content Changed Event class.
 * @public
 */
export declare class ActiveContentChangedEvent extends UiEvent<ActiveContentChangedEventArgs> {
}
/** Content View Manager class.
 * @public
 */
export declare class ContentViewManager {
    private static _mouseDown;
    private static _activeContent?;
    /** Gets the [[MouseDownChangedEvent]] */
    static readonly onMouseDownChangedEvent: MouseDownChangedEvent;
    /** Determines if the mouse is down in a content view */
    static get isMouseDown(): boolean;
    /** Sets the mouse down status for a content view */
    static setMouseDown(mouseDown: boolean): void;
    /** Gets the [[ActiveContentChangedEvent]] */
    static readonly onActiveContentChangedEvent: ActiveContentChangedEvent;
    /** Gets the active content as a React.ReactNode. */
    static getActiveContent(): React.ReactNode | undefined;
    /** Return the active ContentControl. */
    static getActiveContentControl(): ContentControl | undefined;
    /** Sets the active [[ContentControl]] */
    static setActiveContent(activeContent?: React.ReactNode, forceEventProcessing?: boolean): void;
    /** Refreshes the active [[ContentControl]] */
    static refreshActiveContent(activeContent: React.ReactNode): void;
    /**
     * Determines if content displays a Sheet view.
     * @param content ContentControl to check
     */
    static isContentSheetView(content: ContentControl | undefined): boolean;
    /**
     * Determines if content displays a Drawing view.
     * @param content ContentControl to check
     */
    static isContentDrawingView(content: ContentControl | undefined): boolean;
    /**
     * Determines if content displays a Spatial view.
     * @param content ContentControl to check
     */
    static isContentSpatialView(content: ContentControl | undefined): boolean;
    /**
     * Determines if content displays a Orthographic view.
     * @param content ContentControl to check
     */
    static isContentOrthographicView(content: ContentControl | undefined): boolean;
    /**
     * Determines if content displays a 3d view.
     * @param content ContentControl to check
     */
    static isContent3dView(content: ContentControl | undefined): boolean;
    /**
     * Determines if viewport supports use of a camera.
     * @param content ContentControl to check
     */
    static contentSupportsCamera(content: ContentControl | undefined): boolean;
}
//# sourceMappingURL=ContentViewManager.d.ts.map