"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module ContentView
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefaultViewOverlay = void 0;
require("./DefaultViewOverlay.scss");
const React = require("react");
const ui_components_1 = require("@bentley/ui-components");
const useScheduleAnimationDataProvider_1 = require("../hooks/useScheduleAnimationDataProvider");
const useActiveViewport_1 = require("../hooks/useActiveViewport");
const useSolarDataProvider_1 = require("../hooks/useSolarDataProvider");
const useAnalysisAnimationDataProvider_1 = require("../hooks/useAnalysisAnimationDataProvider");
/**
 * Default viewport overlay that examines ViewState of the active view for a schedule script, analysis data, or solar data. If one of these is detected, the corresponding
 * data provider is attached to the TimelineComponent and the overlay is made visible.
 * @public
 */
// istanbul ignore next
function DefaultViewOverlay({ viewport, onPlayPause }) {
    const solarDataTimelineProvider = useSolarDataProvider_1.useSolarDataProvider(viewport);
    const analysisAnimationTimelineDataProvider = useAnalysisAnimationDataProvider_1.useAnalysisAnimationDataProvider(viewport);
    const scheduleTimelineDataProvider = useScheduleAnimationDataProvider_1.useScheduleAnimationDataProvider(viewport);
    const currentViewport = useActiveViewport_1.useActiveViewport();
    const timelineDataProvider = scheduleTimelineDataProvider ? scheduleTimelineDataProvider : analysisAnimationTimelineDataProvider;
    const isCurrentViewport = currentViewport === viewport;
    return (React.createElement("div", { className: "uifw-view-overlay" },
        isCurrentViewport && !timelineDataProvider && solarDataTimelineProvider &&
            React.createElement("div", { className: "uifw-animation-overlay" },
                React.createElement(ui_components_1.SolarTimeline, { dataProvider: solarDataTimelineProvider })),
        isCurrentViewport && timelineDataProvider &&
            React.createElement("div", { className: "uifw-animation-overlay" },
                React.createElement(ui_components_1.TimelineComponent, { startDate: timelineDataProvider.start, endDate: timelineDataProvider.end, initialDuration: timelineDataProvider.initialDuration, totalDuration: timelineDataProvider.duration, minimized: true, onChange: timelineDataProvider.onAnimationFractionChanged, onPlayPause: onPlayPause }))));
}
exports.DefaultViewOverlay = DefaultViewOverlay;
//# sourceMappingURL=DefaultViewOverlay.js.map