/** @packageDocumentation
 * @module ContentView
 */
import * as React from "react";
import { Id64String } from "@bentley/bentleyjs-core";
import { IModelConnection, ScreenViewport, ViewState } from "@bentley/imodeljs-frontend";
import { ViewStateProp } from "@bentley/ui-components";
import { ConfigurableCreateInfo } from "../configurableui/ConfigurableUiControl";
import { ViewportContentControl } from "./ViewportContentControl";
/** Viewport that is connected to the IModelConnection property in the Redux store. The application must set up the Redux store and include the FrameworkReducer.
 * @beta
 */
export declare const IModelConnectedViewport: import("react-redux").ConnectedComponent<React.ComponentType<import("@bentley/ui-components").ViewportProps & import("@bentley/presentation-components").ViewWithUnifiedSelectionProps>, any>;
/** [[IModelViewportControl]] options. These options are set in the applicationData property of the [[ContentProps]].
 * @beta
 */
export interface IModelViewportControlOptions {
    /** ViewState or a function to return a ViewState */
    viewState?: ViewStateProp;
    /** IModelConnection of data in Viewport */
    iModelConnection?: IModelConnection | (() => IModelConnection);
    /** Optional property to disable the use of the DefaultViewOverlay */
    disableDefaultViewOverlay?: boolean;
    /** Optional background color which may be used if viewState and iModelConnection are undefined */
    bgColor?: string;
    /** Optional property to always use the supplied `viewState` property instead of using viewport.view when set */
    alwaysUseSuppliedViewState?: boolean;
    /** Optional property to supply custom view overlay. Uses when caller want to supply custom overlay component. */
    supplyViewOverlay?: (_viewport: ScreenViewport) => React.ReactNode;
    /** Optional property to defer reactNode initialization until first reactNode property in needed. Useful when subclassing the `IModelViewportControl`. */
    deferNodeInitialization?: boolean;
}
/** iModel Viewport Control
 * @beta
 */
export declare class IModelViewportControl extends ViewportContentControl {
    protected _options: IModelViewportControlOptions;
    static get id(): string;
    protected _disableDefaultViewOverlay: boolean;
    protected _viewState: ViewStateProp | undefined;
    protected _iModelConnection: IModelConnection | undefined;
    protected _alwaysUseSuppliedViewState: boolean;
    private _userSuppliedViewOverlay?;
    constructor(info: ConfigurableCreateInfo, _options: IModelViewportControlOptions);
    protected initializeReactNode(): void;
    protected getReactNode(): React.ReactNode;
    /**
     * This is passed as a function to the ViewportComponent as the `viewState` prop in getImodelViewportReactElement().
     * It is called by ViewportComponent on a mount to resolve the viewState.
     */
    private _determineViewState;
    /** Get the React component that will contain the Viewport */
    protected getImodelConnectedViewportReactElement(): React.ReactNode;
    /** Get the React component that will contain the Viewport */
    protected getImodelViewportReactElement(iModelConnection: IModelConnection, viewState: ViewStateProp): React.ReactNode;
    /** Get the React component that will be shown when no iModel data is available */
    protected getNoContentReactElement(_options: IModelViewportControlOptions): React.ReactNode;
    /** Get the React.Element for a ViewSelector change. */
    getReactElementForViewSelectorChange(iModelConnection: IModelConnection, _unusedViewDefinitionId: Id64String, viewState: ViewState, _name: string): React.ReactNode;
    /** Get the default ViewOverlay unless parameter is set to not use it. May be override in an application specific sub-class  */
    protected _getViewOverlay: (viewport: ScreenViewport) => React.ReactNode;
    /** Get the NavigationAidControl associated with this ContentControl */
    get navigationAidControl(): string;
}
//# sourceMappingURL=IModelViewport.d.ts.map