"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module ContentView
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.SavedView = void 0;
const imodeljs_frontend_1 = require("@bentley/imodeljs-frontend");
const ViewUtilities_1 = require("../utils/ViewUtilities");
/** SavedView class. Used to serialize/deserialize a ViewState.
 * @public
 */
class SavedView {
    /** Create a ViewState from the SavedView */
    static async viewStateFromProps(iModelConnection, savedViewProps) {
        const props = {
            viewDefinitionProps: savedViewProps.viewDefinitionProps,
            categorySelectorProps: savedViewProps.categorySelectorProps,
            modelSelectorProps: savedViewProps.modelSelectorProps,
            displayStyleProps: savedViewProps.displayStyleProps,
            sheetProps: savedViewProps.sheetProps,
            sheetAttachments: savedViewProps.sheetAttachments,
        };
        let viewState;
        if (ViewUtilities_1.ViewUtilities.isSpatial(savedViewProps.bisBaseClass))
            viewState = imodeljs_frontend_1.SpatialViewState.createFromProps(props, iModelConnection);
        else if (ViewUtilities_1.ViewUtilities.isDrawing(savedViewProps.bisBaseClass))
            viewState = imodeljs_frontend_1.DrawingViewState.createFromProps(props, iModelConnection);
        else {
            // istanbul ignore else
            if (ViewUtilities_1.ViewUtilities.isSheet(savedViewProps.bisBaseClass))
                viewState = imodeljs_frontend_1.SheetViewState.createFromProps(props, iModelConnection);
        }
        // istanbul ignore else
        if (viewState)
            await viewState.load();
        return viewState;
    }
    /** Apply EmphasizeElements from the SavedView */
    static emphasizeElementsFromProps(vp, savedViewProps) {
        let changed = false;
        if (savedViewProps.emphasizeElementsProps) {
            const emphasizeElements = new imodeljs_frontend_1.EmphasizeElements();
            changed = emphasizeElements.fromJSON(savedViewProps.emphasizeElementsProps, vp);
        }
        return changed;
    }
    /** Create props for a ViewState */
    static viewStateToProps(viewState) {
        const savedViewProps = viewState.toProps();
        savedViewProps.bisBaseClass = ViewUtilities_1.ViewUtilities.getBisBaseClass(viewState.classFullName);
        return savedViewProps;
    }
    /** Create props for an EmphasizeElements and store in SavedViewProps */
    static emphasizeElementsToProps(vp, savedViewProps) {
        const ee = imodeljs_frontend_1.EmphasizeElements.get(vp);
        const emphasizeElementsProps = ee ? ee.toJSON(vp) : undefined;
        savedViewProps.emphasizeElementsProps = emphasizeElementsProps;
    }
}
exports.SavedView = SavedView;
//# sourceMappingURL=SavedView.js.map