/** @packageDocumentation
 * @module ContentView
 */
import { IModelConnection, ViewState } from "@bentley/imodeljs-frontend";
import { ContentCallback, ContentGroup, ContentGroupProps } from "./ContentGroup";
import { ContentLayoutDef } from "./ContentLayout";
import { ContentLayoutProps } from "./ContentLayoutProps";
import { SavedViewProps } from "./SavedView";
/** SavedViewLayoutProps interface for sharing view layout information.
 * @public
 */
export interface SavedViewLayoutProps {
    contentLayoutProps: ContentLayoutProps;
    contentGroupProps: ContentGroupProps;
    savedViews: SavedViewProps[];
}
/** ViewLayout interface for sharing view layout information.
 * @public
 */
export interface ViewLayout {
    contentLayoutDef: ContentLayoutDef;
    contentGroup: ContentGroup;
    viewStates: Array<ViewState | undefined>;
}
/** SavedViewLayout class. Used to serialize/deserialize a View Layout with Saved Views.
 * @public
 */
export declare class SavedViewLayout {
    /** Create props for a View Layout */
    static viewLayoutToProps(contentLayoutDef: ContentLayoutDef, contentGroup: ContentGroup, emphasizeElements?: boolean, contentCallback?: ContentCallback): SavedViewLayoutProps;
    /** Create an array of ViewStates from the SavedViewLayout */
    static viewStatesFromProps(iModelConnection: IModelConnection, savedProps: SavedViewLayoutProps): Promise<Array<ViewState | undefined>>;
    /** Apply EmphasizeElements from the SavedView */
    static emphasizeElementsFromProps(contentGroup: ContentGroup, savedProps: SavedViewLayoutProps): boolean;
}
//# sourceMappingURL=SavedViewLayout.d.ts.map