"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module ContentView
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.SavedViewLayout = void 0;
const SavedView_1 = require("./SavedView");
/** SavedViewLayout class. Used to serialize/deserialize a View Layout with Saved Views.
 * @public
 */
class SavedViewLayout {
    /** Create props for a View Layout */
    static viewLayoutToProps(contentLayoutDef, contentGroup, emphasizeElements = false, contentCallback) {
        const contentLayoutProps = contentLayoutDef.toJSON();
        contentLayoutProps.id = ""; // Will generate a new id when ContentLayoutDef is created
        const contentGroupProps = contentGroup.toJSON(contentCallback);
        const savedViews = new Array();
        const viewports = contentGroup.getViewports();
        for (const viewport of viewports) {
            // istanbul ignore else
            if (viewport) {
                const savedViewProps = SavedView_1.SavedView.viewStateToProps(viewport.view);
                if (emphasizeElements)
                    SavedView_1.SavedView.emphasizeElementsToProps(viewport, savedViewProps);
                savedViews.push(savedViewProps);
            }
        }
        const savedViewLayoutProps = {
            contentLayoutProps,
            contentGroupProps,
            savedViews,
        };
        return savedViewLayoutProps;
    }
    /** Create an array of ViewStates from the SavedViewLayout */
    static async viewStatesFromProps(iModelConnection, savedProps) {
        const viewStates = new Array();
        for (const savedViewProps of savedProps.savedViews) {
            const viewState = await SavedView_1.SavedView.viewStateFromProps(iModelConnection, savedViewProps);
            viewStates.push(viewState);
        }
        return viewStates;
    }
    /** Apply EmphasizeElements from the SavedView */
    static emphasizeElementsFromProps(contentGroup, savedProps) {
        const changedList = new Array();
        const viewports = contentGroup.getViewports();
        let index = 0;
        for (const savedViewProps of savedProps.savedViews) {
            const viewport = viewports[index];
            // istanbul ignore else
            if (viewport) {
                const changed = SavedView_1.SavedView.emphasizeElementsFromProps(viewport, savedViewProps);
                changedList.push(changed);
            }
            index++;
        }
        return changedList.some((changed) => changed);
    }
}
exports.SavedViewLayout = SavedViewLayout;
//# sourceMappingURL=SavedViewLayout.js.map