/** @packageDocumentation
 * @module Cursor
 */
import { RelativePosition } from "@bentley/ui-abstract";
import { PointProps, UiEvent } from "@bentley/ui-core";
/** Enum for Cursor Direction parts
 *  @public
 */
export declare enum CursorDirectionParts {
    Top = 4096,
    Left = 256,
    Right = 16,
    Bottom = 1
}
/** Enum for Cursor Direction
 * @public
 */
export declare enum CursorDirection {
    None = 0,
    Top = 4096,
    Left = 256,
    Right = 16,
    Bottom = 1,
    TopLeft = 4352,
    TopRight = 4112,
    BottomLeft = 257,
    BottomRight = 17
}
/** Cursor Updated Event Args interface.
 * @public
 */
export interface CursorUpdatedEventArgs {
    oldPt: PointProps;
    newPt: PointProps;
    direction: CursorDirection;
}
/** Cursor Updated Event class.
 * @public
 */
export declare class CursorUpdatedEvent extends UiEvent<CursorUpdatedEventArgs> {
}
/** Cursor Information class
 * @public
 */
export declare class CursorInformation {
    private static _cursorPosition;
    private static _cursorDirection;
    private static _cursorDirections;
    /** The cursor position. */
    static get cursorPosition(): PointProps;
    static set cursorPosition(pt: PointProps);
    /** Gets the cursor X position. */
    static get cursorX(): number;
    /** Gets the cursor Y position. */
    static get cursorY(): number;
    /** Gets the general cursor movement direction. */
    static get cursorDirection(): CursorDirection;
    /** Gets the [[CursorUpdatedEvent]]. */
    static readonly onCursorUpdatedEvent: CursorUpdatedEvent;
    /** Handles the mouse movement.  Sets the cursor position and direction and emits onCursorUpdatedEvent. */
    static handleMouseMove(point: PointProps): void;
    private static _determineMostFrequentDirection;
    private static _mostFrequent;
    private static _determineCursorDirection;
    /** Gets the relative position based on the cursor direction. */
    static getRelativePositionFromCursorDirection(cursorDirection: CursorDirection): RelativePosition;
    /** @internal - for testing */
    static clearCursorDirections(): void;
}
//# sourceMappingURL=CursorInformation.d.ts.map