/** @packageDocumentation
 * @module Dialog
 */
import * as React from "react";
import { CommonProps } from "@bentley/ui-core";
import { DialogChangedEvent, DialogManagerBase } from "./DialogManagerBase";
/** Modal Dialog Changed Event class.
 * @public
 */
export declare class ModalDialogChangedEvent extends DialogChangedEvent {
}
/** Modal Dialog Manager class displays and manages multiple modal dialogs
 * @public
 */
export declare class ModalDialogManager {
    /** Modal Dialog Changed Event */
    static readonly onModalDialogChangedEvent: ModalDialogChangedEvent;
    /** @internal */
    static readonly dialogManager: DialogManagerBase;
    /** Get the array of modal dialogs */
    static get dialogs(): import("./DialogManagerBase").DialogInfo[];
    /** Open a modal dialog
     * @param dialog The Dialog to open
     * @param id The id of the Dialog. If one is not provided, an id is generated.
     * @param parentDocument The Document used to determine the owning window.
     */
    static openDialog(dialog: React.ReactNode, id?: string, parentDocument?: Document): void;
    /** Close a modal dialog
     * @param dialog The Dialog to open. If one is not specified, the active dialog will be closed.
     */
    static closeDialog(dialog?: React.ReactNode): void;
    /** @internal */
    static closeAll(): void;
    /** Update the dialogs */
    static update(): void;
    /** Get the active modal dialog */
    static get activeDialog(): React.ReactNode | undefined;
    /** Get the count of modal dialogs */
    static get dialogCount(): number;
}
/** ModalDialogRenderer React component renders modal dialogs
 * @public
 */
export declare class ModalDialogRenderer extends React.PureComponent<CommonProps> {
    constructor(props: CommonProps);
    render(): React.ReactNode;
}
//# sourceMappingURL=ModalDialogManager.d.ts.map