"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Dialog
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModalDialogRenderer = exports.ModalDialogManager = exports.ModalDialogChangedEvent = void 0;
const React = require("react");
const DialogManagerBase_1 = require("./DialogManagerBase");
/** Modal Dialog Changed Event class.
 * @public
 */
class ModalDialogChangedEvent extends DialogManagerBase_1.DialogChangedEvent {
}
exports.ModalDialogChangedEvent = ModalDialogChangedEvent;
/** Modal Dialog Manager class displays and manages multiple modal dialogs
 * @public
 */
class ModalDialogManager {
    /** Get the array of modal dialogs */
    static get dialogs() { return ModalDialogManager.dialogManager.dialogs; }
    /** Open a modal dialog
     * @param dialog The Dialog to open
     * @param id The id of the Dialog. If one is not provided, an id is generated.
     * @param parentDocument The Document used to determine the owning window.
     */
    static openDialog(dialog, id, parentDocument = document) {
        ModalDialogManager.dialogManager.openDialog(dialog, id, parentDocument);
    }
    /** Close a modal dialog
     * @param dialog The Dialog to open. If one is not specified, the active dialog will be closed.
     */
    static closeDialog(dialog) {
        ModalDialogManager.dialogManager.closeDialog(dialog);
    }
    /** @internal */
    static closeAll() {
        ModalDialogManager.dialogManager.closeAll();
    }
    /** Update the dialogs */
    static update() {
        ModalDialogManager.dialogManager.update();
    }
    /** Get the active modal dialog */
    static get activeDialog() {
        return ModalDialogManager.dialogManager.activeDialog;
    }
    /** Get the count of modal dialogs */
    static get dialogCount() {
        return ModalDialogManager.dialogManager.dialogCount;
    }
}
exports.ModalDialogManager = ModalDialogManager;
/** Modal Dialog Changed Event */
ModalDialogManager.onModalDialogChangedEvent = new ModalDialogChangedEvent();
/** @internal */
ModalDialogManager.dialogManager = new DialogManagerBase_1.DialogManagerBase(ModalDialogManager.onModalDialogChangedEvent);
/** ModalDialogRenderer React component renders modal dialogs
 * @public
 */
class ModalDialogRenderer extends React.PureComponent {
    constructor(props) {
        super(props);
    }
    render() {
        return (React.createElement(DialogManagerBase_1.DialogRendererBase, Object.assign({}, this.props, { dialogManager: ModalDialogManager.dialogManager })));
    }
}
exports.ModalDialogRenderer = ModalDialogRenderer;
//# sourceMappingURL=ModalDialogManager.js.map