/** @packageDocumentation
 * @module Dialog
 */
import * as React from "react";
import { CommonProps } from "@bentley/ui-core";
import { DialogChangedEvent, DialogManagerBase } from "./DialogManagerBase";
/** Modeless Dialog Changed Event class.
 * @public
 */
export declare class ModelessDialogChangedEvent extends DialogChangedEvent {
}
/** @internal */
interface ModelessDialogInfo {
    reactNode: React.ReactNode;
    zIndex: number;
    parentDocument: Document;
}
/** Modeless Dialog Manager class displays and manages multiple modeless dialogs
 * @public
 */
export declare class ModelessDialogManager {
    /** Modeless Dialog Changed Event */
    static readonly onModelessDialogChangedEvent: ModelessDialogChangedEvent;
    /** @internal */
    static readonly dialogManager: DialogManagerBase;
    /** Get the array of modeless dialogs */
    static get dialogs(): import("./DialogManagerBase").DialogInfo[];
    private static _dialogMap;
    private static _idArray;
    private static _topZIndex;
    /** Initialize the modeless dialog manager */
    static initialize(): void;
    private static getDialogZIndexDefault;
    /** Open a modeless dialog
     * @param dialog The Dialog to open
     * @param id The id of the Dialog to open
     */
    static openDialog(dialog: React.ReactNode, id: string, parentDocument?: Document): void;
    /** Close a modeless dialog
     * @param id The id of the Dialog to close.
     */
    static closeDialog(id: string): void;
    /** @internal */
    static closeAll(): void;
    /** Update the dialogs */
    static update(): void;
    /** Get the active modeless dialog */
    static get activeDialog(): React.ReactNode | undefined;
    /** Get the count of modeless dialogs */
    static get dialogCount(): number;
    /** Handle a pointer down event on a modeless dialog */
    static handlePointerDownEvent(_event: React.PointerEvent, id: string, updateFunc: () => void): void;
    /** Get the z-index for a modeless dialog */
    static getDialogZIndex(id: string): number;
    static getDialogInfo(id: string): ModelessDialogInfo | undefined;
}
/** ModelessDialogRenderer React component renders modeless dialogs.
 * @public
 */
export declare class ModelessDialogRenderer extends React.PureComponent<CommonProps> {
    constructor(props: CommonProps);
    render(): React.ReactNode;
}
export {};
//# sourceMappingURL=ModelessDialogManager.d.ts.map