/** @packageDocumentation
 * @module Dialog
 */
import * as React from "react";
import { MessageBoxIconType, MessageBoxType, MessageBoxValue } from "@bentley/imodeljs-frontend";
import { CommonProps } from "@bentley/ui-core";
/** Properties for [[StandardMessageBox]] React component
 * @public
 */
export interface StandardMessageBoxProps extends CommonProps {
    /** Indicates whether the message box is open */
    opened: boolean;
    /** The standard icon to display in the message box */
    iconType: MessageBoxIconType;
    /** Title to display in the message box */
    title: string;
    /** Controls the button set displayed */
    messageBoxType: MessageBoxType;
    /** Callback function for processing the message box result */
    onResult?: (result: MessageBoxValue) => void;
}
/** State for [[StandardMessageBox]] React component
 * @internal
 */
interface StandardMessageBoxState {
    opened: boolean;
}
/** StandardMessageBox React component displays a standard icon, message text and a standard button set in the lower right.
 * @public
 */
export declare class StandardMessageBox extends React.PureComponent<StandardMessageBoxProps, StandardMessageBoxState> {
    /** @internal */
    readonly state: Readonly<StandardMessageBoxState>;
    constructor(props: StandardMessageBoxProps);
    render(): JSX.Element;
    private _handleButton;
    private _handleCancel;
    private _closeDialog;
}
export {};
//# sourceMappingURL=StandardMessageBox.d.ts.map