"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Dialog
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.StandardMessageBox = void 0;
const React = require("react");
const imodeljs_frontend_1 = require("@bentley/imodeljs-frontend");
const ui_core_1 = require("@bentley/ui-core");
const ModalDialogManager_1 = require("./ModalDialogManager");
/** StandardMessageBox React component displays a standard icon, message text and a standard button set in the lower right.
 * @public
 */
class StandardMessageBox extends React.PureComponent {
    constructor(props) {
        super(props);
        this._handleButton = (buttonType) => {
            this._closeDialog(() => {
                // istanbul ignore else
                if (this.props.onResult)
                    this.props.onResult(buttonType);
            });
        };
        this._handleCancel = () => {
            this._closeDialog(() => {
                // istanbul ignore else
                if (this.props.onResult)
                    this.props.onResult(imodeljs_frontend_1.MessageBoxValue.Cancel);
            });
        };
        this._closeDialog = (followUp) => {
            this.setState((_prevState) => ({
                opened: false,
            }), () => {
                ModalDialogManager_1.ModalDialogManager.closeDialog();
                followUp();
            });
        };
        this.state = {
            opened: this.props.opened,
        };
    }
    render() {
        const buttonCluster = new Array();
        switch (this.props.messageBoxType) {
            case imodeljs_frontend_1.MessageBoxType.Ok:
            case imodeljs_frontend_1.MessageBoxType.LargeOk:
                buttonCluster.push({ type: ui_core_1.DialogButtonType.OK, onClick: () => { this._handleButton(imodeljs_frontend_1.MessageBoxValue.Ok); } });
                break;
            case imodeljs_frontend_1.MessageBoxType.OkCancel:
            case imodeljs_frontend_1.MessageBoxType.MediumAlert:
                buttonCluster.push({ type: ui_core_1.DialogButtonType.OK, onClick: () => { this._handleButton(imodeljs_frontend_1.MessageBoxValue.Ok); } });
                buttonCluster.push({ type: ui_core_1.DialogButtonType.Cancel, onClick: () => { this._handleButton(imodeljs_frontend_1.MessageBoxValue.Cancel); } });
                break;
            case imodeljs_frontend_1.MessageBoxType.YesNo:
            case imodeljs_frontend_1.MessageBoxType.YesNoCancel:
                buttonCluster.push({ type: ui_core_1.DialogButtonType.Yes, onClick: () => { this._handleButton(imodeljs_frontend_1.MessageBoxValue.Yes); } });
                buttonCluster.push({ type: ui_core_1.DialogButtonType.No, onClick: () => { this._handleButton(imodeljs_frontend_1.MessageBoxValue.No); } });
                if (imodeljs_frontend_1.MessageBoxType.YesNoCancel === this.props.messageBoxType)
                    buttonCluster.push({ type: ui_core_1.DialogButtonType.Cancel, onClick: () => { this._handleButton(imodeljs_frontend_1.MessageBoxValue.Cancel); } });
                break;
        }
        let severity = ui_core_1.MessageSeverity.None;
        switch (this.props.iconType) {
            case imodeljs_frontend_1.MessageBoxIconType.NoSymbol:
                severity = ui_core_1.MessageSeverity.None;
                break;
            case imodeljs_frontend_1.MessageBoxIconType.Information:
                severity = ui_core_1.MessageSeverity.Information;
                break;
            case imodeljs_frontend_1.MessageBoxIconType.Question:
                severity = ui_core_1.MessageSeverity.Question;
                break;
            case imodeljs_frontend_1.MessageBoxIconType.Warning:
                severity = ui_core_1.MessageSeverity.Warning;
                break;
            case imodeljs_frontend_1.MessageBoxIconType.Critical:
                severity = ui_core_1.MessageSeverity.Error;
                break;
        }
        return (React.createElement(ui_core_1.MessageBox, { className: this.props.className, style: this.props.style, opened: this.state.opened, title: this.props.title, severity: severity, buttonCluster: buttonCluster, onClose: this._handleCancel, onEscape: this._handleCancel }, this.props.children));
    }
}
exports.StandardMessageBox = StandardMessageBox;
//# sourceMappingURL=StandardMessageBox.js.map