/** @packageDocumentation
 * @module Dialog
 */
/// <reference types="react" />
import { DialogLayoutDataProvider } from "@bentley/ui-abstract";
/** Props for [[UiDataProvidedDialog]] component.
 * @beta
 */
export interface UiDataProvidedDialogProps {
    /** Dialog title */
    title: string;
    /** Provider that provides and lays out DialogItems */
    uiDataProvider: DialogLayoutDataProvider;
    /** Indicates if Dialog is Modal */
    isModal: boolean;
    /** Id used to specify dialog. */
    id?: string;
    /** Indicates whether the user can resize dialog with cursor. Default: false */
    resizable?: boolean;
    /** Indicates whether the user can move dialog with cursor. Default: false */
    movable?: boolean;
    /** Initial width of dialog. Displayed in px if value is a number; otherwise, displayed in specified CSS unit. Default: "50%" */
    width?: string | number;
    /** Initial height of dialog. Displayed in px if value is a number; otherwise, displayed in specified CSS unit. */
    height?: string | number;
    /** Minimum width that the dialog may be resized to. Displayed in px if value is a number; otherwise, displayed in specified CSS unit. Default: 300px */
    minWidth?: string | number;
    /** Minimum height that the dialog may be resized to. Displayed in px if value is a number; otherwise, displayed in specified CSS unit. Default: 100px */
    minHeight?: string | number;
    /** Maximum width that the dialog may be resized to. Displayed in px if value is a number; otherwise, displayed in specified CSS unit. */
    maxWidth?: string | number;
    /** Maximum height that the dialog may be resized to. Displayed in px if value is a number; otherwise, displayed in specified CSS unit. */
    maxHeight?: string | number;
}
/** Component to show dialog populated from properties supplied via uiDataProvider
 * @beta
 */
export declare function UiDataProvidedDialog({ uiDataProvider, id, isModal, ...dialogProps }: UiDataProvidedDialogProps): JSX.Element;
//# sourceMappingURL=UiDataProvidedDialog.d.ts.map