"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Dialog
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UiDataProvidedDialog = void 0;
const React = require("react");
const ui_core_1 = require("@bentley/ui-core");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
const ModalDialogManager_1 = require("./ModalDialogManager");
const ModelessDialogManager_1 = require("./ModelessDialogManager");
const DefaultDialogGridContainer_1 = require("../uiprovider/DefaultDialogGridContainer");
const ComponentGenerator_1 = require("../uiprovider/ComponentGenerator");
/** Component to show dialog populated from properties supplied via uiDataProvider
 * @beta
 */
function UiDataProvidedDialog(_a) {
    var { uiDataProvider, id, isModal } = _a, dialogProps = __rest(_a, ["uiDataProvider", "id", "isModal"]);
    const dialogId = React.useRef(id ? id : ui_ninezone_1.getUniqueId());
    const dialogIsModal = React.useRef(isModal);
    const onOK = React.useRef();
    const onCancel = React.useRef();
    const closeDialog = () => {
        if (dialogIsModal.current)
            ModalDialogManager_1.ModalDialogManager.closeDialog();
        else
            ModelessDialogManager_1.ModelessDialogManager.closeDialog(dialogId.current);
    };
    const handleOk = React.useCallback(() => {
        onOK.current && onOK.current();
        closeDialog();
    }, []);
    const handleCancel = React.useCallback(() => {
        onCancel.current && onCancel.current();
        closeDialog();
    }, []);
    const generateButtonCluster = React.useCallback((buttons) => {
        // istanbul ignore else
        if (buttons) {
            for (const button of buttons) {
                if (ui_core_1.DialogButtonType.Cancel === button.type) {
                    onCancel.current = button.onClick;
                    button.onClick = handleCancel;
                    continue;
                }
                if (ui_core_1.DialogButtonType.OK === button.type) {
                    onOK.current = button.onClick;
                    button.onClick = handleOk;
                    continue;
                }
            }
        }
        return buttons;
    }, [handleCancel, handleOk]);
    const [buttonCluster, setButtonCluster] = React.useState(() => generateButtonCluster(uiDataProvider.supplyButtonData()));
    React.useEffect(() => {
        const handleReloaded = () => {
            setButtonCluster(generateButtonCluster(uiDataProvider.supplyButtonData()));
        };
        uiDataProvider.onItemsReloadedEvent.addListener(handleReloaded);
        return () => {
            uiDataProvider.onItemsReloadedEvent.removeListener(handleReloaded);
        };
    }, [generateButtonCluster, uiDataProvider]);
    React.useEffect(() => {
        const handleButtonReloaded = () => {
            setButtonCluster(generateButtonCluster(uiDataProvider.supplyButtonData()));
        };
        uiDataProvider.onButtonsReloadedEvent.addListener(handleButtonReloaded);
        return () => {
            uiDataProvider.onButtonsReloadedEvent.removeListener(handleButtonReloaded);
        };
    }, [generateButtonCluster, uiDataProvider]);
    const handleClose = React.useCallback(() => closeDialog(), []);
    return (React.createElement(ui_core_1.Dialog, Object.assign({}, dialogProps, { opened: true, modal: isModal, buttonCluster: buttonCluster, onClose: handleClose, onEscape: handleClose }),
        React.createElement(DefaultDialogGridContainer_1.DefaultDialogGridContainer, { componentGenerator: new ComponentGenerator_1.ComponentGenerator(uiDataProvider) })));
}
exports.UiDataProvidedDialog = UiDataProvidedDialog;
//# sourceMappingURL=UiDataProvidedDialog.js.map