/** @packageDocumentation
 * @module DragDrop
 */
import * as React from "react";
import { DndComponentClass } from "react-dnd";
import { DragLayerProps, DragSourceArguments } from "@bentley/ui-components";
import { CommonProps, UiEvent } from "@bentley/ui-core";
/** Drag/Drop Layer Changed Event Args class.
 * @beta
 * @deprecated
 */
export interface DragDropLayerChangedEventArgs {
    /** The new drag type. */
    type: string | undefined;
}
/** Drag/Drop Layer Changed Event class.
 * @beta
 * @deprecated
 */
export declare class DragDropLayerChangedEvent extends UiEvent<DragDropLayerChangedEventArgs> {
}
/** Drag/Drop Layer Manager class.
 * @beta
 * @deprecated
 */
export declare class DragDropLayerManager {
    private static _currentType;
    private static _layers;
    private static _dragDropLayerChangedEvent;
    static get onDragDropLayerChangedEvent(): DragDropLayerChangedEvent;
    /**
     * Gets the currently active drag type.
     */
    static getType(): string | undefined;
    /**
     * Gets the DragLayer component of the currently active type.
     */
    static getActiveLayer(): React.ComponentType<DragLayerProps<any>> | undefined;
    /**
     * Sets the current type.
     * @note The current drag type is set automatically when a drag starts. Manually setting type before a drag will be overridden by DragDropManager.
     */
    static setType(type: string | undefined): void;
    /** Registers a new DragLayer for the given type. */
    static registerTypeLayer(type: string, layer: React.ComponentType<DragLayerProps>): void;
}
/** Properties for the DragDropLayerRenderer component
 * @beta
 * @deprecated
 */
export interface DragDropLayerRendererProps extends CommonProps {
    dragging?: boolean;
    item?: any;
    itemType?: string;
    args?: DragSourceArguments;
    /** @internal */
    clientOffset?: {
        x: number;
        y: number;
    };
    /** @internal */
    initialClientOffset?: {
        x: number;
        y: number;
    };
    /** @internal */
    sourceClientOffset?: {
        x: number;
        y: number;
    };
    /** @internal */
    initialSourceClientOffset?: {
        x: number;
        y: number;
    };
}
/** DragDropLayerRenderer component.
 * @beta
 * @deprecated
 */
export declare class DragDropLayerRendererComponent extends React.Component<DragDropLayerRendererProps> {
    private _dragging;
    constructor(props: DragDropLayerRendererProps);
    componentDidMount(): void;
    componentWillUnmount(): void;
    private _handleDragStart;
    private _handleDragEnd;
    render(): React.ReactNode;
}
/**
 * Contains the DragLayers to all DragSource types.
 * New DragLayers are registered by type using [[DragDropLayerManager.registerTypeLayer]]
 * This component must be placed on a root DOM node at the bottom to render DragLayers properly.
 * @beta
 * @deprecated
 */
export declare const DragDropLayerRenderer: typeof DragDropLayerRendererComponent & DndComponentClass<typeof React.Component, {}>;
//# sourceMappingURL=DragDropLayerManager.d.ts.map