"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module DragDrop
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DragDropLayerRenderer = exports.DragDropLayerRendererComponent = exports.DragDropLayerManager = exports.DragDropLayerChangedEvent = void 0;
const classnames = require("classnames");
const React = require("react");
const react_dnd_1 = require("react-dnd");
const ui_core_1 = require("@bentley/ui-core");
/** Drag/Drop Layer Changed Event class.
 * @beta
 * @deprecated
 */
class DragDropLayerChangedEvent extends ui_core_1.UiEvent {
} // eslint-disable-line deprecation/deprecation
exports.DragDropLayerChangedEvent = DragDropLayerChangedEvent;
/** Drag/Drop Layer Manager class.
 * @beta
 * @deprecated
 */
class DragDropLayerManager {
    // istanbul ignore next
    static get onDragDropLayerChangedEvent() { return this._dragDropLayerChangedEvent; } // eslint-disable-line deprecation/deprecation
    /**
     * Gets the currently active drag type.
     */
    static getType() {
        return this._currentType;
    }
    /**
     * Gets the DragLayer component of the currently active type.
     */
    static getActiveLayer() {
        // istanbul ignore if
        if (this._currentType)
            return this._layers[this._currentType];
        return undefined;
    }
    /**
     * Sets the current type.
     * @note The current drag type is set automatically when a drag starts. Manually setting type before a drag will be overridden by DragDropManager.
     */
    static setType(type) {
        this._currentType = type;
        this._dragDropLayerChangedEvent.emit({ type });
    }
    /** Registers a new DragLayer for the given type. */
    // istanbul ignore next
    static registerTypeLayer(type, layer) {
        this._layers[type] = layer;
    }
}
exports.DragDropLayerManager = DragDropLayerManager;
DragDropLayerManager._layers = {}; // eslint-disable-line deprecation/deprecation
DragDropLayerManager._dragDropLayerChangedEvent = new DragDropLayerChangedEvent(); // eslint-disable-line deprecation/deprecation
/** DragDropLayerRenderer component.
 * @beta
 * @deprecated
 */
class DragDropLayerRendererComponent extends React.Component {
    constructor(props) {
        super(props);
        this._dragging = false;
        // istanbul ignore next
        this._handleDragStart = () => {
            this._dragging = true;
        };
        // istanbul ignore next
        this._handleDragEnd = () => {
            this._dragging = false;
        };
    }
    componentDidMount() {
        window.addEventListener("dragstart", this._handleDragStart);
        window.addEventListener("dragend", this._handleDragEnd);
    }
    componentWillUnmount() {
        window.removeEventListener("dragstart", this._handleDragStart);
        window.removeEventListener("dragend", this._handleDragEnd);
    }
    // istanbul ignore next
    render() {
        // eslint-disable-next-line deprecation/deprecation
        if (this.props.itemType !== DragDropLayerManager.getType()) { // A drag of a new type has been triggered.
            DragDropLayerManager.setType(this.props.itemType); // eslint-disable-line deprecation/deprecation
        }
        const { item, clientOffset, initialClientOffset, sourceClientOffset, initialSourceClientOffset, } = this.props;
        const dragSourceArgs = item; // eslint-disable-line deprecation/deprecation
        // eslint-disable-next-line deprecation/deprecation
        const LayerElement = DragDropLayerManager.getActiveLayer() || (dragSourceArgs && dragSourceArgs.defaultDragLayer); // eslint-disable-line @typescript-eslint/naming-convention
        if (!this._dragging || !LayerElement)
            return null;
        if (clientOffset)
            dragSourceArgs.clientOffset = clientOffset;
        if (initialClientOffset)
            dragSourceArgs.initialClientOffset = initialClientOffset;
        dragSourceArgs.sourceClientOffset = sourceClientOffset;
        dragSourceArgs.initialSourceClientOffset = initialSourceClientOffset;
        return (React.createElement("div", { className: classnames("uifw-dragdrop-layer", this.props.className), style: this.props.style },
            React.createElement(LayerElement, { args: dragSourceArgs })));
    }
}
exports.DragDropLayerRendererComponent = DragDropLayerRendererComponent;
/** Dnd Collecting Function */
const collect = (monitor) => ({
    item: monitor.getItem(),
    itemType: monitor.getItemType(),
    clientOffset: monitor.getClientOffset(),
    initialClientOffset: monitor.getInitialClientOffset(),
    sourceClientOffset: monitor.getSourceClientOffset(),
    initialSourceClientOffset: monitor.getInitialSourceClientOffset(),
    dragging: monitor.isDragging(),
});
/**
 * Contains the DragLayers to all DragSource types.
 * New DragLayers are registered by type using [[DragDropLayerManager.registerTypeLayer]]
 * This component must be placed on a root DOM node at the bottom to render DragLayers properly.
 * @beta
 * @deprecated
 */
exports.DragDropLayerRenderer = react_dnd_1.DragLayer(collect)(DragDropLayerRendererComponent); // eslint-disable-line deprecation/deprecation
//# sourceMappingURL=DragDropLayerManager.js.map