"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Hooks
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.useActiveStageId = void 0;
const react_1 = require("react");
const FrontstageManager_1 = require("../frontstage/FrontstageManager");
/** React hook that maintains the active stage Id.
 * @public
 */
function useActiveStageId() {
    const [activeStageId, setActiveStageId] = react_1.useState(FrontstageManager_1.FrontstageManager.activeFrontstageId);
    react_1.useEffect(() => {
        const handleFrontstageActivatedEvent = (args) => {
            setActiveStageId(args.activatedFrontstageDef.id);
        };
        FrontstageManager_1.FrontstageManager.onFrontstageActivatedEvent.addListener(handleFrontstageActivatedEvent);
        return () => {
            FrontstageManager_1.FrontstageManager.onFrontstageActivatedEvent.removeListener(handleFrontstageActivatedEvent);
        };
    }, []);
    return activeStageId;
}
exports.useActiveStageId = useActiveStageId;
//# sourceMappingURL=useActiveStageId.js.map