"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Hooks
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.useActiveViewport = void 0;
const react_1 = require("react");
const imodeljs_frontend_1 = require("@bentley/imodeljs-frontend");
const ContentViewManager_1 = require("../content/ContentViewManager");
const SyncUiEventDispatcher_1 = require("../syncui/SyncUiEventDispatcher");
/** React hook that maintains the active viewport.
 * @public
 */
// istanbul ignore next
function useActiveViewport() {
    const [activeViewport, setActiveViewport] = react_1.useState(imodeljs_frontend_1.IModelApp.viewManager.selectedView);
    react_1.useEffect(() => {
        const onActiveContentChanged = (_args) => {
            setActiveViewport(imodeljs_frontend_1.IModelApp.viewManager.selectedView);
        };
        // IModelApp.viewManager.onSelectedViewportChanged will often fire before UI components have mounted
        // so use ContentViewManager.onActiveContentChangedEvent which will always trigger once all stage components
        // are loaded and when the IModelApp.viewManager.selectedView changes.
        ContentViewManager_1.ContentViewManager.onActiveContentChangedEvent.addListener(onActiveContentChanged);
        return () => {
            ContentViewManager_1.ContentViewManager.onActiveContentChangedEvent.removeListener(onActiveContentChanged);
        };
    }, []);
    react_1.useEffect(() => {
        const syncIdsOfInterest = [SyncUiEventDispatcher_1.SyncUiEventId.ActiveContentChanged, SyncUiEventDispatcher_1.SyncUiEventId.ContentControlActivated, SyncUiEventDispatcher_1.SyncUiEventId.FrontstageReady];
        const handleSyncUiEvent = (args) => {
            // istanbul ignore else
            if (syncIdsOfInterest.some((value) => args.eventIds.has(value))) {
                const activeContentControl = ContentViewManager_1.ContentViewManager.getActiveContentControl();
                setActiveViewport(activeContentControl && activeContentControl.viewport);
            }
        };
        return SyncUiEventDispatcher_1.SyncUiEventDispatcher.onSyncUiEvent.addListener(handleSyncUiEvent);
    }, []);
    return activeViewport;
}
exports.useActiveViewport = useActiveViewport;
//# sourceMappingURL=useActiveViewport.js.map