"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* Licensed under the MIT License. See LICENSE.md in the project root for license terms.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Hooks
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.useAvailableUiItemsProviders = void 0;
const react_1 = require("react");
const ui_abstract_1 = require("@bentley/ui-abstract");
/** React hook that maintains the number of available UiItemsProviders. This allows components to use it to refresh when a
 * UiItemsProviders is added or removed allowing the ui component to be re-rendered.
 * @internal
 */
function useAvailableUiItemsProviders() {
    const [uiItemsProviderIds, setUiItemsProviderIds] = react_1.useState(ui_abstract_1.UiItemsManager.registeredProviderIds);
    react_1.useEffect(() => {
        const handleUiProviderRegisteredEvent = () => {
            setUiItemsProviderIds(ui_abstract_1.UiItemsManager.registeredProviderIds);
        };
        ui_abstract_1.UiItemsManager.onUiProviderRegisteredEvent.addListener(handleUiProviderRegisteredEvent);
        return () => {
            ui_abstract_1.UiItemsManager.onUiProviderRegisteredEvent.removeListener(handleUiProviderRegisteredEvent);
        };
    }, []);
    return uiItemsProviderIds;
}
exports.useAvailableUiItemsProviders = useAvailableUiItemsProviders;
//# sourceMappingURL=useAvailableUiItemsProviders.js.map