"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Hooks
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.useEscapeSetFocusToHome = exports.onEscapeSetFocusToHome = void 0;
const React = require("react");
const ui_abstract_1 = require("@bentley/ui-abstract");
const KeyboardShortcut_1 = require("../keyboardshortcut/KeyboardShortcut");
/** Keyboard Event handler to set focus to Home on Escape key
 * @internal
 */
function onEscapeSetFocusToHome(e) {
    // istanbul ignore else
    if (e.key === ui_abstract_1.SpecialKey.Escape) {
        KeyboardShortcut_1.KeyboardShortcutManager.setFocusToHome();
    }
}
exports.onEscapeSetFocusToHome = onEscapeSetFocusToHome;
/** useCallback Hook for Keyboard Event handler to set focus to Home on Escape key
 * @internal
 */
function useEscapeSetFocusToHome() {
    return React.useCallback(onEscapeSetFocusToHome, []);
}
exports.useEscapeSetFocusToHome = useEscapeSetFocusToHome;
//# sourceMappingURL=useEscapeSetFocusToHome.js.map