"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Hooks
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.FrameworkVersionSwitch = exports.FrameworkVersion = exports.FrameworkVersionContext = exports.useFrameworkVersion = void 0;
const React = require("react");
const UiFramework_1 = require("../UiFramework");
/** @internal */
function useFrameworkVersion() {
    return React.useContext(exports.FrameworkVersionContext);
}
exports.useFrameworkVersion = useFrameworkVersion;
/** @internal */
exports.FrameworkVersionContext = React.createContext("1"); // eslint-disable-line @typescript-eslint/naming-convention
/** @alpha */
function FrameworkVersion(props) {
    const currentVersion = React.useRef("");
    React.useEffect(() => {
        const version = props.version;
        // ensure UiFramework.uiVersion matches as non-react extensions may need to know target UI version.
        UiFramework_1.UiFramework.setUiVersion(props.version);
        // istanbul ignore else
        if (currentVersion.current !== version) {
            const oldVersion = currentVersion.current;
            currentVersion.current = version;
            UiFramework_1.UiFramework.onFrameworkVersionChangedEvent.emit({ version, oldVersion });
        }
    }, [props.version]);
    return (React.createElement(exports.FrameworkVersionContext.Provider, { children: props.children, value: props.version }));
}
exports.FrameworkVersion = FrameworkVersion;
/** @internal */
function FrameworkVersionSwitch(props) {
    const version = useFrameworkVersion();
    switch (version) {
        case "2": {
            return React.createElement(React.Fragment, null, props.v2);
        }
        case "1":
        default: {
            return React.createElement(React.Fragment, null, props.v1);
        }
    }
}
exports.FrameworkVersionSwitch = FrameworkVersionSwitch;
//# sourceMappingURL=useFrameworkVersion.js.map