/** @packageDocumentation
 * @module IModelComponents
 */
/// <reference types="react" />
import { IPresentationTreeDataProvider } from "@bentley/presentation-components";
import { AbstractTreeNodeLoaderWithProvider, TreeNodeRendererProps, TreeRendererProps } from "@bentley/ui-components";
import { NodeCheckboxRenderProps } from "@bentley/ui-core";
import { VisibilityTreeFilterInfo } from "./Common";
/**
 * Creates Visibility tree renderer which renders nodes with eye checkbox.
 * @alpha
 */
export declare const useVisibilityTreeRenderer: (iconsEnabled: boolean, descriptionsEnabled: boolean) => (props: TreeRendererProps) => JSX.Element;
/**
 * Creates node renderer which renders node with eye checkbox.
 * @alpha
 */
export declare const createVisibilityTreeNodeRenderer: (iconsEnabled: boolean, descriptionEnabled: boolean) => (props: TreeNodeRendererProps) => JSX.Element;
/**
 * Checkbox renderer that renders an eye.
 * @alpha
 */
export declare const visibilityTreeNodeCheckboxRenderer: (props: NodeCheckboxRenderProps) => JSX.Element;
/**
 * Filters data provider used in supplied node loader and invokes onFilterApplied when filtering is completed.
 * @alpha
 */
export declare const useVisibilityTreeFiltering: (nodeLoader: AbstractTreeNodeLoaderWithProvider<IPresentationTreeDataProvider>, filterInfo?: VisibilityTreeFilterInfo | undefined, onFilterApplied?: ((filteredDataProvider: IPresentationTreeDataProvider, matchesCount: number) => void) | undefined) => {
    filteredNodeLoader: AbstractTreeNodeLoaderWithProvider<IPresentationTreeDataProvider>;
    isFiltering: boolean;
    nodeHighlightingProps: import("@bentley/ui-components").HighlightableTreeProps | undefined;
};
/**
 * Properties for [[VisibilityTreeNoFilteredData]] component.
 * @alpha
 */
export interface VisibilityTreeNoFilteredDataProps {
    title: string;
    message: string;
}
/**
 * Renders message that no nodes was found for filter.
 * @alpha
 */
export declare function VisibilityTreeNoFilteredData(props: VisibilityTreeNoFilteredDataProps): JSX.Element;
//# sourceMappingURL=VisibilityTreeRenderer.d.ts.map