"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module IModelComponents
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.VisibilityTreeNoFilteredData = exports.useVisibilityTreeFiltering = exports.visibilityTreeNodeCheckboxRenderer = exports.createVisibilityTreeNodeRenderer = exports.useVisibilityTreeRenderer = void 0;
const React = require("react");
const presentation_components_1 = require("@bentley/presentation-components");
const ui_components_1 = require("@bentley/ui-components");
const ui_core_1 = require("@bentley/ui-core");
/**
 * Creates Visibility tree renderer which renders nodes with eye checkbox.
 * @alpha
 */
const useVisibilityTreeRenderer = (iconsEnabled, descriptionsEnabled) => {
    // eslint-disable-next-line react-hooks/exhaustive-deps
    const nodeRenderer = React.useCallback(exports.createVisibilityTreeNodeRenderer(iconsEnabled, descriptionsEnabled), [iconsEnabled, descriptionsEnabled]);
    return React.useCallback((props) => (React.createElement(ui_components_1.TreeRenderer, Object.assign({}, props, { nodeRenderer: nodeRenderer }))), [nodeRenderer]);
};
exports.useVisibilityTreeRenderer = useVisibilityTreeRenderer;
const imageLoader = new ui_components_1.TreeImageLoader();
/**
 * Creates node renderer which renders node with eye checkbox.
 * @alpha
 */
const createVisibilityTreeNodeRenderer = (iconsEnabled, descriptionEnabled) => {
    return (props) => ( // eslint-disable-line react/display-name
    React.createElement(ui_components_1.TreeNodeRenderer, Object.assign({}, props, { checkboxRenderer: exports.visibilityTreeNodeCheckboxRenderer, descriptionEnabled: descriptionEnabled, imageLoader: iconsEnabled ? imageLoader : undefined, className: "with-checkbox" })));
};
exports.createVisibilityTreeNodeRenderer = createVisibilityTreeNodeRenderer;
/**
 * Checkbox renderer that renders an eye.
 * @alpha
 */
const visibilityTreeNodeCheckboxRenderer = (props) => (React.createElement(ui_core_1.ImageCheckBox, { checked: props.checked, disabled: props.disabled, imageOn: "icon-visibility", imageOff: "icon-visibility-hide-2", onClick: props.onChange, tooltip: props.title }));
exports.visibilityTreeNodeCheckboxRenderer = visibilityTreeNodeCheckboxRenderer;
/**
 * Filters data provider used in supplied node loader and invokes onFilterApplied when filtering is completed.
 * @alpha
 */
const useVisibilityTreeFiltering = (nodeLoader, filterInfo, onFilterApplied) => {
    const { filter, activeMatchIndex } = filterInfo !== null && filterInfo !== void 0 ? filterInfo : { filter: undefined, activeMatchIndex: undefined };
    const { filteredNodeLoader, isFiltering, matchesCount, nodeHighlightingProps, } = presentation_components_1.useControlledPresentationTreeFiltering({ nodeLoader, filter, activeMatchIndex });
    React.useEffect(() => {
        if (filter && matchesCount !== undefined && filteredNodeLoader !== nodeLoader)
            onFilterApplied && onFilterApplied(filteredNodeLoader.dataProvider, matchesCount);
    }, [filter, matchesCount, nodeLoader, filteredNodeLoader, onFilterApplied]);
    return { filteredNodeLoader, isFiltering, nodeHighlightingProps };
};
exports.useVisibilityTreeFiltering = useVisibilityTreeFiltering;
/**
 * Renders message that no nodes was found for filter.
 * @alpha
 */
function VisibilityTreeNoFilteredData(props) {
    return (React.createElement("div", { className: "components-tree-errormessage" },
        React.createElement("span", { className: "errormessage-header" }, props.title),
        React.createElement("span", { className: "errormessage-body" }, props.message)));
}
exports.VisibilityTreeNoFilteredData = VisibilityTreeNoFilteredData;
//# sourceMappingURL=VisibilityTreeRenderer.js.map