/** @packageDocumentation
 * @module IModelComponents
 */
/// <reference types="react" />
import "./CategoriesTree.scss";
import { IModelConnection, ViewManager, Viewport } from "@bentley/imodeljs-frontend";
import { Ruleset } from "@bentley/presentation-common";
import { IPresentationTreeDataProvider } from "@bentley/presentation-components";
import { VisibilityTreeFilterInfo } from "../Common";
import { CategoryVisibilityHandler } from "./CategoryVisibilityHandler";
/**
 * Presentation rules used by ControlledCategoriesTree
 * @internal
 */
export declare const RULESET_CATEGORIES: Ruleset;
/**
 * Properties for the [[CategoryTree]] component
 * @public
 */
export interface CategoryTreeProps {
    /** Flag for accommodating all viewports */
    allViewports?: boolean;
    /** Active viewport */
    activeView?: Viewport;
    /**
     * An IModel to pull data from
     */
    iModel: IModelConnection;
    /**
     * Start loading hierarchy as soon as the component is created
     */
    enablePreloading?: boolean;
    /**
     * Information for tree filtering.
     * @alpha
     */
    filterInfo?: VisibilityTreeFilterInfo;
    /**
     * Callback invoked when tree is filtered.
     */
    onFilterApplied?: (filteredDataProvider: IPresentationTreeDataProvider, matchesCount: number) => void;
    /**
     * Custom data provider to use for testing
     * @internal
     */
    dataProvider?: IPresentationTreeDataProvider;
    /**
     * Custom category visibility handler to use for testing
     * @internal
     */
    categoryVisibilityHandler?: CategoryVisibilityHandler;
    /**
     * Custom view manager to use for testing
     * @internal
     */
    viewManager?: ViewManager;
}
/**
 * Tree which displays and manages categories contained in an iModel.
 * @public
 */
export declare function CategoryTree(props: CategoryTreeProps): JSX.Element;
/**
 * CategoryTree that is connected to the IModelConnection property in the Redux store. The
 * application must set up the Redux store and include the FrameworkReducer.
 * @beta
 */
export declare const IModelConnectedCategoryTree: import("react-redux").ConnectedComponent<typeof CategoryTree, any>;
/**
 * Toggles visibility of categories to show or hide.
 * @alpha
 */
export declare function toggleAllCategories(viewManager: ViewManager, imodel: IModelConnection, display: boolean, viewport?: Viewport, forAllViewports?: boolean, filteredProvider?: IPresentationTreeDataProvider): Promise<void>;
/**
 * Gets ids of all categories or categories from filtered data provider.
 * @alpha
 */
export declare function getCategories(imodel: IModelConnection, viewport?: Viewport, filteredProvider?: IPresentationTreeDataProvider): Promise<string[]>;
//# sourceMappingURL=CategoriesTree.d.ts.map