"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module IModelComponents
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.IModelConnectedSpatialContainmentTree = exports.SpatialContainmentTree = exports.RULESET_SPATIAL_BREAKDOWN_GROUPED_BY_CLASS = exports.RULESET_SPATIAL_BREAKDOWN = void 0;
require("./SpatialContainmentTree.scss");
const React = require("react");
const presentation_components_1 = require("@bentley/presentation-components");
const ui_components_1 = require("@bentley/ui-components");
const ui_core_1 = require("@bentley/ui-core");
const connectIModel_1 = require("../../redux/connectIModel");
const Common_1 = require("../Common");
const PAGING_SIZE = 20;
/** @internal */
exports.RULESET_SPATIAL_BREAKDOWN = require("./SpatialBreakdown.json"); // eslint-disable-line @typescript-eslint/no-var-requires
/** @internal */
exports.RULESET_SPATIAL_BREAKDOWN_GROUPED_BY_CLASS = require("./SpatialBreakdown.GroupedByClass.json"); // eslint-disable-line @typescript-eslint/no-var-requires
/**
 * Tree which displays and manages models or categories contained in an iModel.
 * @public
 */
function SpatialContainmentTree(props) {
    const { nodeLoader } = presentation_components_1.usePresentationTreeNodeLoader({
        imodel: props.iModel,
        dataProvider: props.dataProvider,
        ruleset: (!props.enableElementsClassGrouping) ? exports.RULESET_SPATIAL_BREAKDOWN : /* istanbul ignore next */ exports.RULESET_SPATIAL_BREAKDOWN_GROUPED_BY_CLASS,
        appendChildrenCountForGroupingNodes: (props.enableElementsClassGrouping === Common_1.ClassGroupingOption.YesWithCounts),
        pagingSize: PAGING_SIZE,
        preloadingEnabled: props.enablePreloading,
    });
    const eventHandler = ui_core_1.useDisposable(React.useCallback(() => new presentation_components_1.UnifiedSelectionTreeEventHandler({
        nodeLoader,
        collapsedChildrenDisposalEnabled: true,
    }), [nodeLoader]));
    const visibleNodes = ui_components_1.useVisibleTreeNodes(nodeLoader.modelSource);
    return (React.createElement("div", { className: "ui-fw-spatial-tree" },
        React.createElement(ui_components_1.ControlledTree, { visibleNodes: visibleNodes, nodeLoader: nodeLoader, treeEvents: eventHandler, selectionMode: ui_components_1.SelectionMode.Extended })));
}
exports.SpatialContainmentTree = SpatialContainmentTree;
/**
 * SpatialContainmentTree that is connected to the IModelConnection property in the Redux store. The
 * application must set up the Redux store and include the FrameworkReducer.
 * @beta
 */
exports.IModelConnectedSpatialContainmentTree = connectIModel_1.connectIModelConnection(null, null)(SpatialContainmentTree); // eslint-disable-line @typescript-eslint/naming-convention
//# sourceMappingURL=SpatialContainmentTree.js.map