/** @packageDocumentation
 * @module Item
 */
import "./KeyinBrowser.scss";
import * as React from "react";
import { AutoSuggestData, CommonProps } from "@bentley/ui-core";
/** Data for each key-in.
 */
interface KeyinBrowserData extends AutoSuggestData {
    /** English key-in - Browser supports both English and localized key-ins */
    englishKeyin: string;
}
/** State of key-in browser.
 */
interface KeyinBrowserState {
    keyins: KeyinBrowserData[];
    currentToolId: string | undefined;
    currentArgs: string;
}
/** Arguments for [[KeyinBrowserProps]] onExecute callback.
 * @beta
 */
export interface KeyinBrowserExecuteArgs {
    /** Id of the tool that was run */
    toolId: string | undefined;
    /** Arguments passed to the tool */
    args: string[];
    /** Status of the key-in run */
    runStatus: boolean;
}
/** Properties of the [[KeyinBrowser]] component.
 * @beta
 */
export interface KeyinBrowserProps extends CommonProps {
    /** Function called after the key-in is executed */
    onExecute?: (args: KeyinBrowserExecuteArgs) => void;
    /** Function called on Escape or popup close */
    onCancel?: () => void;
}
/**
 * Component used to allow users to select, provide arguments, and execute a key-in.
 * @beta
 */
export declare class KeyinBrowser extends React.PureComponent<KeyinBrowserProps, KeyinBrowserState> {
    private _toolIdLabel;
    private _argsLabel;
    private _argsTip;
    private _executeLabel;
    private _suggestPlaceholder;
    private _toolIdKey;
    private _isMounted;
    /** @internal */
    constructor(props: any);
    /** @internal */
    componentDidMount(): void;
    /** @internal */
    componentWillUnmount(): void;
    private getArgsKey;
    private getSavedToolId;
    private getToolArgs;
    private getToolKeyinMap;
    private getArgsArray;
    private _onClick;
    private _execute;
    private _outputMessage;
    private _onKeyinSelected;
    private _onArgumentsChange;
    private _onKeyDown;
    private _onInputFocus;
    private _onAutoSuggestEnter;
    private _onAutoSuggestTab;
    private _processInputValue;
    private _onAutoSuggestEscape;
    /** Calculate suggestions for any given input value. */
    private _getSuggestions;
    /** @internal */
    render(): React.ReactNode;
}
export {};
//# sourceMappingURL=KeyinBrowser.d.ts.map