"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Notification
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ActivityMessage = void 0;
const React = require("react");
const ui_core_1 = require("@bentley/ui-core");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
const UiFramework_1 = require("../UiFramework");
const HollowIcon_1 = require("./HollowIcon");
const MessageLabel_1 = require("./MessageLabel");
/** Activity Message React component
 * @beta
 */
function ActivityMessage(props) {
    const messageDetails = props.activityMessageInfo.details;
    const [percentCompleteLabel] = React.useState(UiFramework_1.UiFramework.translate("activityCenter.percentComplete"));
    const [cancelLabel] = React.useState(ui_core_1.UiCore.translate("dialog.cancel"));
    return (React.createElement(ui_ninezone_1.Message, { status: ui_ninezone_1.Status.Information, icon: React.createElement(HollowIcon_1.HollowIcon, { iconSpec: "icon-info-hollow" }) },
        React.createElement(ui_ninezone_1.MessageLayout, { buttons: (messageDetails && messageDetails.supportsCancellation) ?
                React.createElement("div", null,
                    React.createElement(ui_ninezone_1.MessageHyperlink, { onClick: props.cancelActivityMessage }, cancelLabel),
                    React.createElement("span", null, "\u00A0"),
                    React.createElement(ui_ninezone_1.MessageButton, { onClick: props.dismissActivityMessage },
                        React.createElement(ui_core_1.Icon, { iconSpec: "icon-close" })))
                :
                    React.createElement(ui_ninezone_1.MessageButton, { onClick: props.dismissActivityMessage },
                        React.createElement(ui_core_1.Icon, { iconSpec: "icon-close" })), progress: (messageDetails && messageDetails.showProgressBar) &&
                React.createElement(ui_ninezone_1.MessageProgress, { status: ui_ninezone_1.Status.Information, progress: props.activityMessageInfo.percentage }) },
            React.createElement("div", null,
                React.createElement(MessageLabel_1.MessageLabel, { message: props.activityMessageInfo.message, className: "uifw-statusbar-message-brief" }),
                (messageDetails && messageDetails.showPercentInMessage) &&
                    React.createElement(ui_core_1.SmallText, null, props.activityMessageInfo.percentage + percentCompleteLabel)))));
}
exports.ActivityMessage = ActivityMessage;
//# sourceMappingURL=ActivityMessage.js.map