"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Notification
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ActivityMessagePopup = void 0;
require("./ActivityMessagePopup.scss");
const React = require("react");
const classnames = require("classnames");
const MessageManager_1 = require("../messages/MessageManager");
const ActivityMessage_1 = require("./ActivityMessage");
/** Activity Message Popup React component
 * @beta
 */
function ActivityMessagePopup(props) {
    const [activityMessageInfo, setActivityMessageInfo] = React.useState(undefined);
    const [isActivityMessageVisible, setIsActivityMessageVisible] = React.useState(false);
    React.useEffect(() => {
        const handleActivityMessageUpdatedEvent = (args) => {
            setActivityMessageInfo(args);
            if (args.restored)
                setIsActivityMessageVisible(true);
        };
        return MessageManager_1.MessageManager.onActivityMessageUpdatedEvent.addListener(handleActivityMessageUpdatedEvent);
    }, [isActivityMessageVisible]);
    React.useEffect(() => {
        const handleActivityMessageCancelledEvent = () => {
            setActivityMessageInfo(undefined);
            setIsActivityMessageVisible(false);
        };
        return MessageManager_1.MessageManager.onActivityMessageCancelledEvent.addListener(handleActivityMessageCancelledEvent);
    }, []);
    const cancelActivityMessage = React.useCallback(() => {
        MessageManager_1.MessageManager.endActivityMessage(false);
        props.cancelActivityMessage && props.cancelActivityMessage();
    }, [props]);
    const dismissActivityMessage = React.useCallback(() => {
        setIsActivityMessageVisible(false);
        props.dismissActivityMessage && props.dismissActivityMessage();
    }, [props]);
    if (!activityMessageInfo || !isActivityMessageVisible)
        return null;
    return (React.createElement("div", { className: classnames("uifw-centered-popup", props.className), style: props.style },
        React.createElement(ActivityMessage_1.ActivityMessage, { activityMessageInfo: activityMessageInfo, cancelActivityMessage: cancelActivityMessage, dismissActivityMessage: dismissActivityMessage })));
}
exports.ActivityMessagePopup = ActivityMessagePopup;
//# sourceMappingURL=ActivityMessagePopup.js.map