"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Notification
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.InputFieldMessage = void 0;
require("./InputField.scss");
const classnames = require("classnames");
const React = require("react");
const imodeljs_frontend_1 = require("@bentley/imodeljs-frontend");
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const MessageManager_1 = require("../messages/MessageManager");
const MessageSpan_1 = require("./MessageSpan");
/** InputField message pops up near pointer when attempting an invalid interaction.
 * @public
 */
class InputFieldMessage extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {
            message: "",
            isVisible: false,
            priority: imodeljs_frontend_1.OutputMessagePriority.None,
            showCloseButton: !!this.props.showCloseButton,
        };
        this._onInputMessageClose = () => {
            this.setState({ isVisible: false });
        };
        this._handleInputFieldMessageAddedEvent = (args) => {
            this.setState({
                inputFieldElement: args.target,
                message: args.messageText,
                isVisible: true,
                priority: args.priority,
                detailedMessage: args.detailedMessage,
            });
        };
        this._handleInputFieldMessageRemovedEvent = () => {
            this.setState({ isVisible: false });
        };
    }
    render() {
        const { isVisible, inputFieldElement, message, priority, detailedMessage, showCloseButton } = this.state;
        if (!inputFieldElement || !message) {
            return null;
        }
        let iconClassName = "";
        switch (priority) {
            case imodeljs_frontend_1.OutputMessagePriority.Warning:
                iconClassName = "icon-status-warning";
                break;
            case imodeljs_frontend_1.OutputMessagePriority.Error:
                iconClassName = "icon-status-error";
                break;
            case imodeljs_frontend_1.OutputMessagePriority.Info:
                iconClassName = "icon-info";
                break;
        }
        return (React.createElement(ui_core_1.Popup, { isOpen: isVisible, position: ui_abstract_1.RelativePosition.BottomLeft, onClose: this._onInputMessageClose, target: inputFieldElement },
            React.createElement("div", { className: "uifw-popup-message-inputField" },
                React.createElement("div", { className: "uifw-popup-message-inputField-content" },
                    React.createElement("div", { className: "uifw-popup-message-inputField-primary" },
                        iconClassName &&
                            React.createElement("span", { className: "uifw-popup-message-icon" },
                                " ",
                                React.createElement("i", { className: classnames("icon", iconClassName) }),
                                " "),
                        React.createElement("span", { className: "uifw-popup-message-text" },
                            React.createElement(MessageSpan_1.MessageDiv, { className: "uifw-popup-message-brief", message: message }),
                            detailedMessage &&
                                React.createElement(MessageSpan_1.MessageDiv, { className: "uifw-popup-message-detailed", message: detailedMessage })))),
                showCloseButton &&
                    // eslint-disable-next-line jsx-a11y/click-events-have-key-events
                    React.createElement("div", { className: "uifw-popup-message-close", onClick: this._onInputMessageClose, role: "button", tabIndex: -1 },
                        React.createElement("i", { className: "icon icon-close" })))));
    }
    componentDidMount() {
        MessageManager_1.MessageManager.onInputFieldMessageAddedEvent.addListener(this._handleInputFieldMessageAddedEvent);
        MessageManager_1.MessageManager.onInputFieldMessageRemovedEvent.addListener(this._handleInputFieldMessageRemovedEvent);
    }
    componentWillUnmount() {
        MessageManager_1.MessageManager.onInputFieldMessageAddedEvent.removeListener(this._handleInputFieldMessageAddedEvent);
        MessageManager_1.MessageManager.onInputFieldMessageRemovedEvent.removeListener(this._handleInputFieldMessageRemovedEvent);
    }
}
exports.InputFieldMessage = InputFieldMessage;
//# sourceMappingURL=InputField.js.map