"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Notification
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageRenderer = void 0;
require("./MessageRenderer.scss");
const React = require("react");
const classnames = require("classnames");
const MessageManager_1 = require("./MessageManager");
const StatusMessagesContainer_1 = require("./StatusMessagesContainer");
/** Message Popup React component that renders one or more Toast or Sticky messages and an Activity message
 * @beta
 */
function MessageRenderer(props) {
    const [messages, setMessages] = React.useState(MessageManager_1.MessageManager.activeMessageManager.messages);
    const [activityMessageInfo, setActivityMessageInfo] = React.useState(undefined);
    const [isActivityMessageVisible, setIsActivityMessageVisible] = React.useState(false);
    React.useEffect(() => {
        const handleMessageAddedEvent = (_args) => {
            setMessages(MessageManager_1.MessageManager.activeMessageManager.messages);
        };
        return MessageManager_1.MessageManager.onMessageAddedEvent.addListener(handleMessageAddedEvent);
    }, []);
    React.useEffect(() => {
        /** Respond to clearing the message list */
        const handleMessagesUpdatedEvent = () => {
            setMessages(MessageManager_1.MessageManager.activeMessageManager.messages);
        };
        return MessageManager_1.MessageManager.onMessagesUpdatedEvent.addListener(handleMessagesUpdatedEvent);
    }, []);
    React.useEffect(() => {
        const handleActivityMessageUpdatedEvent = (args) => {
            setActivityMessageInfo(args);
            if (args.restored)
                setIsActivityMessageVisible(true);
        };
        return MessageManager_1.MessageManager.onActivityMessageUpdatedEvent.addListener(handleActivityMessageUpdatedEvent);
    }, [isActivityMessageVisible]);
    React.useEffect(() => {
        const handleActivityMessageCancelledEvent = () => {
            setActivityMessageInfo(undefined);
            setIsActivityMessageVisible(false);
        };
        return MessageManager_1.MessageManager.onActivityMessageCancelledEvent.addListener(handleActivityMessageCancelledEvent);
    }, []);
    const closeMessage = React.useCallback((id) => {
        MessageManager_1.MessageManager.activeMessageManager.remove(id);
        MessageManager_1.MessageManager.updateMessages();
        props.closeMessage && props.closeMessage(id);
    }, [props]);
    const cancelActivityMessage = React.useCallback(() => {
        MessageManager_1.MessageManager.endActivityMessage(false);
        props.cancelActivityMessage && props.cancelActivityMessage();
    }, [props]);
    const dismissActivityMessage = React.useCallback(() => {
        setIsActivityMessageVisible(false);
        props.dismissActivityMessage && props.dismissActivityMessage();
    }, [props]);
    if (!(activityMessageInfo && isActivityMessageVisible) && messages.length === 0)
        return null;
    return (React.createElement("div", { className: classnames("uifw-message-renderer", props.className), style: props.style },
        React.createElement(StatusMessagesContainer_1.StatusMessagesContainer, { messages: messages, activityMessageInfo: activityMessageInfo, isActivityMessageVisible: isActivityMessageVisible, toastTarget: null, closeMessage: closeMessage, cancelActivityMessage: cancelActivityMessage, dismissActivityMessage: dismissActivityMessage })));
}
exports.MessageRenderer = MessageRenderer;
//# sourceMappingURL=MessageRenderer.js.map