"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Notification
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.StickyMessage = void 0;
require("./StickyMessage.scss");
const React = require("react");
const classnames = require("classnames");
const ui_core_1 = require("@bentley/ui-core");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
const StatusBar_1 = require("../statusbar/StatusBar");
const MessageLabel_1 = require("./MessageLabel");
const HollowIcon_1 = require("./HollowIcon");
/** Sticky Message React component
 * @beta
 */
function StickyMessage(props) {
    const { id, messageDetails, severity, closeMessage } = props;
    const [closing, setClosing] = React.useState(false);
    const handleClose = () => {
        setClosing(true);
        setTimeout(() => closeMessage(id), 500);
    };
    const classNames = classnames("uifw-statusbar-sticky-message", closing && "uifw-closing");
    return (React.createElement("div", { className: classNames },
        React.createElement(ui_ninezone_1.Message, { status: StatusBar_1.StatusBar.severityToStatus(severity), icon: React.createElement(HollowIcon_1.HollowIcon, { iconSpec: ui_core_1.MessageContainer.getIconClassName(severity, true) }) },
            React.createElement(ui_ninezone_1.MessageLayout, { buttons: React.createElement(ui_ninezone_1.MessageButton, { onClick: handleClose, className: "uifw-statusbar-sticky-close" },
                    React.createElement(ui_core_1.Icon, { iconSpec: "icon-close" })) },
                React.createElement(MessageLabel_1.MessageLabel, { message: messageDetails.briefMessage, className: "uifw-statusbar-message-brief" }),
                messageDetails.detailedMessage &&
                    React.createElement(MessageLabel_1.MessageLabel, { message: messageDetails.detailedMessage, className: "uifw-statusbar-message-detailed" })))));
}
exports.StickyMessage = StickyMessage;
//# sourceMappingURL=StickyMessage.js.map