"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Notification
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ToastMessage = void 0;
const React = require("react");
const ui_core_1 = require("@bentley/ui-core");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
const StatusBar_1 = require("../statusbar/StatusBar");
const HollowIcon_1 = require("./HollowIcon");
const MessageLabel_1 = require("./MessageLabel");
/** Toast Message React component
 * @beta
 */
function ToastMessage(props) {
    const { id, messageDetails, severity, toastTarget, closeMessage } = props;
    return (React.createElement(ui_ninezone_1.Toast, { animateOutTo: toastTarget, onAnimatedOut: () => closeMessage(id), timeout: messageDetails.displayTime.milliseconds, content: React.createElement(ui_ninezone_1.Message, { status: StatusBar_1.StatusBar.severityToStatus(severity), icon: React.createElement(HollowIcon_1.HollowIcon, { iconSpec: ui_core_1.MessageContainer.getIconClassName(severity, true) }) },
            React.createElement(ui_ninezone_1.MessageLayout, null,
                React.createElement(MessageLabel_1.MessageLabel, { message: messageDetails.briefMessage, className: "uifw-statusbar-message-brief" }),
                messageDetails.detailedMessage &&
                    React.createElement(MessageLabel_1.MessageLabel, { message: messageDetails.detailedMessage, className: "uifw-statusbar-message-detailed" }))) }));
}
exports.ToastMessage = ToastMessage;
//# sourceMappingURL=ToastMessage.js.map