/** @packageDocumentation
 * @module NavigationAids
 */
import "./SheetNavigationAid.scss";
import * as React from "react";
import { IModelConnection } from "@bentley/imodeljs-frontend";
import { CommonProps } from "@bentley/ui-core";
import { ConfigurableCreateInfo } from "../configurableui/ConfigurableUiControl";
import { NavigationAidControl } from "./NavigationAidControl";
/** A Sheet Navigation Aid control.
 * @alpha
 */
export declare class SheetNavigationAidControl extends NavigationAidControl {
    static navigationAidId: string;
    constructor(info: ConfigurableCreateInfo, options: any);
    getSize(): string | undefined;
}
/** Data displayed about sheet
 * @alpha
 */
export interface SheetData {
    name: string;
    viewId: string;
}
/** Properties for the [[SheetNavigationAid]] component
 * @alpha
 */
export interface SheetNavigationProps extends CommonProps {
    iModelConnection: IModelConnection;
}
/** @internal */
interface SheetNavigationState {
    index: number;
    sheetData: SheetData[];
}
/** A Sheet Navigation Aid.
 * @alpha
 */
export declare class SheetNavigationAid extends React.Component<SheetNavigationProps, SheetNavigationState> {
    private _isMounted;
    /** @internal */
    readonly state: Readonly<SheetNavigationState>;
    private _viewport;
    constructor(props: SheetNavigationProps);
    /** Adds listeners when components mounts */
    componentDidMount(): Promise<void>;
    /** Removes listeners when component will unmount */
    componentWillUnmount(): void;
    /** Queries for sheet info and sets as sheetData */
    private _setupSheets;
    /** @internal */
    render(): React.ReactNode;
    /** Sets index of newly selected card */
    private _handleCardSelected;
    /** Updates view to the next lowest index in sheetData */
    private _handleOnClickLeftArrow;
    /** Updates view to next highest index in sheetData */
    private _handleOnClickRightArrow;
    /** Handles a Viewport change & synchs the index */
    private _handleSelectedViewportChanged;
    private _handleViewIdChanged;
    /** Handles a Viewport change & synchs the index */
    private _handleViewportChanged;
    /** Updates view to currently set sheet */
    private _updateView;
    /** Creates a new SheetsModalFrontstage */
    private modalFrontstage;
    /** Opens a new SheetsModelFrontstage on sheetName click */
    private _handleOnClickSheetName;
}
export {};
//# sourceMappingURL=SheetNavigationAid.d.ts.map