"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module OIDC
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.SignOutModalFrontstage = void 0;
require("./SignOut.scss");
const React = require("react");
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
const frontend_authorization_client_1 = require("@bentley/frontend-authorization-client");
const imodeljs_frontend_1 = require("@bentley/imodeljs-frontend");
const ui_core_1 = require("@bentley/ui-core");
const FrontstageManager_1 = require("../frontstage/FrontstageManager");
const UiFramework_1 = require("../UiFramework");
// cSpell:Ignore userprofile signoutprompt
/** Modal frontstage displaying sign out form.
 * @public
 */
class SignOutModalFrontstage {
    constructor(userInfo) {
        this.title = UiFramework_1.UiFramework.translate("userProfile.userprofile");
        this._signOut = UiFramework_1.UiFramework.translate("userProfile.signout");
        this._signOutPrompt = UiFramework_1.UiFramework.translate("userProfile.signoutprompt");
        this._userInfo = undefined;
        this._onSignOut = async () => {
            FrontstageManager_1.FrontstageManager.closeModalFrontstage();
            const authorizationClient = imodeljs_frontend_1.IModelApp.authorizationClient;
            // istanbul ignore next
            if (frontend_authorization_client_1.isFrontendAuthorizationClient(authorizationClient))
                await authorizationClient.signOut(new bentleyjs_core_1.ClientRequestContext());
            else
                bentleyjs_core_1.Logger.logError(UiFramework_1.UiFramework.loggerCategory(this), "IModelApp.authorizationClient must be set for signOut");
        };
        this._userInfo = userInfo;
    }
    _getInitials() {
        let initials = "";
        // istanbul ignore else
        if (this._userInfo && this._userInfo.profile) {
            // istanbul ignore else
            if (this._userInfo.profile.firstName.length > 0)
                initials += this._userInfo.profile.firstName[0];
            // istanbul ignore else
            if (this._userInfo.profile.lastName.length > 0)
                initials += this._userInfo.profile.lastName[0];
        }
        return initials;
    }
    _getFullName() {
        let name = "";
        // istanbul ignore else
        if (this._userInfo && this._userInfo.profile) {
            name = `${this._userInfo.profile.firstName} ${this._userInfo.profile.lastName}`;
        }
        return name;
    }
    get content() {
        const initials = this._getInitials();
        const fullName = this._getFullName();
        const email = (this._userInfo && this._userInfo.email && typeof this._userInfo.email.id === "string") ? this._userInfo.email.id : /* istanbul ignore next */ "";
        const organization = (this._userInfo && this._userInfo.organization) ? this._userInfo.organization.name : /* istanbul ignore next */ "";
        const color = ui_core_1.getUserColor(email);
        return (React.createElement("div", { className: "uifw-user-profile" },
            React.createElement("div", { className: "profile-info" },
                React.createElement("span", { className: "circle", style: { backgroundColor: color } }, initials),
                React.createElement("span", null, fullName),
                React.createElement("span", null, email),
                React.createElement("span", null, organization)),
            React.createElement("div", { className: "user-profile-separator" }),
            React.createElement("div", { className: "signout" },
                React.createElement("span", null, this._signOut),
                React.createElement("span", null, this._signOutPrompt),
                React.createElement("button", { onClick: this._onSignOut }, this._signOut))));
    }
}
exports.SignOutModalFrontstage = SignOutModalFrontstage;
//# sourceMappingURL=SignOut.js.map