"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Picker
 */
var __asyncValues = (this && this.__asyncValues) || function (o) {
    if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
    var m = o[Symbol.asyncIterator], i;
    return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
    function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
    function settle(resolve, reject, d, v) { Promise.resolve(v).then(function(v) { resolve({ value: v, done: d }); }, reject); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModelSelectorWidget = exports.ModelSelectorWidgetControl = void 0;
require("./ModelSelector.scss");
const classnames = require("classnames");
const React = require("react");
const imodeljs_frontend_1 = require("@bentley/imodeljs-frontend");
const presentation_frontend_1 = require("@bentley/presentation-frontend");
const ui_core_1 = require("@bentley/ui-core");
const ConfigurableUiManager_1 = require("../../configurableui/ConfigurableUiManager");
const UiFramework_1 = require("../../UiFramework");
const WidgetControl_1 = require("../../widgets/WidgetControl");
const ListPicker_1 = require("../ListPicker");
const ModelSelectorDefinitions_1 = require("./ModelSelectorDefinitions");
const ModelSelectorTree_1 = require("./ModelSelectorTree");
/**
 * Model Selector [[WidgetControl]]
 * @internal
 */
// istanbul ignore next
class ModelSelectorWidgetControl extends WidgetControl_1.WidgetControl {
    /** Creates a ModelSelectorDemoWidget */
    constructor(info, options) {
        super(info, options);
        this.reactNode = (
        // eslint-disable-next-line deprecation/deprecation
        React.createElement(ModelSelectorWidget, { iModelConnection: options.iModelConnection }));
    }
}
exports.ModelSelectorWidgetControl = ModelSelectorWidgetControl;
/**
 * Widget that manages category and model visibility via [[CategoryModelTree]]
 * @internal
 * @deprecated - Use [[VisibilityTree]] instead
 */
// istanbul ignore next
class ModelSelectorWidget extends React.Component {
    /** Creates a ModelSelectorWidget */
    constructor(props) {
        super(props);
        this._groups = [];
        this._isMounted = false;
        /** Initializes category/model groups and contents */
        this._initGroups = () => {
            this._groups.push(this._getDefaultModelGroup());
            this._groups.push(this._getDefaultCategoryGroup());
        };
        /** Initializes state to default values */
        this._initState = () => {
            this.state = {
                activeView: (this.props.activeView ||
                    imodeljs_frontend_1.IModelApp.viewManager.getFirstOpenView()),
            };
        };
        /** Initialize models */
        this._initModelState = async () => {
            const ruleset = await presentation_frontend_1.Presentation.presentation
                .rulesets()
                .add(require("../../../../rulesets/Models.json")); // eslint-disable-line @typescript-eslint/no-var-requires
            this._modelRuleset = ruleset;
            await this._setViewType(ruleset);
            this._updateModelsWithViewport(this.state.activeView); // eslint-disable-line @typescript-eslint/no-floating-promises
        };
        /** Initialize categories */
        this._initCategoryState = async () => {
            const ruleset = await presentation_frontend_1.Presentation.presentation
                .rulesets()
                .add(require("../../../../rulesets/Categories.json")); // eslint-disable-line @typescript-eslint/no-var-requires
            this._categoryRuleset = ruleset;
            await this._setViewType(ruleset);
            this._updateCategoriesWithViewport(this.state.activeView); // eslint-disable-line @typescript-eslint/no-floating-promises
        };
        /**
         * Sets provided ruleset as new ruleset for tree.
         * @param ruleset Ruleset to provide to tree.
         */
        this._setViewType = async (ruleset) => {
            if (!imodeljs_frontend_1.IModelApp.viewManager || !this.state.activeView)
                return;
            const view = this.state.activeView.view;
            const viewType = view.is3d() ? "3d" : "2d";
            await presentation_frontend_1.Presentation.presentation
                .vars(ruleset.id)
                .setString("ViewType", viewType); // eslint-disable-line @typescript-eslint/no-floating-promises
        };
        /**
         * Creates initial model group
         * @returns Initialized model group
         */
        this._getDefaultModelGroup = () => {
            return {
                id: ModelSelectorDefinitions_1.Groups.Models,
                // eslint-disable-next-line @typescript-eslint/no-unnecessary-type-assertion -- false positive
                ruleset: this._modelRuleset,
                dataProvider: new ModelSelectorDefinitions_1.ModelSelectorDataProvider(this.props.iModelConnection, 
                // eslint-disable-next-line @typescript-eslint/no-unnecessary-type-assertion -- false positive
                this._modelRuleset.id),
                label: UiFramework_1.UiFramework.translate("categoriesModels.models"),
                items: [],
                setEnabled: this._onModelsChecked,
            };
        };
        /** Modify viewport to display checked models */
        this._onModelsChecked = (items, checked) => {
            if (!imodeljs_frontend_1.IModelApp.viewManager)
                return;
            for (const vp of imodeljs_frontend_1.IModelApp.viewManager) {
                if (!(vp.view instanceof imodeljs_frontend_1.SpatialViewState))
                    continue;
                const modelIds = items.map((item) => {
                    item.enabled = checked;
                    return item.key;
                });
                if (checked) {
                    vp.addViewedModels(modelIds); // eslint-disable-line @typescript-eslint/no-floating-promises
                }
                else {
                    vp.changeModelDisplay(modelIds, checked);
                }
            }
        };
        /**
         * Creates initial category group
         * @returns Initialized category group
         */
        this._getDefaultCategoryGroup = () => {
            return {
                id: ModelSelectorDefinitions_1.Groups.Categories,
                // eslint-disable-next-line @typescript-eslint/no-unnecessary-type-assertion -- false positive
                ruleset: this._categoryRuleset,
                dataProvider: new ModelSelectorDefinitions_1.ModelSelectorDataProvider(this.props.iModelConnection, 
                // eslint-disable-next-line @typescript-eslint/no-unnecessary-type-assertion -- false positive
                this._categoryRuleset.id),
                label: UiFramework_1.UiFramework.translate("categoriesModels.categories"),
                items: [],
                setEnabled: this._onCategoriesChecked,
            };
        };
        /** Modify viewport to display checked categories */
        this._onCategoriesChecked = (items, checked) => {
            if (!imodeljs_frontend_1.IModelApp.viewManager || !imodeljs_frontend_1.IModelApp.viewManager.selectedView)
                return;
            const keys = [];
            items.forEach((item) => {
                item.enabled = checked;
                keys.push(item.key);
            });
            const updateViewport = (vp) => {
                // Only act on viewports that are both 3D or both 2D. Important if we have multiple viewports opened and we
                // are using 'allViewports' property
                if (imodeljs_frontend_1.IModelApp.viewManager.selectedView &&
                    imodeljs_frontend_1.IModelApp.viewManager.selectedView.view.is3d() === vp.view.is3d()) {
                    vp.changeCategoryDisplay(keys, checked);
                }
            };
            // This property let us act on all viewports or just on the selected one, configurable by the app
            if (this.props.allViewports) {
                for (const viewport of imodeljs_frontend_1.IModelApp.viewManager) {
                    updateViewport(viewport);
                }
            }
            else if (imodeljs_frontend_1.IModelApp.viewManager.selectedView) {
                updateViewport(imodeljs_frontend_1.IModelApp.viewManager.selectedView);
            }
            // this._updateCategoriesWithViewport(IModelApp.viewManager.selectedView); // eslint-disable-line @typescript-eslint/no-floating-promises
        };
        this._getGroupTabs = () => {
            const activeClassName = classnames(this.state.activeGroup.label && "active");
            return (React.createElement("div", null,
                React.createElement("ul", { className: "uifw-category-model-horizontal-tabs", role: "tablist" }, this._groups.map((group) => (
                // eslint-disable-next-line jsx-a11y/click-events-have-key-events
                React.createElement("li", { key: group.id, className: group.label === this.state.activeGroup.label
                        ? activeClassName
                        : "", onClick: this._onExpand.bind(this, group), role: "tab" },
                    React.createElement("a", null, group.label)))))));
        };
        this._onExpand = async (group) => {
            if (this._isMounted)
                this.setState({ activeGroup: group });
        };
        this._getTabContent = () => {
            return (React.createElement(ModelSelectorTree_1.CategoryModelTree // eslint-disable-line deprecation/deprecation
            , { key: this.state.activeGroup.id, iModelConnection: this.props.iModelConnection, activeGroup: this.state.activeGroup, activeView: this.state.activeView }));
        };
        this._initState();
    }
    /** @internal */
    async componentDidMount() {
        this._isMounted = true;
        await this.initialize();
    }
    /** @internal */
    componentWillUnmount() {
        this._isMounted = false;
    }
    async initialize() {
        await this._initModelState();
        await this._initCategoryState();
        this._initGroups();
        // istanbul ignore else
        if (this._isMounted)
            this.setState({
                activeGroup: this._groups[0],
                activeRuleset: this._modelRuleset,
            });
    }
    async _updateModelsWithViewport(vp) {
        // Query models and add them to state
        if (!vp || !(vp.view instanceof imodeljs_frontend_1.SpatialViewState))
            return;
        const modelQueryParams = {
            from: imodeljs_frontend_1.SpatialModelState.classFullName,
            wantPrivate: false,
        };
        let curModelProps = new Array();
        if (this.props.iModelConnection)
            curModelProps = await this.props.iModelConnection.models.queryProps(modelQueryParams);
        const models = [];
        for (const modelProps of curModelProps) {
            const model = {
                key: modelProps.id ? modelProps.id.toString() : "",
                name: modelProps.name ? modelProps.name : "",
                enabled: modelProps.id
                    ? vp.view.modelSelector.has(modelProps.id)
                    : false,
                type: ListPicker_1.ListItemType.Item,
            };
            models.push(model);
        }
        this._groups[0].items = models;
        this.forceUpdate();
    }
    async _updateCategoriesWithViewport(vp) {
        var e_1, _a;
        if (!vp)
            return;
        // Query categories and add them to state
        const selectUsedSpatialCategoryIds = "SELECT DISTINCT Category.Id as id from BisCore.GeometricElement3d WHERE Category.Id IN (SELECT ECInstanceId from BisCore.SpatialCategory)";
        const selectUsedDrawingCategoryIds = "SELECT DISTINCT Category.Id as id from BisCore.GeometricElement2d WHERE Model.Id=? AND Category.Id IN (SELECT ECInstanceId from BisCore.DrawingCategory)";
        const ecsql = vp.view.is3d()
            ? selectUsedSpatialCategoryIds
            : selectUsedDrawingCategoryIds;
        const ecsql2 = 
        // eslint-disable-next-line prefer-template
        "SELECT ECInstanceId as id, UserLabel as label, CodeValue as code FROM " +
            (vp.view.is3d() ? "BisCore.SpatialCategory" : "BisCore.DrawingCategory") +
            " WHERE ECInstanceId IN (" +
            ecsql +
            ")";
        const rows = [];
        if (this.props.iModelConnection) {
            const rowIterator = this.props.iModelConnection.query(ecsql2);
            try {
                for (var rowIterator_1 = __asyncValues(rowIterator), rowIterator_1_1; rowIterator_1_1 = await rowIterator_1.next(), !rowIterator_1_1.done;) {
                    const row = rowIterator_1_1.value;
                    rows.push(row);
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (rowIterator_1_1 && !rowIterator_1_1.done && (_a = rowIterator_1.return)) await _a.call(rowIterator_1);
                }
                finally { if (e_1) throw e_1.error; }
            }
        }
        const categories = [];
        for (const row of rows) {
            const category = {
                key: row.id,
                enabled: vp.view.categorySelector.has(row.id),
                type: ListPicker_1.ListItemType.Item,
            };
            categories.push(category);
        }
        this._groups[1].items = categories;
        this.forceUpdate();
    }
    /** @internal */
    render() {
        return (React.createElement("div", { className: "uifw-widget-picker", "data-testid": "model-selector-widget" },
            !this.state.activeRuleset && (React.createElement(ui_core_1.LoadingSpinner, { size: ui_core_1.SpinnerSize.Medium })),
            this.state.activeRuleset && (React.createElement(React.Fragment, null,
                this._getGroupTabs(),
                this._getTabContent()))));
    }
}
exports.ModelSelectorWidget = ModelSelectorWidget;
ConfigurableUiManager_1.ConfigurableUiManager.registerControl("ModelSelectorWidget", ModelSelectorWidgetControl);
//# sourceMappingURL=ModelSelector.js.map