"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Picker
 */
var __asyncValues = (this && this.__asyncValues) || function (o) {
    if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
    var m = o[Symbol.asyncIterator], i;
    return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
    function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
    function settle(resolve, reject, d, v) { Promise.resolve(v).then(function(v) { resolve({ value: v, done: d }); }, reject); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CategoryModelTree = void 0;
const classnames = require("classnames");
const React = require("react");
const imodeljs_frontend_1 = require("@bentley/imodeljs-frontend");
const presentation_common_1 = require("@bentley/presentation-common");
const presentation_components_1 = require("@bentley/presentation-components");
const ui_components_1 = require("@bentley/ui-components");
const ui_core_1 = require("@bentley/ui-core");
const UiFramework_1 = require("../../UiFramework");
const ListPicker_1 = require("../ListPicker");
const ModelSelectorDefinitions_1 = require("./ModelSelectorDefinitions");
/**
 * Tree which displays and manages models or categories contained in an iModel.
 * @internal @deprecated
 */
// istanbul ignore next
class CategoryModelTree extends React.Component {
    constructor(props) {
        super(props);
        this._optionsElement = null;
        this._allNodeIds = [];
        this._isMounted = false;
        this._searchLabel = ui_core_1.UiCore.translate("general.search");
        this._closeLabel = ui_core_1.UiCore.translate("dialog.close");
        this._onViewedModelsChanged = () => {
            this._resetCheckBoxState();
        };
        this._onViewedCategoriesChanged = () => {
            this._resetCheckBoxState();
        };
        this._onCloseContextMenu = () => {
            this.setState({ isOptionsOpened: false });
        };
        this._initState();
    }
    _initState() {
        this.state = {
            activeGroup: this.props.activeGroup,
            checkboxInfo: this.createCheckBoxInfoCallback(),
            isLoading: false,
            isOptionsOpened: false,
            filterInfo: {},
            showSearchBox: false,
        };
    }
    /** @internal */
    componentDidMount() {
        this._isMounted = true;
        if (this.props.activeView) {
            this.props.activeView.onViewedModelsChanged.addListener(this._onViewedModelsChanged);
            this.props.activeView.onViewedCategoriesChanged.addListener(this._onViewedCategoriesChanged);
        }
    }
    /** @internal */
    componentDidUpdate(prevProps, _prevState) {
        if (prevProps.activeView) {
            prevProps.activeView.onViewedModelsChanged.removeListener(this._onViewedModelsChanged);
            prevProps.activeView.onViewedCategoriesChanged.removeListener(this._onViewedCategoriesChanged);
        }
        if (this.props.activeView) {
            this.props.activeView.onViewedModelsChanged.addListener(this._onViewedModelsChanged);
            this.props.activeView.onViewedCategoriesChanged.addListener(this._onViewedCategoriesChanged);
        }
    }
    /** @internal */
    componentWillUnmount() {
        this._isMounted = false;
    }
    createCheckBoxInfoCallback() {
        const combine = (status) => (Object.assign({ isVisible: true }, status));
        return (node) => {
            const status = this.getNodeCheckBoxInfo(node);
            if (ui_core_1.isPromiseLike(status))
                return status.then(combine);
            return combine(status);
        };
    }
    getNodeCheckBoxInfo(node) {
        const key = this.state.activeGroup.dataProvider.getNodeKey(node);
        const nodeId = presentation_common_1.NodeKey.isInstancesNodeKey(key) ? key.instanceKeys[0].id : "";
        const item = this._getItem(nodeId);
        if (item && this.props.activeView) {
            const view = this.props.activeView.view;
            let state = ui_core_1.CheckBoxState.Off;
            const group = this.state.activeGroup.id;
            if ((group === ModelSelectorDefinitions_1.Groups.Models && view.modelSelector.models.has(item.key)) ||
                (group === ModelSelectorDefinitions_1.Groups.Categories &&
                    view.categorySelector.categories.has(item.key)))
                state = ui_core_1.CheckBoxState.On;
            return { isDisabled: false, isVisible: true, state };
        }
        return {};
    }
    async onCheckboxStateChange(stateChanges) {
        const nodesToEnable = [];
        const nodesToDisable = [];
        for (const { node, newState } of stateChanges) {
            if (newState === ui_core_1.CheckBoxState.On) {
                nodesToEnable.push(node);
            }
            else {
                nodesToDisable.push(node);
            }
        }
        if (nodesToEnable.length > 0) {
            this._manageNodesState(nodesToEnable, true); // eslint-disable-line @typescript-eslint/no-floating-promises
        }
        if (nodesToDisable.length > 0) {
            this._manageNodesState(nodesToDisable, false); // eslint-disable-line @typescript-eslint/no-floating-promises
        }
    }
    // eslint-disable-next-line @typescript-eslint/naming-convention
    renderNodeCheckbox(props) {
        return (React.createElement(ui_core_1.ImageCheckBox, { checked: props.checked, disabled: props.disabled, imageOn: "icon-visibility", imageOff: "icon-visibility-hide-2", onClick: props.onChange, tooltip: UiFramework_1.UiFramework.translate(props.checked ? "modelTree.status.visible" : "modelTree.status.hidden") }));
    }
    /**
     * Enable or disable all items and nodes
     * @param enable Specifies if items and nodes should be enabled or disabled
     */
    async _onSetEnableAll(enable) {
        this.setState({ isLoading: true });
        this._onCloseContextMenu();
        if (this._allNodeIds.length === 0)
            this._allNodeIds = await this._fetchAllNodeIds();
        this._setItemStates(this._allNodeIds, enable); // eslint-disable-line @typescript-eslint/no-floating-promises
        if (this._isMounted)
            this.setState({
                isLoading: false,
                checkboxInfo: this.createCheckBoxInfoCallback(),
            });
    }
    async _fetchAllNodeIds() {
        if (this.state.activeGroup.id === ModelSelectorDefinitions_1.Groups.Models) {
            const nodeIds = await this._fetchAllModelNodeIds();
            return nodeIds;
        }
        if (this.state.activeGroup.id === ModelSelectorDefinitions_1.Groups.Categories) {
            const nodeIds = await this._fetchAllCategoryNodeIds();
            return nodeIds;
        }
        return [];
    }
    async _fetchAllModelNodeIds() {
        const modelQueryParams = {
            from: imodeljs_frontend_1.SpatialModelState.classFullName,
            wantPrivate: false,
        };
        let curModelProps = new Array();
        if (this.props.iModelConnection)
            curModelProps = await this.props.iModelConnection.models.queryProps(modelQueryParams);
        const ids = [];
        for (const modelProps of curModelProps) {
            ids.push(modelProps.id ? modelProps.id.toString() : "");
        }
        return ids;
    }
    async _fetchAllCategoryNodeIds() {
        var e_1, _a;
        if (!this.props.activeView)
            return [];
        const view = this.props.activeView.view;
        const selectUsedSpatialCategoryIds = "SELECT DISTINCT Category.Id as id from BisCore.GeometricElement3d WHERE Category.Id IN (SELECT ECInstanceId from BisCore.SpatialCategory)";
        const selectUsedDrawingCategoryIds = "SELECT DISTINCT Category.Id as id from BisCore.GeometricElement2d WHERE Model.Id=? AND Category.Id IN (SELECT ECInstanceId from BisCore.DrawingCategory)";
        const ecsql = view.is3d()
            ? selectUsedSpatialCategoryIds
            : selectUsedDrawingCategoryIds;
        const ecsql2 = 
        // eslint-disable-next-line prefer-template
        "SELECT ECInstanceId as id, UserLabel as label, CodeValue as code FROM " +
            (view.is3d() ? "BisCore.SpatialCategory" : "BisCore.DrawingCategory") +
            " WHERE ECInstanceId IN (" +
            ecsql +
            ")";
        const ids = [];
        if (this.props.iModelConnection) {
            const rowIterator = this.props.iModelConnection.query(ecsql2);
            try {
                for (var rowIterator_1 = __asyncValues(rowIterator), rowIterator_1_1; rowIterator_1_1 = await rowIterator_1.next(), !rowIterator_1_1.done;) {
                    const row = rowIterator_1_1.value;
                    ids.push(row.id);
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (rowIterator_1_1 && !rowIterator_1_1.done && (_a = rowIterator_1.return)) await _a.call(rowIterator_1);
                }
                finally { if (e_1) throw e_1.error; }
            }
        }
        return ids;
    }
    /** Invert display on all items and state of all nodes */
    async _onInvertAll() {
        this.setState({ isLoading: true });
        this._onCloseContextMenu();
        this._invertEnableOnAllItems();
        if (this._isMounted)
            this.setState({
                isLoading: false,
                checkboxInfo: this.createCheckBoxInfoCallback(),
            });
    }
    /** Invert display on all items */
    _invertEnableOnAllItems() {
        const enabledItems = [];
        const disabledItems = [];
        for (const item of this.state.activeGroup.items) {
            item.enabled = !item.enabled;
            item.enabled ? enabledItems.push(item) : disabledItems.push(item);
        }
        this.state.activeGroup.setEnabled(enabledItems, true);
        this.state.activeGroup.setEnabled(disabledItems, false);
    }
    /** @internal */
    render() {
        const listClassName = classnames("uifw-modelselector", "show");
        return (React.createElement("div", { className: listClassName },
            this._getToolbar(),
            React.createElement("div", { className: "modelselector-content" }, this.state.isLoading ? this._getSpinner() : this._getTree())));
    }
    _getToolbar() {
        return (React.createElement("div", { className: "modelselector-toolbar" },
            this.state.showSearchBox && (React.createElement(ui_components_1.FilteringInput, { filteringInProgress: (this.state.filterInfo && this.state.filterInfo.filtering) ||
                    false, onFilterCancel: this._onFilterCancel.bind(this), onFilterClear: this._onFilterClear.bind(this), onFilterStart: this._onFilterStart.bind(this), resultSelectorProps: {
                    onSelectedChanged: this._onSelectedMatchChanged,
                    resultCount: (this.state.filterInfo && this.state.filterInfo.matchesCount) ||
                        0,
                } })),
            React.createElement("div", { className: "option-group" },
                !this.state.showSearchBox ?
                    // eslint-disable-next-line jsx-a11y/click-events-have-key-events
                    React.createElement("span", { className: "icon icon-search", onClick: this._onToggleSearchBox.bind(this), role: "button", tabIndex: -1, title: this._searchLabel }) :
                    // eslint-disable-next-line jsx-a11y/click-events-have-key-events
                    React.createElement("span", { className: "icon icon-close", onClick: this._onToggleSearchBox.bind(this), role: "button", tabIndex: -1, title: this._closeLabel }),
                React.createElement("span", { className: "options icon icon-more-2", title: UiFramework_1.UiFramework.translate("categoriesModels.options"), onClick: this._onShowOptions.bind(this), ref: (element) => {
                        this._optionsElement = element;
                    }, role: "button", tabIndex: -1 }),
                React.createElement(ui_core_1.GlobalContextMenu, { opened: this.state.isOptionsOpened, x: this._getOptionsX(), y: this._getOptionsY(), onOutsideClick: this._onCloseContextMenu },
                    React.createElement(ui_core_1.ContextMenuItem, { key: 0, icon: "icon-visibility", onClick: this._onSetEnableAll.bind(this, true) }, UiFramework_1.UiFramework.translate("pickerButtons.showAll")),
                    React.createElement(ui_core_1.ContextMenuItem, { key: 1, icon: "icon-visibility-hide-2", onClick: this._onSetEnableAll.bind(this, false) }, UiFramework_1.UiFramework.translate("pickerButtons.hideAll")),
                    React.createElement(ui_core_1.ContextMenuItem, { key: 2, icon: "icon-visibility-invert", onClick: this._onInvertAll.bind(this) }, UiFramework_1.UiFramework.translate("pickerButtons.invert"))))));
    }
    _getOptionsX() {
        if (!this._optionsElement)
            return 0;
        const rect = this._optionsElement.getBoundingClientRect();
        return rect.right;
    }
    _getOptionsY() {
        if (!this._optionsElement)
            return 0;
        const rect = this._optionsElement.getBoundingClientRect();
        return rect.bottom;
    }
    _onToggleSearchBox() {
        this._onFilterClear();
        this.setState((prevState) => ({
            showSearchBox: !prevState.showSearchBox,
            filterInfo: Object.assign(Object.assign({}, prevState.filterInfo), { filter: "", filtering: false }),
        }));
    }
    _onFilterCancel() {
        if (!this.state.filterInfo)
            return;
        this.setState((prevState) => ({
            filterInfo: Object.assign(Object.assign({}, prevState.filterInfo), { filter: "", filtering: false }),
        }));
    }
    _onFilterClear() {
        if (!this.state.filterInfo)
            return;
        this.setState((prevState) => ({
            filterInfo: Object.assign(Object.assign({}, prevState.filterInfo), { filter: "", filtering: false }),
        }));
    }
    _onFilterStart(filter) {
        if (!this.state.filterInfo)
            return;
        this.setState((prevState) => ({
            filterInfo: Object.assign(Object.assign({}, prevState.filterInfo), { filter, filtering: true }),
        }));
    }
    _onSelectedMatchChanged(index) {
        if (this.state.filterInfo && index !== this.state.filterInfo.matchesCount) {
            this.setState((prevState) => ({
                filterInfo: Object.assign(Object.assign({}, prevState.filterInfo), { activeMatchIndex: index }),
            }));
        }
    }
    // eslint-disable-next-line @typescript-eslint/naming-convention
    async onFilterApplied(_filter) {
        if (this.state.filterInfo && this.state.filterInfo.filtering) {
            this.setState((prevState) => ({
                filterInfo: Object.assign(Object.assign({}, prevState.filterInfo), { filtering: false }),
            }));
        }
    }
    _onMatchesCounted(count) {
        if (this.state.filterInfo && count !== this.state.filterInfo.matchesCount) {
            this.setState((prevState) => ({
                filterInfo: Object.assign(Object.assign({}, prevState.filterInfo), { matchesCount: count }),
            }));
        }
    }
    _onShowOptions(event) {
        event.stopPropagation();
        this.setState((prevState) => ({
            isOptionsOpened: !prevState.isOptionsOpened,
        }));
    }
    _getSpinner() {
        return React.createElement(ui_core_1.LoadingSpinner, { size: ui_core_1.SpinnerSize.Large });
    }
    _getTree() {
        return (React.createElement(CategoryModelFilterTree, { dataProvider: this.state.activeGroup.dataProvider, filter: this.state.filterInfo ? this.state.filterInfo.filter : "", onFilterApplied: async (filter) => this.onFilterApplied(filter), onMatchesCounted: (count) => this._onMatchesCounted(count), activeMatchIndex: this.state.filterInfo ? this.state.filterInfo.activeMatchIndex : 0, selectionMode: ui_components_1.SelectionMode.SingleAllowDeselect, onNodeExpanded: async (node) => this._onNodeExpanded(node), showDescriptions: true, checkboxInfo: this.state.checkboxInfo, onCheckboxClick: async (stateChange) => this.onCheckboxStateChange(stateChange), showIcons: true, renderOverrides: {
                renderCheckbox: this.renderNodeCheckbox,
            }, pageSize: 5 }));
    }
    // Nodes only expand if active group is "Categories"
    async _onNodeExpanded(node) {
        var e_2, _a;
        const categories = this.state.activeGroup.items;
        const key = this.state.activeGroup.dataProvider.getNodeKey(node);
        const nodeId = presentation_common_1.NodeKey.isInstancesNodeKey(key) ? key.instanceKeys[0].id : "";
        const ecsql = `SELECT ECInstanceId as id FROM BisCore.SubCategory WHERE Parent.Id=${nodeId}`;
        const rows = [];
        if (this.props.iModelConnection) {
            const rowIterator = this.props.iModelConnection.query(ecsql);
            try {
                for (var rowIterator_2 = __asyncValues(rowIterator), rowIterator_2_1; rowIterator_2_1 = await rowIterator_2.next(), !rowIterator_2_1.done;) {
                    const row = rowIterator_2_1.value;
                    rows.push(row);
                }
            }
            catch (e_2_1) { e_2 = { error: e_2_1 }; }
            finally {
                try {
                    if (rowIterator_2_1 && !rowIterator_2_1.done && (_a = rowIterator_2.return)) await _a.call(rowIterator_2);
                }
                finally { if (e_2) throw e_2.error; }
            }
        }
        for (const row of rows) {
            const existingItem = categories.find((category) => {
                return row.id === category.key;
            });
            if (!existingItem) {
                const category = {
                    key: row.id,
                    enabled: this.props.activeView
                        ? this.props.activeView.view.categorySelector.has(row.id)
                        : false,
                    type: ListPicker_1.ListItemType.Item,
                };
                categories.push(category);
            }
        }
        this.setState((prevState) => ({
            activeGroup: Object.assign(Object.assign({}, prevState.activeGroup), { items: categories }),
            checkboxInfo: this.createCheckBoxInfoCallback(),
        }));
    }
    async _manageNodesState(nodes, enable) {
        const nodeIds = this._getNodeIds(nodes);
        await this._setItemStates(nodeIds, enable);
        if (this._isMounted)
            this.setState({
                checkboxInfo: this.createCheckBoxInfoCallback(),
            });
    }
    _getNodeIds(nodes) {
        const nodeIds = [];
        nodes.forEach((node) => {
            const key = this.state.activeGroup.dataProvider.getNodeKey(node);
            const id = presentation_common_1.NodeKey.isInstancesNodeKey(key) ? key.instanceKeys[0].id : "";
            nodeIds.push(id);
        });
        return nodeIds;
    }
    /**
     * Set item and node state after input change
     * @param treeItemIds Ids of items to set state on
     * @param enable Flag to enable or disable item, determined by checkBoxState if not specified
     */
    async _setItemStates(treeItemIds, enable) {
        this._setEnableItems(treeItemIds, enable);
        if (this.state.activeGroup.id === ModelSelectorDefinitions_1.Groups.Categories)
            treeItemIds.forEach((treeItemId) => {
                this._setEnableChildren(treeItemId, enable); // eslint-disable-line @typescript-eslint/no-floating-promises
            });
    }
    /**
     * Set display flag on an item based on toggled node.
     * @param treeNodeIds  Ids of Nodes related to toggled display item.
     */
    _setEnableItems(treeNodeIds, enable) {
        treeNodeIds.forEach((treeNodeId) => {
            const item = this._getItem(treeNodeId);
            item.enabled = enable;
            this.state.activeGroup.setEnabled([item], enable);
        });
        if (this._isMounted)
            this.setState({
                checkboxInfo: this.createCheckBoxInfoCallback(),
            });
    }
    /**
     * Find an item specified by a node based on shared key.
     * @param treeNodeId Tree node ID to match.
     * @returns Specified item from list. Defaults to first item if none found.
     */
    _getItem(treeNodeId) {
        const items = this.state.activeGroup.items;
        for (const item of items) {
            if (treeNodeId === item.key) {
                return item;
            }
        }
        return items[0];
    }
    async _setEnableChildren(nodeId, enable) {
        const childNodeIds = await this._fetchChildNodes(nodeId);
        this._setEnableItems(childNodeIds, enable);
    }
    async _fetchChildNodes(nodeId) {
        var e_3, _a;
        const ecsql = `SELECT ECInstanceId as id FROM BisCore.SubCategory WHERE Parent.Id=${nodeId}`;
        const childIds = [];
        if (this.props.iModelConnection) {
            const rowIterator = this.props.iModelConnection.query(ecsql);
            try {
                for (var rowIterator_3 = __asyncValues(rowIterator), rowIterator_3_1; rowIterator_3_1 = await rowIterator_3.next(), !rowIterator_3_1.done;) {
                    const row = rowIterator_3_1.value;
                    childIds.push(row.id);
                }
            }
            catch (e_3_1) { e_3 = { error: e_3_1 }; }
            finally {
                try {
                    if (rowIterator_3_1 && !rowIterator_3_1.done && (_a = rowIterator_3.return)) await _a.call(rowIterator_3);
                }
                finally { if (e_3) throw e_3.error; }
            }
        }
        return childIds;
    }
    _resetCheckBoxState() {
        if (this._isMounted)
            this.setState({
                checkboxInfo: this.createCheckBoxInfoCallback(),
            });
    }
}
exports.CategoryModelTree = CategoryModelTree;
/**
 * Tree component with support for filtering
 * @internal
 */
const CategoryModelFilterTree = presentation_components_1.DEPRECATED_treeWithFilteringSupport(ui_components_1.DEPRECATED_Tree); // eslint-disable-line @typescript-eslint/naming-convention, deprecation/deprecation
//# sourceMappingURL=ModelSelectorTree.js.map