"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Popup
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Card = exports.CardPopup = void 0;
require("./CardPopup.scss");
const React = require("react");
const classnames = require("classnames");
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const CursorPopup_1 = require("../cursor/cursorpopup/CursorPopup");
const PopupManager_1 = require("./PopupManager");
const PositionPopup_1 = require("./PositionPopup");
const MessageSpan_1 = require("../messages/MessageSpan");
const ui_components_1 = require("@bentley/ui-components");
/** Popup component for Input Editor
 * @alpha
 */
class CardPopup extends React.PureComponent {
    constructor() {
        super(...arguments);
        /** @internal */
        this.state = {
            size: new ui_core_1.Size(-1, -1),
        };
        this._onSizeKnown = (newSize) => {
            // istanbul ignore else
            if (!this.state.size.equals(newSize))
                this.setState({ size: ui_core_1.Size.create(newSize) });
        };
        this._handleKeyDown = (event) => {
            switch (event.key) {
                case ui_abstract_1.SpecialKey.Escape:
                    this._cancel();
                    break;
            }
        };
    }
    _cancel() {
        // istanbul ignore else
        if (this.props.onCancel) {
            this.props.onCancel();
        }
    }
    render() {
        let point = PopupManager_1.PopupManager.getPopupPosition(this.props.el, this.props.pt, new ui_core_1.Point(), this.state.size);
        const popupRect = CursorPopup_1.CursorPopup.getPopupRect(point, this.props.offset, this.state.size, this.props.relativePosition);
        point = new ui_core_1.Point(popupRect.left, popupRect.top);
        return (React.createElement(PositionPopup_1.PositionPopup, { key: this.props.id, className: classnames("uifw-no-border", "uifw-card"), point: point, onSizeKnown: this._onSizeKnown },
            React.createElement(ui_core_1.DivWithOutsideClick, { onOutsideClick: this.props.onCancel, onKeyDown: this._handleKeyDown },
                React.createElement(ui_core_1.FocusTrap, { active: true, returnFocusOnDeactivate: true },
                    React.createElement(Card, { content: this.props.content, title: this.props.title, items: this.props.items, onItemExecuted: this.props.onItemExecuted })))));
    }
}
exports.CardPopup = CardPopup;
/** @alpha */
function Card(props) {
    let titleNode;
    // istanbul ignore else
    if (props.title) {
        if (typeof props.title === "string")
            titleNode = React.createElement(ui_core_1.LeadingText, null, props.title);
        else {
            const propertyValueRendererManager = ui_components_1.PropertyValueRendererManager.defaultManager;
            const titleValue = propertyValueRendererManager.render(props.title);
            titleNode = React.createElement(ui_core_1.LeadingText, null, titleValue);
        }
    }
    const content = PopupManager_1.isReactContent(props.content) ? props.content.reactNode : React.createElement(MessageSpan_1.MessageDiv, { message: props.content });
    return (React.createElement(React.Fragment, null,
        React.createElement("div", { className: "uifw-card-content" },
            props.title &&
                React.createElement(React.Fragment, null,
                    titleNode,
                    React.createElement("div", { className: "uifw-card-gap" })),
            content),
        props.items &&
            React.createElement(React.Fragment, null,
                React.createElement("div", { className: "uifw-card-separator" }),
                React.createElement(ui_components_1.ToolbarWithOverflow, { expandsTo: ui_components_1.Direction.Bottom, panelAlignment: ui_components_1.ToolbarPanelAlignment.Start, items: props.items, useDragInteraction: true, toolbarOpacitySetting: ui_components_1.ToolbarOpacitySetting.Transparent, onItemExecuted: props.onItemExecuted }))));
}
exports.Card = Card;
//# sourceMappingURL=CardPopup.js.map