"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Popup
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeyinPalettePopup = void 0;
const React = require("react");
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const PositionPopup_1 = require("./PositionPopup");
const KeyinPalettePanel_1 = require("./KeyinPalettePanel");
/** Keyin Palette Popup Component
 * @alpha
 */
function KeyinPalettePopup({ el, id, keyins, onCancel, onItemExecuted }) {
    const [popupSize, setPopupSize] = React.useState(new ui_core_1.Size(-1, -1));
    const onSizeKnown = React.useCallback((newSize) => {
        // istanbul ignore else
        if (!popupSize.equals(newSize))
            setPopupSize(ui_core_1.Size.create(newSize));
    }, [popupSize]);
    const cancel = React.useCallback(() => {
        onCancel && onCancel();
    }, [onCancel]);
    const handleKeyDown = React.useCallback((event) => {
        switch (event.key) {
            case ui_abstract_1.SpecialKey.Escape:
                cancel();
                event.preventDefault();
                break;
        }
    }, [cancel]);
    const xMid = el.getBoundingClientRect().left + el.getBoundingClientRect().width / 2;
    let point = new ui_core_1.Point(xMid, el.getBoundingClientRect().top);
    // istanbul ignore next
    if (popupSize.width > 0)
        point = point.offsetX(popupSize.width / (-2));
    return (React.createElement(PositionPopup_1.PositionPopup, { key: id, className: "uifw-command-palette-popup-container", point: point, onSizeKnown: onSizeKnown },
        React.createElement(ui_core_1.DivWithOutsideClick, { onOutsideClick: onCancel, onKeyDown: handleKeyDown },
            React.createElement(ui_core_1.FocusTrap, { active: true, returnFocusOnDeactivate: true },
                React.createElement(KeyinPalettePanel_1.KeyinPalettePanel, { keyins: keyins, onKeyinExecuted: onItemExecuted })))));
}
exports.KeyinPalettePopup = KeyinPalettePopup;
//# sourceMappingURL=KeyinPalettePopup.js.map