"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Popup
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ToolbarPopup = void 0;
const React = require("react");
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const ui_components_1 = require("@bentley/ui-components");
const CursorPopup_1 = require("../cursor/cursorpopup/CursorPopup");
const PopupManager_1 = require("./PopupManager");
const PositionPopup_1 = require("./PositionPopup");
/** Popup component for Input Editor
 * @alpha
 */
class ToolbarPopup extends React.PureComponent {
    constructor() {
        super(...arguments);
        /** @internal */
        this.state = {
            size: new ui_core_1.Size(-1, -1),
        };
        this._onSizeKnown = (newSize) => {
            // istanbul ignore else
            if (!this.state.size.equals(newSize))
                this.setState({ size: ui_core_1.Size.create(newSize) });
        };
        this._handleKeyDown = (event) => {
            switch (event.key) {
                case ui_abstract_1.SpecialKey.Escape:
                    this._cancel();
                    break;
            }
        };
    }
    _cancel() {
        // istanbul ignore else
        if (this.props.onCancel) {
            this.props.onCancel();
        }
    }
    render() {
        let point = PopupManager_1.PopupManager.getPopupPosition(this.props.el, this.props.pt, new ui_core_1.Point(), this.state.size);
        const popupRect = CursorPopup_1.CursorPopup.getPopupRect(point, this.props.offset, this.state.size, this.props.relativePosition);
        point = new ui_core_1.Point(popupRect.left, popupRect.top);
        return (React.createElement(PositionPopup_1.PositionPopup, { key: this.props.id, className: "uifw-no-border", point: point, onSizeKnown: this._onSizeKnown },
            React.createElement(ui_core_1.DivWithOutsideClick, { onOutsideClick: this.props.onCancel, onKeyDown: this._handleKeyDown },
                React.createElement(ui_core_1.FocusTrap, { active: true, returnFocusOnDeactivate: true },
                    React.createElement(ui_components_1.Toolbar, { expandsTo: ui_components_1.Direction.Bottom, panelAlignment: ui_components_1.ToolbarPanelAlignment.Start, items: this.props.items, useDragInteraction: true, toolbarOpacitySetting: ui_components_1.ToolbarOpacitySetting.Defaults, onItemExecuted: this.props.onItemExecuted })))));
    }
}
exports.ToolbarPopup = ToolbarPopup;
//# sourceMappingURL=ToolbarPopup.js.map