/** Function that will connect a component to the IModelConnection data in the Redux store.
 * @param mapStateToProps optional user function that, if defined, will be executed to provide additional properties from store.
 * @param mapDispatchToProps data passed to Redux connect function.
 * @public
 */
export declare const connectIModelConnection: (mapStateToProps?: any, mapDispatchToProps?: any) => import("react-redux").InferableComponentEnhancerWithProps<any, any>;
/** Function that will connect a component to the IModelConnection data in the Redux store
 * @param mapStateToProps optional user function that, if defined, will be executed to provide additional properties from store.
 * @param mapDispatchToProps data passed to Redux connect function.
 * @beta
 *
 * @example
 *   // connect component for both getting and setting ImodelConnection data from Redux store.
 *  import { connectIModelConnection, sessionStateMapDispatchToProps, SessionStateActionsProps } from "@bentley/ui-framework";
 *
 *  export interface ComponentProps extends SessionStateActionsProps {
 *    myData: string;
 *  }
 *
 *  export const ConnectControl = connectIModelConnection(null, sessionStateMapDispatchToProps)(ComponentClass); // eslint-disable-line @typescript-eslint/naming-convention
 *
 *  //  this then allows connected control to update the store using a call like shown below.
 *  this.props.setNumItemsSelected(30);
 *
 */
export declare const connectIModelConnectionAndViewState: (mapStateToProps?: any, mapDispatchToProps?: any) => import("react-redux").InferableComponentEnhancerWithProps<any, any>;
//# sourceMappingURL=connectIModel.d.ts.map