"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module State
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.withSafeArea = exports.SafeAreaContext = void 0;
const React = require("react");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
/**
 * Context used to manage safe area (feature used by devices with non-rectangular screens).
 * @public
 */
// eslint-disable-next-line @typescript-eslint/naming-convention
exports.SafeAreaContext = React.createContext(ui_ninezone_1.SafeAreaInsets.None);
/** HOC that injects SafeAreaInsets.
 * @public
 */
const withSafeArea = (
// eslint-disable-next-line @typescript-eslint/naming-convention
Component) => {
    return class WithSafeArea extends React.PureComponent {
        render() {
            const props = __rest(this.props, []);
            return (React.createElement(exports.SafeAreaContext.Consumer, null, (safeAreaInsets) => (React.createElement(Component, Object.assign({}, props, { safeAreaInsets: safeAreaInsets })))));
        }
    };
};
exports.withSafeArea = withSafeArea;
//# sourceMappingURL=SafeAreaContext.js.map