"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Item
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ActionButtonItemDef = void 0;
const React = require("react");
const ui_core_1 = require("@bentley/ui-core");
const ActionItemButton_1 = require("../toolbar/ActionItemButton");
const ItemDefBase_1 = require("./ItemDefBase");
/** Abstract base class that is used by classes to execute an action when pressed.
 * @public
 */
class ActionButtonItemDef extends ItemDefBase_1.ItemDefBase {
    constructor(itemProps, onItemExecuted) {
        super(itemProps);
        /** Called when the size of the action button is initialized and the size is known */
        this.handleSizeKnown = (size) => {
            this.size = size;
        };
        /** @internal */
        this.getKey = (index) => {
            const key = (!!this.id) ? this.id : (index !== undefined) ? index.toString() : ActionButtonItemDef.getRandomId();
            return key;
        };
        this.execute = this.execute.bind(this);
        this._onItemExecuted = onItemExecuted;
    }
    /** Called when the action button is invoked by a click or touch */
    execute() {
        if (this._commandHandler && this._commandHandler.execute) {
            if (this._commandHandler.getCommandArgs)
                this._commandHandler.execute(this._commandHandler.getCommandArgs());
            else
                this._commandHandler.execute(this._commandHandler.parameters);
        }
        // istanbul ignore else
        if (this._onItemExecuted)
            this._onItemExecuted(this);
    }
    /** Determines the dimension in a given orientation */
    getDimension(orientation) {
        let dimension = ActionButtonItemDef.defaultButtonSize;
        if (this.size)
            dimension = (orientation === ui_core_1.Orientation.Horizontal) ? this.size.width : this.size.height;
        return dimension;
    }
    /** @internal */
    static getRandomId() {
        return (Math.floor(Math.random() * 100) + 1000).toString();
    }
    /** @internal */
    toolbarReactNode(index) {
        if (!this.isVisible) // eslint-disable-line deprecation/deprecation
            return null;
        const key = this.getKey(index);
        return (React.createElement(ActionItemButton_1.ActionItemButton, { key: key, actionItem: this, onSizeKnown: this.handleSizeKnown }));
    }
}
exports.ActionButtonItemDef = ActionButtonItemDef;
/** The default button size for all action buttons */
ActionButtonItemDef.defaultButtonSize = 42;
//# sourceMappingURL=ActionButtonItemDef.js.map