"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Item
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.CustomItemDef = void 0;
const React = require("react");
const ui_abstract_1 = require("@bentley/ui-abstract");
const ActionButtonItemDef_1 = require("./ActionButtonItemDef");
/** An Item that renders a React component.
 * @public
 */
class CustomItemDef extends ActionButtonItemDef_1.ActionButtonItemDef {
    constructor(props) {
        super(props);
        if (props.customId)
            this.customId = props.customId;
        else {
            CustomItemDef._sId++;
            this.customId = CustomItemDef.customIdPrefix + CustomItemDef._sId;
        }
        this.reactElement = props.reactElement;
        this.popupPanelNode = props.popupPanelNode;
    }
    get id() {
        return this.customId;
    }
    toolbarReactNode(index) {
        if (!this.isVisible || ui_abstract_1.ConditionalBooleanValue.getValue(this.isHidden)) // eslint-disable-line deprecation/deprecation
            return null;
        let clone;
        // istanbul ignore else
        if (this.reactElement && React.isValidElement(this.reactElement)) {
            const key = this.getKey(index);
            const cloneProps = {
                key,
                onSizeKnown: this.handleSizeKnown,
            };
            clone = React.cloneElement(this.reactElement, cloneProps);
        }
        return clone;
    }
}
exports.CustomItemDef = CustomItemDef;
CustomItemDef._sId = 0;
CustomItemDef.customIdPrefix = "Custom-";
//# sourceMappingURL=CustomItemDef.js.map