"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Frontstage
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNestedStagePanelKey = exports.getStagePanelType = exports.StagePanel = void 0;
const React = require("react");
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
const FrontstageManager_1 = require("../frontstage/FrontstageManager");
const FrameworkStagePanel_1 = require("./FrameworkStagePanel");
const StagePanelDef_1 = require("./StagePanelDef");
/** Frontstage Panel React component.
 * @public
 */
class StagePanel extends React.Component {
    constructor(props) {
        var _a;
        super(props);
        this._handleRenderPane = (widgetDefId) => {
            const runtimeProps = this.props.runtimeProps;
            if (!runtimeProps)
                return null;
            const widgetDef = runtimeProps.panelDef.findWidgetDef(widgetDefId);
            if (!widgetDef || !widgetDef.isVisible)
                return null;
            return (React.createElement("div", { style: {
                    height: "100%",
                    display: runtimeProps.panel.isCollapsed ? "none" : "block",
                } }, widgetDef.reactNode));
        };
        this._handlePanelStateChangedEvent = ({ panelDef, panelState }) => {
            var _a;
            // istanbul ignore else
            if (panelDef !== ((_a = this.props.runtimeProps) === null || _a === void 0 ? void 0 : _a.panelDef))
                return;
            // istanbul ignore next
            this.setState({
                panelState,
            });
        };
        this._handleWidgetStateChangedEvent = ({ widgetDef }) => {
            const runtimeProps = this.props.runtimeProps;
            if (!runtimeProps)
                return;
            if (!runtimeProps.panelDef.findWidgetDef(widgetDef.id))
                return;
            this.setState({
                stagePanelWidgets: this._getVisibleStagePanelWidgets(),
            });
        };
        const panelState = (_a = this.props.runtimeProps) === null || _a === void 0 ? void 0 : _a.panelDef.panelState;
        this.state = {
            panelState: panelState === undefined ? StagePanelDef_1.StagePanelState.Open : panelState,
            stagePanelWidgets: this._getVisibleStagePanelWidgets(),
        };
    }
    static initializeStagePanelDef(panelDef, props, panelLocation) {
        panelDef.initializeFromProps(props, panelLocation);
    }
    componentDidMount() {
        FrontstageManager_1.FrontstageManager.onPanelStateChangedEvent.addListener(this._handlePanelStateChangedEvent);
        FrontstageManager_1.FrontstageManager.onWidgetStateChangedEvent.addListener(this._handleWidgetStateChangedEvent);
    }
    componentDidUpdate(prevProps) {
        var _a, _b;
        if (((_a = prevProps.runtimeProps) === null || _a === void 0 ? void 0 : _a.panelDef) !== ((_b = this.props.runtimeProps) === null || _b === void 0 ? void 0 : _b.panelDef)) {
            this.setState({
                stagePanelWidgets: this._getVisibleStagePanelWidgets(),
            });
        }
    }
    componentWillUnmount() {
        FrontstageManager_1.FrontstageManager.onPanelStateChangedEvent.removeListener(this._handlePanelStateChangedEvent);
        FrontstageManager_1.FrontstageManager.onWidgetStateChangedEvent.removeListener(this._handleWidgetStateChangedEvent);
    }
    render() {
        const _a = this.props, { applicationData, defaultState, runtimeProps, maxSize, size } = _a, props = __rest(_a, ["applicationData", "defaultState", "runtimeProps", "maxSize", "size"]); // eslint-disable-line @typescript-eslint/no-unused-vars
        if (!runtimeProps)
            return null;
        const { stagePanelChangeHandler, panelDef } = runtimeProps, otherRuntimeProps = __rest(runtimeProps, ["stagePanelChangeHandler", "panelDef"]);
        return (React.createElement(FrameworkStagePanel_1.FrameworkStagePanel, Object.assign({ changeHandler: stagePanelChangeHandler, initialSize: size, location: panelDef.location, renderPane: this._handleRenderPane, stagePanelWidgets: this.state.stagePanelWidgets, panelState: this.state.panelState, maxSize: typeof maxSize === "number" ? maxSize : undefined }, props, otherRuntimeProps)));
    }
    _getVisibleStagePanelWidgets() {
        var _a;
        const panelDef = (_a = this.props.runtimeProps) === null || _a === void 0 ? void 0 : _a.panelDef;
        if (!panelDef)
            return [];
        const visibleWidgets = panelDef.widgetDefs.filter((wd) => wd.isVisible);
        return visibleWidgets.map((widgetDef) => widgetDef.id);
    }
}
exports.StagePanel = StagePanel;
StagePanel.defaultProps = {
    resizable: true,
};
/** @internal */
const getStagePanelType = (location) => {
    switch (location) {
        case ui_abstract_1.StagePanelLocation.Bottom:
        case ui_abstract_1.StagePanelLocation.BottomMost:
            return ui_ninezone_1.StagePanelType.Bottom;
        case ui_abstract_1.StagePanelLocation.Left:
            return ui_ninezone_1.StagePanelType.Left;
        case ui_abstract_1.StagePanelLocation.Right:
            return ui_ninezone_1.StagePanelType.Right;
        case ui_abstract_1.StagePanelLocation.Top:
        case ui_abstract_1.StagePanelLocation.TopMost:
            return ui_ninezone_1.StagePanelType.Top;
    }
};
exports.getStagePanelType = getStagePanelType;
/** @internal */
const getNestedStagePanelKey = (location) => {
    switch (location) {
        case ui_abstract_1.StagePanelLocation.Bottom:
            return {
                id: "inner",
                type: ui_ninezone_1.StagePanelType.Bottom,
            };
        case ui_abstract_1.StagePanelLocation.BottomMost:
            return {
                id: "outer",
                type: ui_ninezone_1.StagePanelType.Bottom,
            };
        case ui_abstract_1.StagePanelLocation.Left:
            return {
                id: "inner",
                type: ui_ninezone_1.StagePanelType.Left,
            };
        case ui_abstract_1.StagePanelLocation.Right:
            return {
                id: "inner",
                type: ui_ninezone_1.StagePanelType.Right,
            };
        case ui_abstract_1.StagePanelLocation.Top:
            return {
                id: "inner",
                type: ui_ninezone_1.StagePanelType.Top,
            };
        case ui_abstract_1.StagePanelLocation.TopMost:
            return {
                id: "outer",
                type: ui_ninezone_1.StagePanelType.Top,
            };
    }
};
exports.getNestedStagePanelKey = getNestedStagePanelKey;
//# sourceMappingURL=StagePanel.js.map