"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Frontstage
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.StagePanelHeader = void 0;
require("./StagePanelHeader.scss");
const classnames = require("classnames");
const React = require("react");
const FrontstageManager_1 = require("../frontstage/FrontstageManager");
const StagePanelDef_1 = require("./StagePanelDef");
/** Stage panel header React component.
 * @alpha
 */
class StagePanelHeader extends React.PureComponent {
    constructor() {
        super(...arguments);
        this._handleCollapseButtonClick = () => {
            const activeFrontstageDef = FrontstageManager_1.FrontstageManager.activeFrontstageDef;
            // istanbul ignore if
            if (!activeFrontstageDef)
                return;
            const stagePanel = activeFrontstageDef.getStagePanelDef(this.props.location);
            // istanbul ignore if
            if (!stagePanel)
                return;
            stagePanel.panelState = StagePanelDef_1.StagePanelState.Minimized;
        };
    }
    render() {
        const className = classnames("uifw-stagepanelheader", this.props.className);
        return (React.createElement("div", { className: className, style: this.props.style },
            React.createElement("span", null, this.props.title),
            this.props.collapseButton ?
                // eslint-disable-next-line jsx-a11y/click-events-have-key-events
                React.createElement("i", { className: "uifw-collapse icon icon-close", title: this.props.collapseButtonTitle, onClick: this._handleCollapseButtonClick, role: "button", tabIndex: -1 }) :
                undefined));
    }
}
exports.StagePanelHeader = StagePanelHeader;
//# sourceMappingURL=StagePanelHeader.js.map