"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module StatusBar
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.StatusBarOverflow = void 0;
require("./Overflow.scss");
const classnames = require("classnames");
const React = require("react");
const ui_core_1 = require("@bentley/ui-core");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
const UiFramework_1 = require("../UiFramework");
/** Entry point to overflow status bar items of [[StatusBarComposer]] component.
 * @internal
 */
// eslint-disable-next-line react/display-name, @typescript-eslint/naming-convention
exports.StatusBarOverflow = React.memo(React.forwardRef(function StatusBarOverflow(props, ref) {
    const roRef = ui_core_1.useResizeObserver(props.onResize);
    const refs = ui_core_1.useRefs(roRef, ref);
    const className = classnames("uifw-statusbar-overflow", props.className);
    const title = React.useRef(UiFramework_1.UiFramework.translate("statusBar.overflow"));
    return (
    // eslint-disable-next-line jsx-a11y/click-events-have-key-events
    React.createElement("div", { className: className, onClick: props.onClick, ref: refs, style: props.style, role: "button", tabIndex: -1, title: title.current },
        React.createElement(ui_ninezone_1.Ellipsis, null)));
}));
//# sourceMappingURL=Overflow.js.map