"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module StatusBar
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.useUiItemsProviderStatusBarItems = void 0;
const React = require("react");
const ui_abstract_1 = require("@bentley/ui-abstract");
const useActiveStageId_1 = require("../hooks/useActiveStageId");
const useAvailableUiItemsProviders_1 = require("../hooks/useAvailableUiItemsProviders");
const FrontstageManager_1 = require("../frontstage/FrontstageManager");
// cspell:ignore setxxx
/** Hook that returns items from [[StatusBarItemsManager]].
 * @beta
 */
const useUiItemsProviderStatusBarItems = (manager) => {
    const uiItemProviderIds = useAvailableUiItemsProviders_1.useAvailableUiItemsProviders();
    const stageId = useActiveStageId_1.useActiveStageId();
    const [items, setItems] = React.useState(manager.items);
    const providersRef = React.useRef("");
    const currentStageRef = React.useRef("");
    // gathers items from registered extensions - dependent on when a UiItemsProvider is register or unregistered and if the
    // current stage's composer allows entries from extensions.
    React.useEffect(() => {
        const uiProviders = uiItemProviderIds.join("-");
        // istanbul ignore else
        if (providersRef.current !== uiProviders || currentStageRef.current !== stageId) {
            currentStageRef.current = stageId;
            const frontstageDef = FrontstageManager_1.FrontstageManager.findFrontstageDef(stageId);
            // istanbul ignore next
            const usage = (frontstageDef === null || frontstageDef === void 0 ? void 0 : frontstageDef.usage) ? frontstageDef.usage : ui_abstract_1.StageUsage.General;
            providersRef.current = uiProviders;
            const statusBarItems = ui_abstract_1.UiItemsManager.getStatusBarItems(stageId, usage);
            const updatedStatusBarItems = ui_abstract_1.UiItemsArbiter.updateStatusBarItems(statusBarItems);
            manager.loadItems(updatedStatusBarItems);
            setItems(manager.items);
        }
    }, [manager, uiItemProviderIds, stageId]);
    // handle item changes caused by calls to UiFramework.addonStatusBarItemsManager.setxxx
    React.useEffect(() => {
        const handleChanged = (args) => {
            setItems(args.items);
        };
        manager.onItemsChanged.addListener(handleChanged);
        return () => {
            manager.onItemsChanged.removeListener(handleChanged);
        };
    }, [manager]);
    return items;
};
exports.useUiItemsProviderStatusBarItems = useUiItemsProviderStatusBarItems;
//# sourceMappingURL=useUiItemsProviderStatusBarItems.js.map