/** @packageDocumentation
 * @module StatusBar
 */
import * as React from "react";
import { StatusFieldProps } from "./StatusFieldProps";
/**
 * Properties supported by [[ConditionalField]] component.
 * @public
 */
export interface ConditionalFieldProps extends StatusFieldProps {
    /** Function to be called to return a boolean value. If the boolean value is different than the component's state value setState is
     * called to update the value and trigger a re-render.
     */
    boolFunc: (props: StatusFieldProps) => boolean;
    /** Optional, default/initial boolean value that is saved in the components state. If
     * not defined it will default to true.
     */
    defaultValue?: boolean;
}
/**
 * State for the [[ConditionalField]] component.
 * @internal
 */
interface ConditionalFieldState {
    boolValue: boolean;
}
/**
 * A component that expects its children to be a function that will be passed the current component Props.
 * @public
 */
export declare class ConditionalField extends React.PureComponent<ConditionalFieldProps, ConditionalFieldState> {
    /** @internal */
    readonly state: ConditionalFieldState;
    constructor(props: ConditionalFieldProps);
    private _resolveBooleanValue;
    componentDidMount(): void;
    componentDidUpdate(prevProps: ConditionalFieldProps): void;
    private _hasNoChildren;
    render(): React.ReactNode;
}
export {};
//# sourceMappingURL=ConditionalField.d.ts.map