"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module StatusBar
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConditionalField = void 0;
const _ = require("lodash");
const React = require("react");
/**
 * A component that expects its children to be a function that will be passed the current component Props.
 * @public
 */
class ConditionalField extends React.PureComponent {
    constructor(props) {
        super(props);
        this._resolveBooleanValue = () => {
            const boolValue = this.props.boolFunc(this.props);
            if (this.state.boolValue !== boolValue) {
                this.setState({ boolValue });
            }
        };
        this._hasNoChildren = (children) => React.Children.count(children) === 0;
        this.state = {
            boolValue: undefined !== props.defaultValue ? props.defaultValue : true,
        };
    }
    componentDidMount() {
        this._resolveBooleanValue();
    }
    componentDidUpdate(prevProps) {
        if (!_.isEqual(prevProps, this.props))
            this._resolveBooleanValue();
    }
    render() {
        const _a = this.props, { 
        // do not bleed our props
        children, eventIds, boolFunc, defaultValue } = _a, // eslint-disable-line @typescript-eslint/no-unused-vars
        // eslint-disable-next-line comma-dangle
        otherProps = __rest(_a, ["children", "eventIds", "boolFunc", "defaultValue"]) // pass-through props
        ;
        const boolValue = this.state.boolValue;
        return (typeof children === "function" ?
            children(boolValue, otherProps)
            : !this._hasNoChildren(children)
                ? React.Children.only(children)
                : null);
    }
}
exports.ConditionalField = ConditionalField;
//# sourceMappingURL=ConditionalField.js.map