"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module StatusBar
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Indicator = void 0;
require("./Indicator.scss");
const classnames = require("classnames");
const React = require("react");
const ui_core_1 = require("@bentley/ui-core");
/** General-purpose [[Footer]] indicator. Shows an icon and supports an optional popup dialog.
 * @beta
 */
class Indicator extends React.Component {
    constructor(props) {
        super(props);
        this._handleOnIndicatorClick = () => {
            // istanbul ignore else
            if (this.props.onClick)
                this.props.onClick();
        };
    }
    render() {
        const className = classnames("uifw-footer-indicator", this.props.isInFooterMode && "nz-footer-mode", this.props.className);
        const iconClassNames = classnames("icon", "uifw-indicator-icon", this.props.iconName ? this.props.iconName : /* istanbul ignore next */ "icon-placeholder");
        return (React.createElement("div", { className: className, title: this.props.toolTip ? this.props.toolTip : this.props.label, style: this.props.style },
            React.createElement("div", { className: "nz-balloon-container", onClick: this._handleOnIndicatorClick, role: "presentation" },
                (this.props.iconName && !this.props.iconSpec) && React.createElement("div", { className: iconClassNames }),
                this.props.iconSpec && React.createElement("div", { className: "uifw-indicator-icon" },
                    " ",
                    React.createElement(ui_core_1.Icon, { iconSpec: this.props.iconSpec })),
                this.props.opened &&
                    React.createElement("div", { className: "nz-dialog" }, this.props.dialog))));
    }
}
exports.Indicator = Indicator;
//# sourceMappingURL=Indicator.js.map