"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module StatusBar
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.PromptField = void 0;
require("./PromptField.scss");
const classnames = require("classnames");
const React = require("react");
const react_redux_1 = require("react-redux");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
const UiFramework_1 = require("../UiFramework");
/**
 * Prompt Field React component. This component is designed to be specified in a status bar definition.
 * It is used to display prompts from tools. To send a prompt to this component use IModelApp.notifications.outputPromptByKey or
 * IModelApp.notifications.outputPrompt.
 */
class PromptFieldComponent extends React.Component {
    constructor(props) {
        super(props);
    }
    render() {
        return (React.createElement(ui_ninezone_1.FooterIndicator, { className: classnames("uifw-statusFields-promptField", this.props.className), style: this.props.style, isInFooterMode: this.props.isInFooterMode }, this.props.toolPrompt));
    }
}
/** Function used by Redux to map state data in Redux store to props that are used to render this component. */
function mapStateToProps(state) {
    const frameworkState = state[UiFramework_1.UiFramework.frameworkStateKey]; // since app sets up key, don't hard-code name
    /* istanbul ignore next */
    if (!frameworkState)
        return undefined;
    return { toolPrompt: frameworkState.configurableUiState.toolPrompt };
}
// we declare the variable and export that rather than using export default.
/**
 * Prompt Field React component. This component is designed to be specified in a status bar definition.
 * It is used to display prompts from tools. To send a prompt to this component use IModelApp.notifications.outputPromptByKey or
 * IModelApp.notifications.outputPrompt.
 * This React component is Redux connected.
 * @public
 * @deprecated Use ToolAssistanceField instead
 */ // eslint-disable-next-line @typescript-eslint/naming-convention
exports.PromptField = react_redux_1.connect(mapStateToProps)(PromptFieldComponent);
//# sourceMappingURL=PromptField.js.map