"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module StatusBar
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.SectionsStatusField = void 0;
require("./SectionsField.scss");
const classnames = require("classnames");
const React = require("react");
const imodeljs_frontend_1 = require("@bentley/imodeljs-frontend");
const ui_core_1 = require("@bentley/ui-core");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
const useActiveViewport_1 = require("../hooks/useActiveViewport");
const UiFramework_1 = require("../UiFramework");
const Indicator_1 = require("./Indicator");
/** Status Field for showing section extra tools for clearing and showing manipulators
 * @beta
 */
function SectionsStatusField(props) {
    const [toolTip] = React.useState(UiFramework_1.UiFramework.translate("tools.sectionTools"));
    const [clearLabel] = React.useState(UiFramework_1.UiFramework.translate("tools.sectionClear"));
    const [showHandlesLabel] = React.useState(UiFramework_1.UiFramework.translate("tools.sectionShowHandles"));
    const activeViewport = useActiveViewport_1.useActiveViewport();
    const [showIndicator, setShowIndicator] = React.useState(false);
    const [isPopupOpen, setPopupOpen] = React.useState(false);
    const targetDiv = React.useRef(null);
    const classes = (showIndicator) ? "uifw-indicator-fade-in" : "uifw-indicator-fade-out";
    const [hasManipulatorsShown, setHasManipulatorsShown] = React.useState(false);
    React.useEffect(() => {
        // istanbul ignore next
        const onClipChanged = (viewport, _eventType, _provider) => {
            if (viewport !== activeViewport)
                return;
            setHasManipulatorsShown(!!imodeljs_frontend_1.ViewClipDecoration.get(activeViewport));
            const isClipActive = !!activeViewport.view.getViewClip();
            setShowIndicator(isClipActive || !props.hideWhenUnused);
        };
        const clipActive = !!activeViewport && /* istanbul ignore next */ !!activeViewport.view.getViewClip();
        setShowIndicator(clipActive || !props.hideWhenUnused);
        setHasManipulatorsShown(clipActive && /* istanbul ignore next */ !!activeViewport && /* istanbul ignore next */ !!imodeljs_frontend_1.ViewClipDecoration.get(activeViewport));
        imodeljs_frontend_1.ViewClipDecorationProvider.create().onActiveClipChanged.addListener(onClipChanged);
        return () => {
            // Get or create static ViewClipDecorationProvider
            imodeljs_frontend_1.ViewClipDecorationProvider.create().onActiveClipChanged.removeListener(onClipChanged);
        };
    }, [activeViewport, props.hideWhenUnused, isPopupOpen]);
    // istanbul ignore next
    const toggleManipulators = (checked) => {
        if (activeViewport) {
            setHasManipulatorsShown(checked);
            imodeljs_frontend_1.ViewClipDecorationProvider.create().toggleDecoration(activeViewport);
        }
    };
    // istanbul ignore next
    const handleClear = () => {
        imodeljs_frontend_1.IModelApp.tools.run(imodeljs_frontend_1.ViewClipClearTool.toolId, imodeljs_frontend_1.ViewClipDecorationProvider.create());
        setPopupOpen(false);
    };
    return (React.createElement(React.Fragment, null,
        React.createElement("div", { ref: targetDiv, title: toolTip },
            React.createElement(Indicator_1.Indicator, { className: classes, iconName: "icon-section-tool", onClick: () => setPopupOpen(!isPopupOpen), opened: isPopupOpen, isInFooterMode: props.isInFooterMode })),
        React.createElement(ui_ninezone_1.FooterPopup, { target: targetDiv.current, onClose: () => setPopupOpen(false), isOpen: isPopupOpen },
            React.createElement(ui_ninezone_1.Dialog, { titleBar: React.createElement(ui_ninezone_1.TitleBar, { title: toolTip }) },
                React.createElement("div", { className: "uifw-sections-footer-contents" },
                    React.createElement(ui_core_1.Button, { buttonType: ui_core_1.ButtonType.Hollow, onClick: handleClear }, clearLabel),
                    React.createElement("div", { className: "uifw-uifw-sections-toggle-container" },
                        React.createElement("div", { className: classnames("uifw-sections-label") }, showHandlesLabel),
                        React.createElement(ui_core_1.Toggle, { className: "uifw-sections-toggle", onChange: toggleManipulators, isOn: hasManipulatorsShown, showCheckmark: false })))))));
}
exports.SectionsStatusField = SectionsStatusField;
//# sourceMappingURL=SectionsField.js.map