"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module StatusBar
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.SelectionInfoField = void 0;
require("./SelectionInfo.scss");
const classnames = require("classnames");
const React = require("react");
const react_redux_1 = require("react-redux");
const ui_core_1 = require("@bentley/ui-core");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
const UiFramework_1 = require("../UiFramework");
/**
 * Status Field React component. This component is designed to be specified in a status bar definition.
 * It is used to display the number of selected items based on the Presentation Rules Selection Manager.
 */
class SelectionInfoFieldComponent extends React.Component {
    constructor(props) {
        super(props);
    }
    render() {
        return (React.createElement(ui_ninezone_1.FooterIndicator, { className: classnames("uifw-statusFields-selectionInfo", this.props.className), style: this.props.style, isInFooterMode: this.props.isInFooterMode },
            React.createElement(ui_core_1.Icon, { iconSpec: "icon-cursor" }),
            this.props.selectionCount.toString()));
    }
}
/** Function used by Redux to map state data in Redux store to props that are used to render this component. */
function mapStateToProps(state) {
    const frameworkState = state[UiFramework_1.UiFramework.frameworkStateKey]; // since app sets up key, don't hard-code name
    /* istanbul ignore next */
    if (!frameworkState)
        return undefined;
    return { selectionCount: frameworkState.sessionState.numItemsSelected };
}
// we declare the variable and export that rather than using export default.
/**
 * SelectionInfo Status Field React component. This component is designed to be specified in a status bar definition.
 * It is used to display the number of selected items based on the Presentation Rules Selection Manager.
 * This React component is Redux connected.
 * @public
 */ // eslint-disable-next-line @typescript-eslint/naming-convention
exports.SelectionInfoField = react_redux_1.connect(mapStateToProps)(SelectionInfoFieldComponent);
//# sourceMappingURL=SelectionInfo.js.map