/** @packageDocumentation
 * @module StatusBar
 */
import "./SelectionScope.scss";
import * as React from "react";
import { PresentationSelectionScope } from "../redux/SessionState";
import { StatusFieldProps } from "./StatusFieldProps";
/** Defines properties supported by the SelectionScopeField Component.
 * @public
 */
interface SelectionScopeFieldProps extends StatusFieldProps {
    activeSelectionScope: string;
    availableSelectionScopes: PresentationSelectionScope[];
}
/**
 * Status Field React component. This component is designed to be specified in a status bar definition.
 * It is used to display the number of selected items based on the Presentation Rules Selection Manager.
 * The IModelApp should call either UiFramework.setIModelConnection or SyncUiEventDispatcher.initializeConnectionEvents
 * with the active iModelConnection each time a new iModel is opened so the selection scope data is properly updated
 * in the Redux state.
 * @public
 */
declare class SelectionScopeFieldComponent extends React.Component<SelectionScopeFieldProps> {
    private _label;
    private _toolTip;
    constructor(props: SelectionScopeFieldProps);
    private _updateSelectValue;
    render(): React.ReactNode;
}
/**
 * SelectionScopeField React component. This component is designed to be specified in a status bar definition. It will
 * display the active selection scope that is used by the PresentationManager to determine what elements are added to the selection nap mode.
 * This React component is Redux connected.
 * @public
 */ export declare const SelectionScopeField: import("react-redux").ConnectedComponent<typeof SelectionScopeFieldComponent, import("react-redux").Omit<React.ClassAttributes<SelectionScopeFieldComponent> & SelectionScopeFieldProps, "availableSelectionScopes" | "activeSelectionScope">>;
export {};
//# sourceMappingURL=SelectionScope.d.ts.map