"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module StatusBar
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.SelectionScopeField = void 0;
require("./SelectionScope.scss");
const classnames = require("classnames");
const React = require("react");
const react_redux_1 = require("react-redux");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
const UiFramework_1 = require("../UiFramework");
/**
 * Status Field React component. This component is designed to be specified in a status bar definition.
 * It is used to display the number of selected items based on the Presentation Rules Selection Manager.
 * The IModelApp should call either UiFramework.setIModelConnection or SyncUiEventDispatcher.initializeConnectionEvents
 * with the active iModelConnection each time a new iModel is opened so the selection scope data is properly updated
 * in the Redux state.
 * @public
 */
class SelectionScopeFieldComponent extends React.Component {
    constructor(props) {
        super(props);
        this._label = UiFramework_1.UiFramework.translate("selectionScopeField.label");
        this._toolTip = UiFramework_1.UiFramework.translate("selectionScopeField.toolTip");
        this._updateSelectValue = (e) => {
            // istanbul ignore else
            if (e.target.value) {
                UiFramework_1.UiFramework.setActiveSelectionScope(e.target.value);
            }
        };
    }
    render() {
        return (React.createElement(ui_ninezone_1.FooterIndicator, { className: classnames("uifw-statusFields-selectionScope", this.props.className), style: this.props.style, isInFooterMode: this.props.isInFooterMode },
            this.props.isInFooterMode &&
                React.createElement("label", { className: "uifw-statusFields-selectionScope-label", htmlFor: "components-selectionScope-selector" },
                    this._label,
                    ":"),
            React.createElement("select", { className: "uifw-statusFields-selectionScope-selector", value: this.props.activeSelectionScope, onChange: this._updateSelectValue, "data-testid": "components-selectionScope-selector", id: "components-selectionScope-selector", title: this._toolTip }, this.props.availableSelectionScopes && this.props.availableSelectionScopes.map((scope, index) => {
                return (React.createElement("option", { key: index, value: scope.id }, scope.label));
            }))));
    }
}
/** Function used by Redux to map state data in Redux store to props that are used to render this component. */
function mapStateToProps(state) {
    const frameworkState = state[UiFramework_1.UiFramework.frameworkStateKey]; // since app sets up key, don't hard-code name
    /* istanbul ignore next */
    if (!frameworkState)
        return undefined;
    return { activeSelectionScope: frameworkState.sessionState.activeSelectionScope, availableSelectionScopes: frameworkState.sessionState.availableSelectionScopes };
}
// we declare the variable and export that rather than using export default.
/**
 * SelectionScopeField React component. This component is designed to be specified in a status bar definition. It will
 * display the active selection scope that is used by the PresentationManager to determine what elements are added to the selection nap mode.
 * This React component is Redux connected.
 * @public
 */ // eslint-disable-next-line @typescript-eslint/naming-convention
exports.SelectionScopeField = react_redux_1.connect(mapStateToProps)(SelectionScopeFieldComponent);
//# sourceMappingURL=SelectionScope.js.map