"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module StatusBar
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TileLoadingIndicator = void 0;
require("./TileLoadingIndicator.scss");
const classnames = require("classnames");
const React = require("react");
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
const imodeljs_frontend_1 = require("@bentley/imodeljs-frontend");
const ui_core_1 = require("@bentley/ui-core");
const UiFramework_1 = require("../../UiFramework");
let onViewOpen;
let onRenderUpdate;
/** TileLoadingIndicator React component
 * @beta
 */
class TileLoadingIndicator extends React.PureComponent {
    constructor(props) {
        super(props);
        this.state = { label: "", progress: 0, enabled: false, finished: true };
    }
    _update(vp) {
        const requested = vp.numRequestedTiles;
        const ready = vp.numReadyTiles;
        const total = ready + requested;
        const pctComplete = (total > 0) ? (ready / total) * 100 : /* istanbul ignore next */ 100;
        let enabled = this.state.enabled;
        let finished = this.state.finished;
        // istanbul ignore else
        if (!enabled && total !== 0 && pctComplete !== 100)
            enabled = true;
        if (enabled && (total === 0 || pctComplete === 100))
            enabled = false;
        if (pctComplete === 100 && !finished) {
            finished = true;
            bentleyjs_core_1.Logger.logTrace(UiFramework_1.UiFramework.loggerCategory(this), `Tiles Finished Loading`);
            bentleyjs_core_1.Logger.logTrace(UiFramework_1.UiFramework.loggerCategory(this), `Tiles Load Report (tiles finished / tiles requested):  ${ready} / ${total}`);
        }
        // istanbul ignore else
        if (pctComplete !== 100 && finished)
            finished = false;
        this.setState({ label: `${ready} / ${total}`, progress: pctComplete, enabled, finished });
    }
    _onViewOpen(vp) {
        onRenderUpdate = () => this._update(vp);
        // istanbul ignore if
        if (this._removeOnRenderListener)
            this._removeOnRenderListener();
        this._removeOnRenderListener = vp.onRender.addListener(onRenderUpdate, this);
    }
    componentDidMount() {
        // istanbul ignore next
        if (!imodeljs_frontend_1.IModelApp.viewManager)
            return;
        // get selected viewport
        const vp = imodeljs_frontend_1.IModelApp.viewManager.selectedView;
        // if view exists bind update routine to onRender loop, otherwise do so once the onViewOpen event runs
        if (vp) {
            this._onViewOpen(vp);
        }
        else {
            // istanbul ignore next
            onViewOpen = (_vp) => this._onViewOpen(_vp);
            this._removeViewOpenListener = imodeljs_frontend_1.IModelApp.viewManager.onViewOpen.addListener(onViewOpen, this);
        }
    }
    componentWillUnmount() {
        // istanbul ignore next
        if (!imodeljs_frontend_1.IModelApp.viewManager)
            return;
        // istanbul ignore else
        if (this._removeViewOpenListener)
            this._removeViewOpenListener();
        // istanbul ignore else
        if (this._removeOnRenderListener)
            this._removeOnRenderListener();
    }
    /** Renders TileLoadingIndicator */
    render() {
        const classes = classnames("uifw-tile-loading-bar", this.state.enabled && "uifw-tile-loading-bar-visible", this.props.isInFooterMode && "nz-footer-mode", this.props.className);
        return (React.createElement("div", { className: classes, style: this.props.style },
            React.createElement("span", null, this.state.label),
            React.createElement(ui_core_1.LoadingBar, { percent: this.state.progress, barHeight: 5 })));
    }
}
exports.TileLoadingIndicator = TileLoadingIndicator;
//# sourceMappingURL=TileLoadingIndicator.js.map