/** @packageDocumentation
 * @module SyncUi
 */
import * as React from "react";
/**
 * Properties supported by [[BooleanSyncUiListener]] component.
 * @public
 */
export interface BooleanListenerProps {
    /** One or more SyncUi event Ids that will trigger the function to be called. */
    eventIds: string[];
    /** Function to be called to return a boolean value. If the boolean value is different than the component's state value setState is
     * called to update the value and trigger a re-render.
     */
    boolFunc: () => boolean;
    /** Optional, default/initial boolean value that is saved in the components state. If
     * not defined it will default to true.
     */
    defaultValue?: boolean;
}
/**
 * State for the [[BooleanSyncUiListener]] component.
 * @internal
 */
interface BooleanListenerState {
    boolValue: boolean;
}
/**
 * A component that expect its children to be a function that will be passed the current boolValue state.
 * @public
 */
export declare class BooleanSyncUiListener extends React.Component<BooleanListenerProps, BooleanListenerState> {
    private _componentUnmounting;
    /** @internal */
    readonly state: BooleanListenerState;
    constructor(props: BooleanListenerProps);
    private _handleVisibilitySyncUiEvent;
    componentDidMount(): void;
    componentWillUnmount(): void;
    private _hasNoChildren;
    render(): React.ReactNode;
}
export {};
//# sourceMappingURL=BooleanListener.d.ts.map