"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module SyncUi
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BooleanSyncUiListener = void 0;
const React = require("react");
const SyncUiEventDispatcher_1 = require("./SyncUiEventDispatcher");
// cSpell:Ignore Unmounting
/**
 * A component that expect its children to be a function that will be passed the current boolValue state.
 * @public
 */
class BooleanSyncUiListener extends React.Component {
    constructor(props) {
        super(props);
        this._componentUnmounting = false;
        this._handleVisibilitySyncUiEvent = (args) => {
            /* istanbul ignore next */
            if (this._componentUnmounting)
                return;
            /* istanbul ignore else */
            if (this.props.eventIds.some((value) => args.eventIds.has(value.toLowerCase()))) {
                const boolValue = this.props.boolFunc();
                /* istanbul ignore else */
                if (this.state.boolValue !== boolValue) {
                    this.setState({ boolValue });
                }
            }
        };
        // istanbul ignore next
        this._hasNoChildren = (children) => React.Children.count(children) === 0;
        this.state = {
            boolValue: undefined !== props.defaultValue ? props.defaultValue : true,
        };
    }
    componentDidMount() {
        /* istanbul ignore else */
        if ((this.props.boolFunc !== undefined) && this.props.eventIds.length > 0)
            SyncUiEventDispatcher_1.SyncUiEventDispatcher.onSyncUiEvent.addListener(this._handleVisibilitySyncUiEvent);
    }
    componentWillUnmount() {
        /* istanbul ignore else */
        if ((this.props.boolFunc !== undefined) && this.props.eventIds.length > 0) {
            this._componentUnmounting = true;
            SyncUiEventDispatcher_1.SyncUiEventDispatcher.onSyncUiEvent.removeListener(this._handleVisibilitySyncUiEvent);
        }
    }
    render() {
        const _a = this.props, { 
        // do not bleed our props
        children, eventIds, boolFunc, defaultValue } = _a, // eslint-disable-line @typescript-eslint/no-unused-vars
        // eslint-disable-next-line comma-dangle
        otherProps = __rest(_a, ["children", "eventIds", "boolFunc", "defaultValue"]) // pass-through props
        ;
        const boolValue = this.state.boolValue;
        return (typeof children === "function" ?
            children(boolValue, otherProps)
            : /* istanbul ignore next */ !this._hasNoChildren(children)
                ? React.Children.only(children)
                : null);
    }
}
exports.BooleanSyncUiListener = BooleanSyncUiListener;
//# sourceMappingURL=BooleanListener.js.map