/** @packageDocumentation
 * @module State
 */
import * as React from "react";
/** Enum for the Color Theme string.
 * @public
 */
export declare enum ColorTheme {
    Light = "light",
    Dark = "dark"
}
/** System preferred color theme.
 * @public
 */
export declare const SYSTEM_PREFERRED_COLOR_THEME = "SYSTEM_PREFERRED";
/** The default color theme.
 * @deprecated SYSTEM_PREFERRED_COLOR_THEME is used as a default color theme.
 * @public
 */
export declare const COLOR_THEME_DEFAULT = ColorTheme.Light;
/** The default widget opacity.
 * @public
 */
export declare const WIDGET_OPACITY_DEFAULT = 0.9;
/** Properties of [[ThemeManagerComponent]].
 */
interface ThemeProps {
    /** theme ("light", "dark", etc.) */
    theme: string;
    widgetOpacity: number;
    children?: React.ReactNode;
}
/** ThemeManagerComponent handles setting themes.
 */
declare class ThemeManagerComponent extends React.Component<ThemeProps> {
    componentDidMount(): void;
    componentDidUpdate(prevProps: ThemeProps): void;
    private _setTheme;
    private _setWidgetOpacity;
    render(): React.ReactNode;
}
/**
 * ThemeManager handles setting color themes.
 * This React component is Redux connected.
 * @public
 */
export declare const ThemeManager: import("react-redux").ConnectedComponent<typeof ThemeManagerComponent, import("react-redux").Omit<React.ClassAttributes<ThemeManagerComponent> & ThemeProps, "theme" | "widgetOpacity">>;
export {};
//# sourceMappingURL=ThemeManager.d.ts.map