"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module State
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemeManager = exports.WIDGET_OPACITY_DEFAULT = exports.COLOR_THEME_DEFAULT = exports.SYSTEM_PREFERRED_COLOR_THEME = exports.ColorTheme = void 0;
const React = require("react");
const react_redux_1 = require("react-redux");
const UiFramework_1 = require("../UiFramework");
/** Enum for the Color Theme string.
 * @public
 */
var ColorTheme;
(function (ColorTheme) {
    ColorTheme["Light"] = "light";
    ColorTheme["Dark"] = "dark";
})(ColorTheme = exports.ColorTheme || (exports.ColorTheme = {}));
/** System preferred color theme.
 * @public
 */
exports.SYSTEM_PREFERRED_COLOR_THEME = "SYSTEM_PREFERRED";
/** The default color theme.
 * @deprecated SYSTEM_PREFERRED_COLOR_THEME is used as a default color theme.
 * @public
 */
exports.COLOR_THEME_DEFAULT = ColorTheme.Light;
/** The default widget opacity.
 * @public
 */
exports.WIDGET_OPACITY_DEFAULT = 0.90;
function mapStateToProps(state) {
    const frameworkState = state[UiFramework_1.UiFramework.frameworkStateKey]; // since app sets up key, don't hard-code name
    // istanbul ignore if
    if (!frameworkState)
        return undefined;
    return {
        theme: frameworkState.configurableUiState.theme,
        widgetOpacity: frameworkState.configurableUiState.widgetOpacity,
    };
}
/** ThemeManagerComponent handles setting themes.
 */
class ThemeManagerComponent extends React.Component {
    constructor() {
        super(...arguments);
        this._setTheme = (theme) => {
            document.documentElement.classList.add("theme-transition");
            document.documentElement.setAttribute("data-theme", theme);
            window.setTimeout(() => document.documentElement.classList.remove("theme-transition"), 1000);
        };
        this._setWidgetOpacity = (opacity) => {
            document.documentElement.style.setProperty("--buic-widget-opacity", opacity.toString());
        };
    }
    componentDidMount() {
        this._setTheme(this.props.theme);
    }
    componentDidUpdate(prevProps) {
        if (this.props.theme !== prevProps.theme)
            this._setTheme(this.props.theme);
        if (this.props.widgetOpacity !== prevProps.widgetOpacity)
            this._setWidgetOpacity(this.props.widgetOpacity);
    }
    render() {
        return this.props.children;
    }
}
/**
 * ThemeManager handles setting color themes.
 * This React component is Redux connected.
 * @public
 */
exports.ThemeManager = react_redux_1.connect(mapStateToProps)(ThemeManagerComponent); // eslint-disable-line @typescript-eslint/naming-convention
//# sourceMappingURL=ThemeManager.js.map