"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Timeline
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.SolarTimelineDataProvider = void 0;
const imodeljs_common_1 = require("@bentley/imodeljs-common");
const ui_components_1 = require("@bentley/ui-components");
// the interface and class are in alpha state - it may change after usability testing - test coverage not complete
/* istanbul ignore file */
/** Default Solar Data Provider interface for getting and setting solar position from iModels view definitions.
 * @alpha
 */
class SolarTimelineDataProvider extends ui_components_1.BaseSolarDataProvider {
    /** constructor that takes an optional viewport and optional position on globe that is used if the imodel is not "GeoLocated"  */
    constructor(viewState, viewport, longitude, latitude) {
        super(viewport, longitude, latitude);
        this.onTimeChanged = (time) => {
            if (this._viewport && this._viewport.view.is3d()) {
                this._viewport.view.displayStyle.setSunTime(time.getTime());
            }
        };
        this._viewState = viewState;
        if (viewState.is3d()) {
            this.supportsTimelineAnimation = true;
            this._cartographicCenter = this.getCartographicCenter(viewState.iModel);
        }
        else {
            this._cartographicCenter = imodeljs_common_1.Cartographic.fromDegrees(this.longitude, this.latitude, 0.0);
        }
        this._projectTimeZoneOffset = this.getZone(this._cartographicCenter);
        this.initializeData(this._projectTimeZoneOffset);
        this.onTimeChanged(this.timeOfDay);
    }
    get _displayStyle3d() {
        return undefined !== this._viewport && this._viewport.view.is3d() ? this._viewport.view.displayStyle : undefined;
    }
    get shouldShowTimeline() {
        const style = this._displayStyle3d;
        return undefined !== style && style.viewFlags.shadows;
    }
    get shadowColor() {
        const style = this._displayStyle3d;
        return style ? style.settings.solarShadows.color.toColorDef() : imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.gray);
    }
    set shadowColor(color) {
        const displayStyle = this._displayStyle3d;
        if (!displayStyle)
            return;
        const prevColor = displayStyle.settings.solarShadows.color;
        const newColor = color.colors;
        if (prevColor.r === newColor.r && prevColor.g === newColor.g && prevColor.b === newColor.b)
            return;
        const newSettings = displayStyle.settings.solarShadows.toJSON();
        if (!newSettings)
            return;
        newSettings.color = color.tbgr;
        displayStyle.settings.solarShadows = imodeljs_common_1.SolarShadowSettings.fromJSON(newSettings);
    }
}
exports.SolarTimelineDataProvider = SolarTimelineDataProvider;
//# sourceMappingURL=SolarTimelineDataProvider.js.map