"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Item
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PopupButton = void 0;
require("@bentley/ui-ninezone/lib/ui-ninezone/toolbar/item/expandable/group/Panel.scss");
require("./PopupButton.scss");
const classnames = require("classnames");
const React = require("react");
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
const FrontstageManager_1 = require("../frontstage/FrontstageManager");
const KeyboardShortcut_1 = require("../keyboardshortcut/KeyboardShortcut");
const SyncUiEventDispatcher_1 = require("../syncui/SyncUiEventDispatcher");
const UiFramework_1 = require("../UiFramework");
const PropsHelper_1 = require("../utils/PropsHelper");
const DragInteraction_1 = require("./DragInteraction");
/* eslint-disable deprecation/deprecation */
// cSpell:ignore popupbutton
// eslint-disable-next-line @typescript-eslint/naming-convention
const DivWithOnOutsideClick = ui_core_1.withOnOutsideClick((props) => (React.createElement("div", Object.assign({}, props))), undefined, true);
const isFunction = (node) => {
    if (typeof node === "function")
        return true;
    return false;
};
/**
 * Used to provide custom popup button in toolbar.
 * @public
 * @deprecated use PopupItem in ToolbarWithOverflow or popupPanelNode in CustomItemDef
 */
class PopupButton extends React.Component {
    constructor(props) {
        super(props);
        this._label = "";
        this._componentUnmounting = false;
        this._closeOnPanelOpened = true;
        this._ref = React.createRef();
        this._isMounted = false;
        /** Minimizes the expandable component. */
        this.minimize = () => {
            if (this._isMounted)
                this.setState({
                    isPressed: false,
                });
        };
        this._handleSyncUiEvent = (args) => {
            // istanbul ignore if
            if (this._componentUnmounting)
                return;
            let refreshState = false;
            let newState = Object.assign({}, this.state);
            // istanbul ignore else
            if (this.props.stateSyncIds && this.props.stateSyncIds.length > 0) // eslint-disable-line deprecation/deprecation
                refreshState = this.props.stateSyncIds.some((value) => args.eventIds.has(value.toLowerCase())); // eslint-disable-line deprecation/deprecation
            // istanbul ignore else
            if (refreshState) {
                // istanbul ignore else
                if (this.props.stateFunc) // eslint-disable-line deprecation/deprecation
                    newState = this.props.stateFunc(newState); // eslint-disable-line deprecation/deprecation
                // istanbul ignore next
                if ((this.state.isActive !== newState.isActive) || (this.state.isEnabled !== newState.isEnabled) || (this.state.isVisible !== newState.isVisible)) {
                    if (this._isMounted)
                        this.setState({ isActive: newState.isActive, isEnabled: newState.isEnabled, isVisible: newState.isVisible });
                }
            }
        };
        this._handleToolPanelOpenedEvent = () => {
            if (!this._closeOnPanelOpened)
                return;
            this.minimize();
        };
        this._handleKeyDown = (e) => {
            // istanbul ignore next
            if (e.key === ui_abstract_1.SpecialKey.Escape) {
                this.minimize();
                KeyboardShortcut_1.KeyboardShortcutManager.setFocusToHome();
            }
        };
        this._handleClick = () => {
            // istanbul ignore else
            if (this._isMounted)
                this.setState((prevState) => {
                    const isPressed = !prevState.isPressed;
                    return {
                        isPressed,
                    };
                }, () => {
                    const expand = !!this.state.isPressed;
                    this._closeOnPanelOpened = false;
                    expand && FrontstageManager_1.FrontstageManager.onToolPanelOpenedEvent.emit();
                    this._closeOnPanelOpened = true;
                    this.props.onExpanded && this.props.onExpanded(expand);
                });
        };
        this._handleOutsideClick = (e) => {
            this._ref.current && (e.target instanceof Node) && !this._ref.current.contains(e.target) && this.minimize();
        };
        if (props.label)
            this._label = props.label;
        // istanbul ignore else
        else if (props.labelKey)
            this._label = UiFramework_1.UiFramework.i18n.translate(props.labelKey);
        this.state = {
            isVisible: undefined !== props.isVisible ? props.isVisible : true,
            isEnabled: undefined !== props.isEnabled ? props.isEnabled : true,
            isActive: undefined !== props.isActive ? props.isActive : false,
            isPressed: undefined !== props.isPressed ? props.isPressed : false,
        };
    }
    get label() {
        return PropsHelper_1.PropsHelper.getStringFromSpec(this._label);
    }
    componentDidMount() {
        this._isMounted = true;
        SyncUiEventDispatcher_1.SyncUiEventDispatcher.onSyncUiEvent.addListener(this._handleSyncUiEvent);
        FrontstageManager_1.FrontstageManager.onToolPanelOpenedEvent.addListener(this._handleToolPanelOpenedEvent);
    }
    componentWillUnmount() {
        this._isMounted = false;
        this._componentUnmounting = true;
        SyncUiEventDispatcher_1.SyncUiEventDispatcher.onSyncUiEvent.removeListener(this._handleSyncUiEvent);
        FrontstageManager_1.FrontstageManager.onToolPanelOpenedEvent.addListener(this._handleToolPanelOpenedEvent);
    }
    /** Renders PopupButton */
    render() {
        if (!this.state.isVisible)
            return null;
        const icon = React.createElement(ui_core_1.Icon, { iconSpec: this.props.iconSpec });
        const badge = ui_core_1.BadgeUtilities.getComponentForBadgeType(this.props.badgeType);
        const _a = this.props, { isDisabled } = _a, otherProps = __rest(_a, ["isDisabled"]);
        return (React.createElement(DragInteraction_1.ToolbarDragInteractionContext.Consumer, null, (isDragEnabled) => {
            return (React.createElement(ui_ninezone_1.ExpandableItem, Object.assign({}, otherProps, { isDisabled: ui_abstract_1.ConditionalBooleanValue.getValue(isDisabled), hideIndicator: isDragEnabled, panel: this.getExpandedContent() }),
                React.createElement("div", { ref: this._ref },
                    React.createElement(ui_ninezone_1.Item, { badge: badge, icon: icon, onKeyDown: this._handleKeyDown, onClick: this._handleClick, onSizeKnown: this.props.onSizeKnown, title: this.label }))));
        }));
    }
    /** Returns expanded content panel */
    getExpandedContent() {
        if (!this.state.isPressed)
            return undefined;
        const classNames = classnames("nz-toolbar-item-expandable-group-panel", this.props.noPadding && "uifw-popupbutton-noPadding");
        return (React.createElement(DivWithOnOutsideClick, { className: classNames, onOutsideClick: this._handleOutsideClick }, isFunction(this.props.children) ? this.props.children({
            closePanel: this.minimize,
        }) : this.props.children));
    }
}
exports.PopupButton = PopupButton;
//# sourceMappingURL=PopupButton.js.map