"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* Licensed under the MIT License. See LICENSE.md in the project root for license terms.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Toolbar
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.useUiItemsProviderToolbarItems = void 0;
const React = require("react");
const ui_abstract_1 = require("@bentley/ui-abstract");
const useActiveStageId_1 = require("../hooks/useActiveStageId");
const useAvailableUiItemsProviders_1 = require("../hooks/useAvailableUiItemsProviders");
const FrontstageManager_1 = require("../frontstage/FrontstageManager");
/** Hook that returns items from [[ToolbarItemsManager]].
 * @beta
 */
const useUiItemsProviderToolbarItems = (manager, toolbarUsage, toolbarOrientation) => {
    const uiItemsProviderIds = useAvailableUiItemsProviders_1.useAvailableUiItemsProviders();
    const stageId = useActiveStageId_1.useActiveStageId();
    const [items, setItems] = React.useState(manager.items);
    const providersRef = React.useRef("");
    const currentStageRef = React.useRef("");
    // gathers items from registered extensions - dependent on when a uiItemsProvider is register or unregistered and if the
    // current stage's composer allows entries from extensions.
    React.useEffect(() => {
        const uiProviders = uiItemsProviderIds.join("-");
        const handleChanged = (args) => {
            setItems(args.items);
        };
        manager.onItemsChanged.addListener(handleChanged);
        // istanbul ignore else
        if (providersRef.current !== uiProviders || currentStageRef.current !== stageId) {
            const frontstageDef = FrontstageManager_1.FrontstageManager.findFrontstageDef(stageId);
            // istanbul ignore next
            const usage = (frontstageDef === null || frontstageDef === void 0 ? void 0 : frontstageDef.usage) ? frontstageDef.usage : ui_abstract_1.StageUsage.General;
            currentStageRef.current = stageId;
            providersRef.current = uiProviders;
            const toolbarItems = ui_abstract_1.UiItemsManager.getToolbarButtonItems(stageId, usage, toolbarUsage, toolbarOrientation);
            const updatedToolbarItems = ui_abstract_1.UiItemsArbiter.updateToolbarButtonItems(toolbarItems);
            manager.loadItems(updatedToolbarItems);
            setItems(manager.items);
        }
        return () => {
            manager.onItemsChanged.removeListener(handleChanged);
        };
    }, [uiItemsProviderIds, stageId, manager, toolbarUsage, toolbarOrientation]);
    return items;
};
exports.useUiItemsProviderToolbarItems = useUiItemsProviderToolbarItems;
//# sourceMappingURL=useUiItemsProviderToolbarItems.js.map