"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Tools
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.CoreTools = void 0;
const React = require("react");
// cSpell:ignore configurableui keyinbrowser
const imodeljs_frontend_1 = require("@bentley/imodeljs-frontend");
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_components_1 = require("@bentley/ui-components");
const PopupButton_1 = require("../toolbar/PopupButton");
const ContentViewManager_1 = require("../content/ContentViewManager");
const KeyinBrowser_1 = require("../keyinbrowser/KeyinBrowser");
const SelectionContextItemDef_1 = require("../selection/SelectionContextItemDef");
const CommandItemDef_1 = require("../shared/CommandItemDef");
const CustomItemDef_1 = require("../shared/CustomItemDef");
const ToolItemDef_1 = require("../shared/ToolItemDef");
const SyncUiEventDispatcher_1 = require("../syncui/SyncUiEventDispatcher");
const GroupItem_1 = require("../toolbar/GroupItem");
const RestoreLayoutTool_1 = require("./RestoreLayoutTool");
const UiFramework_1 = require("../UiFramework");
/* eslint-disable deprecation/deprecation */
/** Utility Class that provides definitions of tools provided by iModel.js core. These definitions can be used to populate the UI.
 * @public
 */
// istanbul ignore next
class CoreTools {
    /** Get the CustomItemDef for PopupButton
     * @beta
     */
    static get keyinBrowserButtonItemDef() {
        return new CustomItemDef_1.CustomItemDef({
            customId: "uif:keyinbrowser",
            iconSpec: "icon-process",
            labelKey: "UiFramework:keyinbrowser.label",
            popupPanelNode: React.createElement(ui_components_1.ToolbarPopupContext.Consumer, null, ({ closePanel }) => (React.createElement(KeyinBrowser_1.KeyinBrowser, { onExecute: closePanel, onCancel: closePanel }))),
            // DEPRECATED way
            reactElement: (React.createElement(PopupButton_1.PopupButton, { iconSpec: "icon-process", labelKey: "UiFramework:keyinbrowser.label" }, this._renderKeyInBrowser)),
        });
    }
    static get keyinPaletteButtonItemDef() {
        return new ToolItemDef_1.ToolItemDef({
            toolId: "uif:keyinpalette",
            iconSpec: "icon-process",
            labelKey: "UiFramework:keyinbrowser.label",
            execute: () => { imodeljs_frontend_1.IModelApp.uiAdmin.showKeyinPalette(); },
        });
    }
    static get fitViewCommand() {
        return new ToolItemDef_1.ToolItemDef({
            toolId: imodeljs_frontend_1.FitViewTool.toolId,
            iconSpec: imodeljs_frontend_1.FitViewTool.iconSpec,
            label: imodeljs_frontend_1.FitViewTool.flyover,
            description: imodeljs_frontend_1.FitViewTool.description,
            execute: () => { imodeljs_frontend_1.IModelApp.tools.run(imodeljs_frontend_1.FitViewTool.toolId, imodeljs_frontend_1.IModelApp.viewManager.selectedView, true); },
        });
    }
    static get windowAreaCommand() {
        return new ToolItemDef_1.ToolItemDef({
            toolId: imodeljs_frontend_1.WindowAreaTool.toolId,
            iconSpec: imodeljs_frontend_1.WindowAreaTool.iconSpec,
            label: imodeljs_frontend_1.WindowAreaTool.flyover,
            description: imodeljs_frontend_1.WindowAreaTool.description,
            execute: () => { imodeljs_frontend_1.IModelApp.tools.run(imodeljs_frontend_1.WindowAreaTool.toolId, imodeljs_frontend_1.IModelApp.viewManager.selectedView); },
        });
    }
    static get zoomViewCommand() {
        return new ToolItemDef_1.ToolItemDef({
            toolId: imodeljs_frontend_1.ZoomViewTool.toolId,
            iconSpec: imodeljs_frontend_1.ZoomViewTool.iconSpec,
            label: imodeljs_frontend_1.ZoomViewTool.flyover,
            description: imodeljs_frontend_1.ZoomViewTool.description,
            execute: () => { imodeljs_frontend_1.IModelApp.tools.run(imodeljs_frontend_1.ZoomViewTool.toolId, imodeljs_frontend_1.IModelApp.viewManager.selectedView); },
        });
    }
    static get panViewCommand() {
        return new ToolItemDef_1.ToolItemDef({
            toolId: imodeljs_frontend_1.PanViewTool.toolId,
            iconSpec: imodeljs_frontend_1.PanViewTool.iconSpec,
            label: imodeljs_frontend_1.PanViewTool.flyover,
            description: imodeljs_frontend_1.PanViewTool.description,
            execute: () => { imodeljs_frontend_1.IModelApp.tools.run(imodeljs_frontend_1.PanViewTool.toolId, imodeljs_frontend_1.IModelApp.viewManager.selectedView); },
        });
    }
    static get rotateViewCommand() {
        return new ToolItemDef_1.ToolItemDef({
            toolId: imodeljs_frontend_1.RotateViewTool.toolId,
            iconSpec: new ui_abstract_1.ConditionalStringValue(() => {
                var _a;
                const activeContentControl = ContentViewManager_1.ContentViewManager.getActiveContentControl();
                if ((_a = activeContentControl === null || activeContentControl === void 0 ? void 0 : activeContentControl.viewport) === null || _a === void 0 ? void 0 : _a.view.is2d())
                    return "icon-rotate-left";
                return "icon-gyroscope";
            }, [SyncUiEventDispatcher_1.SyncUiEventId.ActiveContentChanged, SyncUiEventDispatcher_1.SyncUiEventId.ActiveViewportChanged, SyncUiEventDispatcher_1.SyncUiEventId.ViewStateChanged]),
            label: imodeljs_frontend_1.RotateViewTool.flyover,
            description: imodeljs_frontend_1.RotateViewTool.description,
            execute: () => { imodeljs_frontend_1.IModelApp.tools.run(imodeljs_frontend_1.RotateViewTool.toolId, imodeljs_frontend_1.IModelApp.viewManager.selectedView); },
        });
    }
    static get walkViewCommand() {
        return new ToolItemDef_1.ToolItemDef({
            toolId: imodeljs_frontend_1.WalkViewTool.toolId,
            iconSpec: imodeljs_frontend_1.WalkViewTool.iconSpec,
            label: imodeljs_frontend_1.WalkViewTool.flyover,
            description: imodeljs_frontend_1.WalkViewTool.description,
            isHidden: new ui_abstract_1.ConditionalBooleanValue(() => {
                var _a;
                const activeContentControl = ContentViewManager_1.ContentViewManager.getActiveContentControl();
                return !!((_a = activeContentControl === null || activeContentControl === void 0 ? void 0 : activeContentControl.viewport) === null || _a === void 0 ? void 0 : _a.view.is2d());
            }, [SyncUiEventDispatcher_1.SyncUiEventId.ActiveContentChanged, SyncUiEventDispatcher_1.SyncUiEventId.ActiveViewportChanged, SyncUiEventDispatcher_1.SyncUiEventId.ViewStateChanged]),
            execute: () => { imodeljs_frontend_1.IModelApp.tools.run(imodeljs_frontend_1.WalkViewTool.toolId, imodeljs_frontend_1.IModelApp.viewManager.selectedView); },
        });
    }
    static get selectElementCommand() {
        return new ToolItemDef_1.ToolItemDef({
            toolId: imodeljs_frontend_1.SelectionTool.toolId,
            iconSpec: imodeljs_frontend_1.SelectionTool.iconSpec,
            label: imodeljs_frontend_1.SelectionTool.flyover,
            description: imodeljs_frontend_1.SelectionTool.description,
            execute: () => {
                imodeljs_frontend_1.IModelApp.tools.run(imodeljs_frontend_1.SelectionTool.toolId);
            },
        });
    }
    static get toggleCameraViewCommand() {
        return new ToolItemDef_1.ToolItemDef({
            toolId: imodeljs_frontend_1.ViewToggleCameraTool.toolId,
            iconSpec: new ui_abstract_1.ConditionalStringValue(() => {
                var _a, _b;
                const activeContentControl = ContentViewManager_1.ContentViewManager.getActiveContentControl();
                if (((_a = activeContentControl === null || activeContentControl === void 0 ? void 0 : activeContentControl.viewport) === null || _a === void 0 ? void 0 : _a.view.is3d()) && ((_b = activeContentControl === null || activeContentControl === void 0 ? void 0 : activeContentControl.viewport) === null || _b === void 0 ? void 0 : _b.isCameraOn))
                    return "icon-camera-animation";
                return "icon-camera-animation-disabled";
            }, [SyncUiEventDispatcher_1.SyncUiEventId.ActiveContentChanged, SyncUiEventDispatcher_1.SyncUiEventId.ActiveViewportChanged, SyncUiEventDispatcher_1.SyncUiEventId.ViewStateChanged]),
            label: imodeljs_frontend_1.ViewToggleCameraTool.flyover,
            description: imodeljs_frontend_1.ViewToggleCameraTool.description,
            isHidden: new ui_abstract_1.ConditionalBooleanValue(() => {
                var _a, _b;
                const activeContentControl = ContentViewManager_1.ContentViewManager.getActiveContentControl();
                return !(((_a = activeContentControl === null || activeContentControl === void 0 ? void 0 : activeContentControl.viewport) === null || _a === void 0 ? void 0 : _a.view.is3d()) && ((_b = activeContentControl === null || activeContentControl === void 0 ? void 0 : activeContentControl.viewport) === null || _b === void 0 ? void 0 : _b.view.supportsCamera()));
            }, [SyncUiEventDispatcher_1.SyncUiEventId.ActiveContentChanged, SyncUiEventDispatcher_1.SyncUiEventId.ActiveViewportChanged, SyncUiEventDispatcher_1.SyncUiEventId.ViewStateChanged]),
            execute: () => { imodeljs_frontend_1.IModelApp.tools.run(imodeljs_frontend_1.ViewToggleCameraTool.toolId, imodeljs_frontend_1.IModelApp.viewManager.selectedView); },
        });
    }
    static get flyViewCommand() {
        return new ToolItemDef_1.ToolItemDef({
            toolId: imodeljs_frontend_1.FlyViewTool.toolId,
            iconSpec: imodeljs_frontend_1.FlyViewTool.iconSpec,
            label: imodeljs_frontend_1.FlyViewTool.flyover,
            description: imodeljs_frontend_1.FlyViewTool.description,
            execute: () => { imodeljs_frontend_1.IModelApp.tools.run(imodeljs_frontend_1.FlyViewTool.toolId, imodeljs_frontend_1.IModelApp.viewManager.selectedView); },
        });
    }
    // TODO - Need to provide a sync message that is fired when the Undo/Redo button needs to be refreshed in the
    // active view.
    static get viewUndoCommand() {
        return new ToolItemDef_1.ToolItemDef({
            toolId: imodeljs_frontend_1.ViewUndoTool.toolId,
            isDisabled: new ui_abstract_1.ConditionalBooleanValue(() => {
                const activeContentControl = ContentViewManager_1.ContentViewManager.getActiveContentControl();
                if (activeContentControl && activeContentControl.viewport)
                    return !activeContentControl.viewport.isUndoPossible;
                return false;
            }, [SyncUiEventDispatcher_1.SyncUiEventId.ActiveContentChanged, SyncUiEventDispatcher_1.SyncUiEventId.ActiveViewportChanged, SyncUiEventDispatcher_1.SyncUiEventId.ViewStateChanged]),
            iconSpec: imodeljs_frontend_1.ViewUndoTool.iconSpec,
            label: imodeljs_frontend_1.ViewUndoTool.flyover,
            description: imodeljs_frontend_1.ViewUndoTool.description,
            execute: () => {
                imodeljs_frontend_1.IModelApp.tools.run(imodeljs_frontend_1.ViewUndoTool.toolId, imodeljs_frontend_1.IModelApp.viewManager.selectedView);
            },
            stateSyncIds: [SyncUiEventDispatcher_1.SyncUiEventId.ActiveContentChanged, SyncUiEventDispatcher_1.SyncUiEventId.ActiveViewportChanged, SyncUiEventDispatcher_1.SyncUiEventId.ViewStateChanged],
            stateFunc: (currentState) => {
                const returnState = Object.assign({}, currentState);
                const activeContentControl = ContentViewManager_1.ContentViewManager.getActiveContentControl();
                if (activeContentControl && activeContentControl.viewport)
                    returnState.isEnabled = activeContentControl.viewport.isUndoPossible;
                return returnState;
            },
        });
    }
    static get viewRedoCommand() {
        return new ToolItemDef_1.ToolItemDef({
            toolId: imodeljs_frontend_1.ViewRedoTool.toolId,
            iconSpec: imodeljs_frontend_1.ViewRedoTool.iconSpec,
            label: imodeljs_frontend_1.ViewRedoTool.flyover,
            description: imodeljs_frontend_1.ViewRedoTool.description,
            execute: () => { imodeljs_frontend_1.IModelApp.tools.run(imodeljs_frontend_1.ViewRedoTool.toolId, imodeljs_frontend_1.IModelApp.viewManager.selectedView); },
            isDisabled: new ui_abstract_1.ConditionalBooleanValue(() => {
                const activeContentControl = ContentViewManager_1.ContentViewManager.getActiveContentControl();
                if (activeContentControl && activeContentControl.viewport)
                    return !activeContentControl.viewport.isRedoPossible;
                return false;
            }, [SyncUiEventDispatcher_1.SyncUiEventId.ActiveContentChanged, SyncUiEventDispatcher_1.SyncUiEventId.ActiveViewportChanged, SyncUiEventDispatcher_1.SyncUiEventId.ViewStateChanged]),
            stateSyncIds: [SyncUiEventDispatcher_1.SyncUiEventId.ActiveContentChanged, SyncUiEventDispatcher_1.SyncUiEventId.ActiveViewportChanged, SyncUiEventDispatcher_1.SyncUiEventId.ViewStateChanged],
            stateFunc: (currentState) => {
                const returnState = Object.assign({}, currentState);
                const activeContentControl = ContentViewManager_1.ContentViewManager.getActiveContentControl();
                if (activeContentControl && activeContentControl.viewport)
                    returnState.isEnabled = activeContentControl.viewport.isRedoPossible;
                return returnState;
            },
        });
    }
    static turnOnClipVolume() {
        const vp = imodeljs_frontend_1.IModelApp.viewManager.selectedView;
        if (!vp || !vp.view.is3d())
            return;
        // Turn on clip volume flag for section tools
        const viewFlags = vp.view.viewFlags.clone();
        viewFlags.clipVolume = true;
        vp.viewFlags = viewFlags;
    }
    // note current ViewClipByPlaneTool is not automatically registered so the app must call ViewClipByPlaneTool.register();
    static get sectionByPlaneCommandItemDef() {
        return new ToolItemDef_1.ToolItemDef({
            toolId: imodeljs_frontend_1.ViewClipByPlaneTool.toolId,
            iconSpec: imodeljs_frontend_1.ViewClipByPlaneTool.iconSpec,
            label: imodeljs_frontend_1.ViewClipByPlaneTool.flyover,
            description: imodeljs_frontend_1.ViewClipByPlaneTool.description,
            execute: () => {
                this.turnOnClipVolume();
                imodeljs_frontend_1.IModelApp.tools.run(imodeljs_frontend_1.ViewClipByPlaneTool.toolId, imodeljs_frontend_1.ViewClipDecorationProvider.create());
            },
        });
    }
    // note current ViewClipByElementTool is not automatically registered so the app must call ViewClipByElementTool.register();
    static get sectionByElementCommandItemDef() {
        return new ToolItemDef_1.ToolItemDef({
            toolId: imodeljs_frontend_1.ViewClipByElementTool.toolId,
            iconSpec: imodeljs_frontend_1.ViewClipByElementTool.iconSpec,
            label: imodeljs_frontend_1.ViewClipByElementTool.flyover,
            description: imodeljs_frontend_1.ViewClipByElementTool.description,
            execute: () => {
                this.turnOnClipVolume();
                imodeljs_frontend_1.IModelApp.tools.run(imodeljs_frontend_1.ViewClipByElementTool.toolId, imodeljs_frontend_1.ViewClipDecorationProvider.create());
            },
        });
    }
    // note current ViewClipByRangeTool is not automatically registered so the app must call ViewClipByRangeTool.register();
    static get sectionByRangeCommandItemDef() {
        return new ToolItemDef_1.ToolItemDef({
            toolId: imodeljs_frontend_1.ViewClipByRangeTool.toolId,
            iconSpec: imodeljs_frontend_1.ViewClipByRangeTool.iconSpec,
            label: imodeljs_frontend_1.ViewClipByRangeTool.flyover,
            description: imodeljs_frontend_1.ViewClipByRangeTool.description,
            execute: () => {
                this.turnOnClipVolume();
                imodeljs_frontend_1.IModelApp.tools.run(imodeljs_frontend_1.ViewClipByRangeTool.toolId, imodeljs_frontend_1.ViewClipDecorationProvider.create());
            },
        });
    }
    // note current ViewClipByShapeTool is not automatically registered so the app must call ViewClipByShapeTool.register();
    static get sectionByShapeCommandItemDef() {
        return new ToolItemDef_1.ToolItemDef({
            toolId: imodeljs_frontend_1.ViewClipByShapeTool.toolId,
            iconSpec: imodeljs_frontend_1.ViewClipByShapeTool.iconSpec,
            label: imodeljs_frontend_1.ViewClipByShapeTool.flyover,
            description: imodeljs_frontend_1.ViewClipByShapeTool.description,
            execute: () => {
                this.turnOnClipVolume();
                imodeljs_frontend_1.IModelApp.tools.run(imodeljs_frontend_1.ViewClipByShapeTool.toolId, imodeljs_frontend_1.ViewClipDecorationProvider.create());
            },
        });
    }
    static get sectionToolGroup() {
        imodeljs_frontend_1.ViewClipByElementTool.register();
        imodeljs_frontend_1.ViewClipByPlaneTool.register();
        imodeljs_frontend_1.ViewClipByRangeTool.register();
        imodeljs_frontend_1.ViewClipByShapeTool.register();
        return new GroupItem_1.GroupItemDef({
            groupId: "sectionTools-group",
            labelKey: "UiFramework:tools.sectionTools",
            iconSpec: "icon-section-tool",
            isHidden: new ui_abstract_1.ConditionalBooleanValue(() => {
                var _a;
                const activeContentControl = ContentViewManager_1.ContentViewManager.getActiveContentControl();
                return !!((_a = activeContentControl === null || activeContentControl === void 0 ? void 0 : activeContentControl.viewport) === null || _a === void 0 ? void 0 : _a.view.is2d());
            }, [SyncUiEventDispatcher_1.SyncUiEventId.ActiveContentChanged, SyncUiEventDispatcher_1.SyncUiEventId.ActiveViewportChanged, SyncUiEventDispatcher_1.SyncUiEventId.ViewStateChanged]),
            items: [this.sectionByPlaneCommandItemDef, this.sectionByElementCommandItemDef, this.sectionByRangeCommandItemDef, this.sectionByShapeCommandItemDef],
            itemsInColumn: 4,
        });
    }
    static get sectionToolGroupWithPanel() {
        imodeljs_frontend_1.ViewClipByElementTool.register();
        imodeljs_frontend_1.ViewClipByPlaneTool.register();
        imodeljs_frontend_1.ViewClipByRangeTool.register();
        imodeljs_frontend_1.ViewClipByShapeTool.register();
        return new GroupItem_1.GroupItemDef({
            groupId: "sectionTools-group-with-panel",
            labelKey: "UiFramework:tools.sectionTools",
            panelLabelKey: "UiFramework:tools.sectionPanelLabel",
            iconSpec: "icon-section-tool",
            isHidden: new ui_abstract_1.ConditionalBooleanValue(() => {
                var _a;
                const activeContentControl = ContentViewManager_1.ContentViewManager.getActiveContentControl();
                return !!((_a = activeContentControl === null || activeContentControl === void 0 ? void 0 : activeContentControl.viewport) === null || _a === void 0 ? void 0 : _a.view.is2d());
            }, [SyncUiEventDispatcher_1.SyncUiEventId.ActiveContentChanged, SyncUiEventDispatcher_1.SyncUiEventId.ActiveViewportChanged, SyncUiEventDispatcher_1.SyncUiEventId.ViewStateChanged]),
            items: [
                new ToolItemDef_1.ToolItemDef(Object.assign(Object.assign({}, this.sectionByPlaneCommandItemDef), { labelKey: "UiFramework:tools.sectionByPlane" })),
                new ToolItemDef_1.ToolItemDef(Object.assign(Object.assign({}, this.sectionByElementCommandItemDef), { labelKey: "UiFramework:tools.sectionByElement" })),
                new ToolItemDef_1.ToolItemDef(Object.assign(Object.assign({}, this.sectionByRangeCommandItemDef), { labelKey: "UiFramework:tools.sectionByRange" })),
                new ToolItemDef_1.ToolItemDef(Object.assign(Object.assign({}, this.sectionByShapeCommandItemDef), { labelKey: "UiFramework:tools.sectionByShape" })),
            ],
            itemsInColumn: 4,
        });
    }
    // note current MeasureDistanceTool is not automatically registered so the app must call MeasureDistanceTool.register();
    static get measureDistanceToolItemDef() {
        return new ToolItemDef_1.ToolItemDef({
            toolId: imodeljs_frontend_1.MeasureDistanceTool.toolId,
            iconSpec: imodeljs_frontend_1.MeasureDistanceTool.iconSpec,
            label: imodeljs_frontend_1.MeasureDistanceTool.flyover,
            description: imodeljs_frontend_1.MeasureDistanceTool.description,
            execute: () => {
                imodeljs_frontend_1.IModelApp.tools.run(imodeljs_frontend_1.MeasureDistanceTool.toolId);
            },
        });
    }
    // note current MeasureLocationTool is not automatically registered so the app must call MeasureLocationTool.register();
    static get measureLocationToolItemDef() {
        return new ToolItemDef_1.ToolItemDef({
            toolId: imodeljs_frontend_1.MeasureLocationTool.toolId,
            iconSpec: imodeljs_frontend_1.MeasureLocationTool.iconSpec,
            label: imodeljs_frontend_1.MeasureLocationTool.flyover,
            description: imodeljs_frontend_1.MeasureLocationTool.description,
            execute: () => {
                imodeljs_frontend_1.IModelApp.tools.run(imodeljs_frontend_1.MeasureLocationTool.toolId);
            },
        });
    }
    static get measureToolGroup() {
        imodeljs_frontend_1.MeasureDistanceTool.register();
        imodeljs_frontend_1.MeasureLocationTool.register();
        return new GroupItem_1.GroupItemDef({
            groupId: "measureTools-group",
            labelKey: "UiFramework:tools.measureTools",
            iconSpec: "icon-measure",
            items: [this.measureDistanceToolItemDef, this.measureLocationToolItemDef],
            itemsInColumn: 2,
        });
    }
    static get clearSelectionItemDef() {
        return new CommandItemDef_1.CommandItemDef({
            commandId: "UiFramework.ClearSelection",
            iconSpec: "icon-selection-clear",
            labelKey: "UiFramework:buttons.clearSelection",
            stateSyncIds: SelectionContextItemDef_1.getSelectionContextSyncEventIds(),
            stateFunc: SelectionContextItemDef_1.selectionContextStateFunc,
            isHidden: SelectionContextItemDef_1.getIsHiddenIfSelectionNotActive(),
            execute: () => {
                const iModelConnection = UiFramework_1.UiFramework.getIModelConnection();
                if (iModelConnection) {
                    iModelConnection.selectionSet.emptyAll();
                }
                const tool = imodeljs_frontend_1.IModelApp.toolAdmin.primitiveTool;
                if (tool)
                    tool.onRestartTool();
                else
                    imodeljs_frontend_1.IModelApp.toolAdmin.startDefaultTool();
            },
        });
    }
    static get restoreFrontstageLayoutCommandItemDef() {
        return new ToolItemDef_1.ToolItemDef({
            toolId: RestoreLayoutTool_1.RestoreFrontstageLayoutTool.toolId,
            iconSpec: RestoreLayoutTool_1.RestoreFrontstageLayoutTool.iconSpec,
            label: RestoreLayoutTool_1.RestoreFrontstageLayoutTool.flyover,
            description: RestoreLayoutTool_1.RestoreFrontstageLayoutTool.description,
            execute: () => {
                imodeljs_frontend_1.IModelApp.tools.run(RestoreLayoutTool_1.RestoreFrontstageLayoutTool.toolId);
            },
        });
    }
}
exports.CoreTools = CoreTools;
// istanbul ignore next
CoreTools._renderKeyInBrowser = ({ closePanel }) => {
    return (React.createElement(KeyinBrowser_1.KeyinBrowser, { onExecute: closePanel, onCancel: closePanel }));
};
//# sourceMappingURL=CoreToolDefinitions.js.map