"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Tools
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.MarkupTools = void 0;
const imodeljs_markup_1 = require("@bentley/imodeljs-markup");
const ToolItemDef_1 = require("../shared/ToolItemDef");
/** Utility Class that provides definitions of tools provided by imodeljs-markup package. These definitions can be used to populate the UI.
 *  Note: Application must call 'MarkupApp.initialize()' or 'MarkupApp.start()' before using these definitions.
 * @public
 */
// istanbul ignore next
class MarkupTools {
    static get selectToolDef() {
        return ToolItemDef_1.ToolItemDef.getItemDefForTool(imodeljs_markup_1.SelectTool, "icon-cursor");
    }
    static get lineToolDef() {
        return ToolItemDef_1.ToolItemDef.getItemDefForTool(imodeljs_markup_1.LineTool);
    }
    static get rectangleToolDef() {
        return ToolItemDef_1.ToolItemDef.getItemDefForTool(imodeljs_markup_1.RectangleTool);
    }
    static get polygonToolDef() {
        return ToolItemDef_1.ToolItemDef.getItemDefForTool(imodeljs_markup_1.PolygonTool);
    }
    static get cloudToolDef() {
        return ToolItemDef_1.ToolItemDef.getItemDefForTool(imodeljs_markup_1.CloudTool);
    }
    static get ellipseToolDef() {
        return ToolItemDef_1.ToolItemDef.getItemDefForTool(imodeljs_markup_1.EllipseTool);
    }
    static get arrowToolDef() {
        return ToolItemDef_1.ToolItemDef.getItemDefForTool(imodeljs_markup_1.ArrowTool);
    }
    static get distanceToolDef() {
        return ToolItemDef_1.ToolItemDef.getItemDefForTool(imodeljs_markup_1.DistanceTool);
    }
    static get sketchToolDef() {
        return ToolItemDef_1.ToolItemDef.getItemDefForTool(imodeljs_markup_1.SketchTool);
    }
    static get placeTextToolDef() {
        return ToolItemDef_1.ToolItemDef.getItemDefForTool(imodeljs_markup_1.PlaceTextTool);
    }
    static get symbolToolDef() {
        return ToolItemDef_1.ToolItemDef.getItemDefForTool(imodeljs_markup_1.SymbolTool);
    }
}
exports.MarkupTools = MarkupTools;
//# sourceMappingURL=MarkupToolDefinitions.js.map