"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RestoreFrontstageLayoutTool = void 0;
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Tools
 */
const imodeljs_frontend_1 = require("@bentley/imodeljs-frontend");
const FrontstageManager_1 = require("../frontstage/FrontstageManager");
const UiFramework_1 = require("../UiFramework");
/**
 * Immediate tool that will reset the layout to that specified in the stage definition. A stage Id
 * may be passed in, if not the active stage is used. The stage Id is case sensitive.
 * @alpha
 */
class RestoreFrontstageLayoutTool extends imodeljs_frontend_1.Tool {
    // istanbul ignore next
    static get minArgs() { return 0; }
    // istanbul ignore next
    static get maxArgs() { return 1; }
    run(frontstageId) {
        let frontstageDef;
        if (frontstageId) {
            frontstageDef = FrontstageManager_1.FrontstageManager.findFrontstageDef(frontstageId);
        }
        else {
            frontstageDef = FrontstageManager_1.FrontstageManager.activeFrontstageDef;
        }
        if (frontstageDef)
            frontstageDef.restoreLayout();
        else
            imodeljs_frontend_1.IModelApp.notifications.outputMessage(new imodeljs_frontend_1.NotifyMessageDetails(imodeljs_frontend_1.OutputMessagePriority.Info, UiFramework_1.UiFramework.translate("tools.RestoreFrontstageLayout.noStageFound")));
        return true;
    }
    parseAndRun(...args) {
        return this.run(args[0]);
    }
}
exports.RestoreFrontstageLayoutTool = RestoreFrontstageLayoutTool;
RestoreFrontstageLayoutTool.toolId = "RestoreFrontstageLayout";
RestoreFrontstageLayoutTool.iconSpec = "icon-view-layouts";
//# sourceMappingURL=RestoreLayoutTool.js.map