"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BumpToolSetting = exports.FocusToolSettings = void 0;
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Tools
 */
const imodeljs_frontend_1 = require("@bentley/imodeljs-frontend");
const ToolSettingsManager_1 = require("../zones/toolsettings/ToolSettingsManager");
/**
 * Immediate tool that will focus into the Tool Settings widget.
 * @alpha
 */
class FocusToolSettings extends imodeljs_frontend_1.Tool {
    run() {
        return ToolSettingsManager_1.ToolSettingsManager.focusIntoToolSettings();
    }
}
exports.FocusToolSettings = FocusToolSettings;
FocusToolSettings.toolId = "FocusToolSettings";
/**
 * Immediate tool that will bump a Tool Settings value.
 * @alpha
 */
class BumpToolSetting extends imodeljs_frontend_1.Tool {
    // istanbul ignore next
    static get maxArgs() { return 1; }
    run(settingIndexStr) {
        let settingIndex;
        if (settingIndexStr) {
            settingIndex = parseInt(settingIndexStr, 10);
            if (isNaN(settingIndex))
                return false;
        }
        imodeljs_frontend_1.IModelApp.toolAdmin.bumpToolSetting(settingIndex); // eslint-disable-line @typescript-eslint/no-floating-promises
        return true;
    }
    parseAndRun(...args) {
        return this.run(args[0]);
    }
}
exports.BumpToolSetting = BumpToolSetting;
BumpToolSetting.toolId = "BumpToolSetting";
//# sourceMappingURL=ToolSettingsTools.js.map