/** @packageDocumentation
 * @module Settings
 */
import { UiSetting, UiSettingsStorage } from "@bentley/ui-core";
import { UserSettingsProvider } from "../UiFramework";
/** Default values that may be specified for [[AppUiSettings]].
 * @beta
 */
export interface InitialAppUiSettings {
    colorTheme: string;
    dragInteraction: boolean;
    frameworkVersion: string;
    widgetOpacity: number;
}
/** These are the UI settings that are stored in the Redux store. They control the color theme, the UI version,
 * how toolbar group buttons work, and the opacity of widgets in 1.0 and floating widget in 2.0 when the cursor
 * is not inside them. It is expect that an IModelApp using App UI components will create and register AppUiSettings with
 * defaults specific to their application. This would be done by calling the following.
 *
 * ```ts
 * UiFramework.registerUserSettingsProvider(new AppUiSettings(defaults));
 * ```
 *
 * @beta
 */
export declare class AppUiSettings implements UserSettingsProvider {
    readonly providerId = "AppUiSettingsProvider";
    private static _settingNamespace;
    private _settings;
    private _applyingLocalSettings;
    colorTheme: UiSetting<string>;
    dragInteraction: UiSetting<boolean>;
    frameworkVersion: UiSetting<string>;
    widgetOpacity: UiSetting<number>;
    private setColorTheme;
    constructor(defaults: Partial<InitialAppUiSettings>);
    private handleSyncUiEvent;
    apply(storage: UiSettingsStorage): Promise<void>;
    loadUserSettings(storage: UiSettingsStorage): Promise<void>;
}
//# sourceMappingURL=AppUiSettings.d.ts.map