/** @packageDocumentation
 * @module Utilities
 */
import { ScreenViewport } from "@bentley/imodeljs-frontend";
/**
 * Various View utility methods
 * @public
 */
export declare class ViewUtilities {
    /**
     * Extracts the BisBaseClass from a full class name.
     * @param classFullName full class name
     * @returns BisBaseClass name
     */
    static getBisBaseClass(classFullName: string): string;
    /**
     * Determines if given class is a spatial view.
     * @param classname Name of class to check
     */
    static isSpatial(classname: string): boolean;
    /**
     * Determines if given class is a spatial view.
     * @param classname Name of class to check
     */
    static isOrthographic(classname: string): boolean;
    /**
     * Determines if given class is a drawing view.
     * @param classname Name of class to check
     */
    static isDrawing(classname: string): boolean;
    /**
     * Determines if given class is a sheet view.
     * @param classname Name of class to check
     */
    static isSheet(classname: string): boolean;
    /**
     * Determines if viewport displays a Sheet view.
     * @param viewport ScreenViewport to check
     */
    static isSheetView(viewport: ScreenViewport): boolean;
    /**
     * Determines if viewport displays a Drawing view.
     * @param viewport ScreenViewport to check
     */
    static isDrawingView(viewport: ScreenViewport): boolean;
    /**
     * Determines if viewport displays a Orthographic view.
     * @param viewport ScreenViewport to check
     */
    static isOrthographicView(viewport: ScreenViewport): boolean;
    /**
     * Determines if viewport displays a Spatial view.
     * @param viewport ScreenViewport to check
     */
    static isSpatialView(viewport: ScreenViewport): boolean;
    /**
     * Determines if viewport displays a 3d view.
     * @param viewport ScreenViewport to check
     */
    static is3dView(viewport: ScreenViewport): boolean;
    /**
     * Determines if viewport supports use of a camera.
     * @param viewport ScreenViewport to check
     */
    static viewSupportsCamera(viewport: ScreenViewport): boolean;
}
//# sourceMappingURL=ViewUtilities.d.ts.map