"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useWidgetDef = exports.WidgetContent = void 0;
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Widget
 */
const React = require("react");
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
const Frontstage_1 = require("../frontstage/Frontstage");
const UiFramework_1 = require("../UiFramework");
/** @internal */
function WidgetContent() {
    const widget = useWidgetDef();
    return (React.createElement(ui_ninezone_1.ScrollableWidgetContent, null, widget === null || widget === void 0 ? void 0 : widget.reactNode));
}
exports.WidgetContent = WidgetContent;
/** @internal */
function useWidgetDef() {
    const tabId = React.useContext(ui_ninezone_1.TabIdContext);
    const frontstage = Frontstage_1.useActiveFrontstageDef();
    const [widgetDef, setWidgetDef] = React.useState(frontstage === null || frontstage === void 0 ? void 0 : frontstage.findWidgetDef(tabId));
    React.useEffect(() => {
        setWidgetDef(frontstage === null || frontstage === void 0 ? void 0 : frontstage.findWidgetDef(tabId));
    }, [frontstage, tabId]);
    React.useEffect(() => {
        // istanbul ignore next
        const handlerActivated = () => {
            setWidgetDef(frontstage === null || frontstage === void 0 ? void 0 : frontstage.findWidgetDef(tabId));
        };
        return UiFramework_1.UiFramework.widgetManager.onWidgetProvidersChanged.addListener(handlerActivated);
    }, [frontstage, tabId]);
    React.useEffect(() => {
        // istanbul ignore next
        const handlerActivated = () => {
            setWidgetDef(frontstage === null || frontstage === void 0 ? void 0 : frontstage.findWidgetDef(tabId));
        };
        return ui_abstract_1.UiItemsManager.onUiProviderRegisteredEvent.addListener(handlerActivated);
    }, [frontstage, tabId]);
    return widgetDef;
}
exports.useWidgetDef = useWidgetDef;
//# sourceMappingURL=Content.js.map