/** @packageDocumentation
 * @module Frontstage
 */
import "./Frontstage.scss";
import * as React from "react";
import { WidgetState } from "@bentley/ui-abstract";
import { UiSettingsResult, UiSettingsStatus } from "@bentley/ui-core";
import { NineZoneDispatch, NineZoneLabels, NineZoneState, PanelSide, TabState } from "@bentley/ui-ninezone";
import { FrontstageDef } from "../frontstage/FrontstageDef";
import { StagePanelState, StagePanelZoneDefKeys } from "../stagepanels/StagePanelDef";
import { WidgetDef } from "../widgets/WidgetDef";
import { ZoneState } from "../zones/ZoneDef";
/** @internal */
export declare function useNineZoneState(frontstageDef: FrontstageDef): NineZoneState | undefined;
/** Update in-memory NineZoneState of newly activated frontstage with up to date size.
 * @internal
 */
export declare function useUpdateNineZoneSize(frontstageDef: FrontstageDef): void;
/** @internal */
export declare function useNineZoneDispatch(frontstageDef: FrontstageDef): NineZoneDispatch;
/** @internal */
export declare const WidgetPanelsFrontstage: React.NamedExoticComponent<object>;
/** @internal */
export declare function ActiveFrontstageDefProvider({ frontstageDef }: {
    frontstageDef: FrontstageDef;
}): JSX.Element;
/** @internal */
export declare function useLabels(): NineZoneLabels;
/** @internal */
export declare function addWidgets(state: NineZoneState, widgets: ReadonlyArray<WidgetDef>, side: PanelSide, widgetId: WidgetIdTypes): NineZoneState;
/** @internal */
export declare function appendWidgets(state: NineZoneState, widgetDefs: ReadonlyArray<WidgetDef>, side: PanelSide, preferredWidgetIndex: number): NineZoneState;
/** Adds frontstageDef widgets that are missing in NineZoneState.
 * @internal
 */
export declare function addMissingWidgets(frontstageDef: FrontstageDef, initialState: NineZoneState): NineZoneState;
/** Removes NineZoneState widgets that are missing in frontstageDef.
 * @internal
 */
export declare function removeMissingWidgets(frontstageDef: FrontstageDef, initialState: NineZoneState): NineZoneState;
declare type WidgetIdTypes = "leftStart" | "leftMiddle" | "leftEnd" | "rightStart" | "rightMiddle" | "rightEnd" | "topStart" | "topEnd" | "bottomStart" | "bottomEnd";
/** @internal */
export declare function getWidgetId(side: PanelSide, key: StagePanelZoneDefKeys): WidgetIdTypes;
/** @internal */
export declare function getPanelZoneWidgets(frontstageDef: FrontstageDef, panelZone: WidgetIdTypes): WidgetDef[];
/** @internal */
export declare function addPanelWidgets(state: NineZoneState, frontstageDef: FrontstageDef, side: PanelSide): NineZoneState;
/** @internal */
export declare function isFrontstageStateSettingResult(settingsResult: UiSettingsResult): settingsResult is {
    status: UiSettingsStatus.Success;
    setting: WidgetPanelsFrontstageState;
};
/** @internal */
export declare function initializePanel(nineZone: NineZoneState, frontstageDef: FrontstageDef, panelSide: PanelSide): NineZoneState;
/** @internal */
export declare function initializeNineZoneState(frontstageDef: FrontstageDef): NineZoneState;
/** Converts from saved NineZoneState to NineZoneState.
 * @note Restores toolSettings tab.
 * @note Restores tab labels.
 * @internal
 */
export declare function restoreNineZoneState(frontstageDef: FrontstageDef, saved: SavedNineZoneState): NineZoneState;
/** Prepares NineZoneState to be saved.
 * @note Removes toolSettings tab.
 * @note Removes tab labels.
 * @internal
 */
export declare function packNineZoneState(state: NineZoneState): SavedNineZoneState;
/** @internal */
export declare function isPanelCollapsed(zoneStates: ReadonlyArray<ZoneState | undefined>, panelStates: ReadonlyArray<StagePanelState | undefined>): boolean;
/** FrontstageState is saved in UiSettings.
 * @internal
 */
export interface WidgetPanelsFrontstageState {
    nineZone: SavedNineZoneState;
    id: FrontstageDef["id"];
    version: number;
    stateVersion: number;
}
declare type SavedTabState = Omit<TabState, "label" | "canPopout">;
interface SavedTabsState {
    readonly [id: string]: SavedTabState;
}
interface SavedNineZoneState extends Omit<NineZoneState, "tabs"> {
    readonly tabs: SavedTabsState;
}
/** @internal */
export declare const setWidgetState: (base: {
    readonly draggedTab: {
        readonly tabId: string;
        readonly position: {
            readonly x: number;
            readonly y: number;
        };
        readonly home: {
            readonly widgetIndex: number;
            readonly widgetId: string | undefined;
            readonly side: PanelSide;
        };
    } | undefined;
    readonly floatingWidgets: {
        readonly byId: {
            readonly [x: string]: {
                readonly bounds: {
                    readonly left: number;
                    readonly top: number;
                    readonly right: number;
                    readonly bottom: number;
                };
                readonly id: string;
                readonly home: {
                    readonly widgetIndex: number;
                    readonly widgetId: string | undefined;
                    readonly side: PanelSide;
                };
            };
        };
        readonly allIds: readonly string[];
    };
    readonly popoutWidgets: {
        readonly byId: {
            readonly [x: string]: {
                readonly bounds: {
                    readonly left: number;
                    readonly top: number;
                    readonly right: number;
                    readonly bottom: number;
                };
                readonly id: string;
                readonly home: {
                    readonly widgetIndex: number;
                    readonly widgetId: string | undefined;
                    readonly side: PanelSide;
                };
            };
        };
        readonly allIds: readonly string[];
    };
    readonly panels: {
        readonly bottom: {
            readonly span: boolean;
            readonly side: import("@bentley/ui-ninezone").HorizontalPanelSide;
            readonly collapseOffset: number;
            readonly collapsed: boolean;
            readonly maxSize: number;
            readonly minSize: number;
            readonly pinned: boolean;
            readonly resizable: boolean;
            readonly size: number | undefined;
            readonly widgets: readonly string[];
            readonly maxWidgetCount: number;
        };
        readonly left: {
            readonly side: import("@bentley/ui-ninezone").VerticalPanelSide;
            readonly collapseOffset: number;
            readonly collapsed: boolean;
            readonly maxSize: number;
            readonly minSize: number;
            readonly pinned: boolean;
            readonly resizable: boolean;
            readonly size: number | undefined;
            readonly widgets: readonly string[];
            readonly maxWidgetCount: number;
        };
        readonly right: {
            readonly side: import("@bentley/ui-ninezone").VerticalPanelSide;
            readonly collapseOffset: number;
            readonly collapsed: boolean;
            readonly maxSize: number;
            readonly minSize: number;
            readonly pinned: boolean;
            readonly resizable: boolean;
            readonly size: number | undefined;
            readonly widgets: readonly string[];
            readonly maxWidgetCount: number;
        };
        readonly top: {
            readonly span: boolean;
            readonly side: import("@bentley/ui-ninezone").HorizontalPanelSide;
            readonly collapseOffset: number;
            readonly collapsed: boolean;
            readonly maxSize: number;
            readonly minSize: number;
            readonly pinned: boolean;
            readonly resizable: boolean;
            readonly size: number | undefined;
            readonly widgets: readonly string[];
            readonly maxWidgetCount: number;
        };
    };
    readonly tabs: {
        readonly [x: string]: {
            readonly id: string;
            readonly label: string;
            readonly preferredFloatingWidgetSize?: {
                readonly width: number;
                readonly height: number;
            } | undefined;
            readonly preferredPopoutWidgetSize?: {
                readonly width: number;
                readonly height: number;
                readonly x: number;
                readonly y: number;
            } | undefined;
            readonly preferredPanelWidgetSize?: "fit-content" | undefined;
            readonly allowedPanelTargets?: readonly PanelSide[] | undefined;
            readonly canPopout?: boolean | undefined;
        };
    };
    readonly toolSettings: {
        readonly type: "docked";
    } | {
        readonly type: "widget";
    };
    readonly widgets: {
        readonly [x: string]: {
            readonly activeTabId: string;
            readonly id: string;
            readonly minimized: boolean;
            readonly tabs: readonly string[];
        };
    };
    readonly size: {
        readonly width: number;
        readonly height: number;
    };
}, widgetDef: WidgetDef, state: WidgetState) => import("immer/dist/internal").WritableDraft<NineZoneState>;
/** @internal */
export declare const showWidget: (base: {
    readonly draggedTab: {
        readonly tabId: string;
        readonly position: {
            readonly x: number;
            readonly y: number;
        };
        readonly home: {
            readonly widgetIndex: number;
            readonly widgetId: string | undefined;
            readonly side: PanelSide;
        };
    } | undefined;
    readonly floatingWidgets: {
        readonly byId: {
            readonly [x: string]: {
                readonly bounds: {
                    readonly left: number;
                    readonly top: number;
                    readonly right: number;
                    readonly bottom: number;
                };
                readonly id: string;
                readonly home: {
                    readonly widgetIndex: number;
                    readonly widgetId: string | undefined;
                    readonly side: PanelSide;
                };
            };
        };
        readonly allIds: readonly string[];
    };
    readonly popoutWidgets: {
        readonly byId: {
            readonly [x: string]: {
                readonly bounds: {
                    readonly left: number;
                    readonly top: number;
                    readonly right: number;
                    readonly bottom: number;
                };
                readonly id: string;
                readonly home: {
                    readonly widgetIndex: number;
                    readonly widgetId: string | undefined;
                    readonly side: PanelSide;
                };
            };
        };
        readonly allIds: readonly string[];
    };
    readonly panels: {
        readonly bottom: {
            readonly span: boolean;
            readonly side: import("@bentley/ui-ninezone").HorizontalPanelSide;
            readonly collapseOffset: number;
            readonly collapsed: boolean;
            readonly maxSize: number;
            readonly minSize: number;
            readonly pinned: boolean;
            readonly resizable: boolean;
            readonly size: number | undefined;
            readonly widgets: readonly string[];
            readonly maxWidgetCount: number;
        };
        readonly left: {
            readonly side: import("@bentley/ui-ninezone").VerticalPanelSide;
            readonly collapseOffset: number;
            readonly collapsed: boolean;
            readonly maxSize: number;
            readonly minSize: number;
            readonly pinned: boolean;
            readonly resizable: boolean;
            readonly size: number | undefined;
            readonly widgets: readonly string[];
            readonly maxWidgetCount: number;
        };
        readonly right: {
            readonly side: import("@bentley/ui-ninezone").VerticalPanelSide;
            readonly collapseOffset: number;
            readonly collapsed: boolean;
            readonly maxSize: number;
            readonly minSize: number;
            readonly pinned: boolean;
            readonly resizable: boolean;
            readonly size: number | undefined;
            readonly widgets: readonly string[];
            readonly maxWidgetCount: number;
        };
        readonly top: {
            readonly span: boolean;
            readonly side: import("@bentley/ui-ninezone").HorizontalPanelSide;
            readonly collapseOffset: number;
            readonly collapsed: boolean;
            readonly maxSize: number;
            readonly minSize: number;
            readonly pinned: boolean;
            readonly resizable: boolean;
            readonly size: number | undefined;
            readonly widgets: readonly string[];
            readonly maxWidgetCount: number;
        };
    };
    readonly tabs: {
        readonly [x: string]: {
            readonly id: string;
            readonly label: string;
            readonly preferredFloatingWidgetSize?: {
                readonly width: number;
                readonly height: number;
            } | undefined;
            readonly preferredPopoutWidgetSize?: {
                readonly width: number;
                readonly height: number;
                readonly x: number;
                readonly y: number;
            } | undefined;
            readonly preferredPanelWidgetSize?: "fit-content" | undefined;
            readonly allowedPanelTargets?: readonly PanelSide[] | undefined;
            readonly canPopout?: boolean | undefined;
        };
    };
    readonly toolSettings: {
        readonly type: "docked";
    } | {
        readonly type: "widget";
    };
    readonly widgets: {
        readonly [x: string]: {
            readonly activeTabId: string;
            readonly id: string;
            readonly minimized: boolean;
            readonly tabs: readonly string[];
        };
    };
    readonly size: {
        readonly width: number;
        readonly height: number;
    };
}, id: string) => import("immer/dist/internal").WritableDraft<NineZoneState>;
/** @internal */
export declare const expandWidget: (base: {
    readonly draggedTab: {
        readonly tabId: string;
        readonly position: {
            readonly x: number;
            readonly y: number;
        };
        readonly home: {
            readonly widgetIndex: number;
            readonly widgetId: string | undefined;
            readonly side: PanelSide;
        };
    } | undefined;
    readonly floatingWidgets: {
        readonly byId: {
            readonly [x: string]: {
                readonly bounds: {
                    readonly left: number;
                    readonly top: number;
                    readonly right: number;
                    readonly bottom: number;
                };
                readonly id: string;
                readonly home: {
                    readonly widgetIndex: number;
                    readonly widgetId: string | undefined;
                    readonly side: PanelSide;
                };
            };
        };
        readonly allIds: readonly string[];
    };
    readonly popoutWidgets: {
        readonly byId: {
            readonly [x: string]: {
                readonly bounds: {
                    readonly left: number;
                    readonly top: number;
                    readonly right: number;
                    readonly bottom: number;
                };
                readonly id: string;
                readonly home: {
                    readonly widgetIndex: number;
                    readonly widgetId: string | undefined;
                    readonly side: PanelSide;
                };
            };
        };
        readonly allIds: readonly string[];
    };
    readonly panels: {
        readonly bottom: {
            readonly span: boolean;
            readonly side: import("@bentley/ui-ninezone").HorizontalPanelSide;
            readonly collapseOffset: number;
            readonly collapsed: boolean;
            readonly maxSize: number;
            readonly minSize: number;
            readonly pinned: boolean;
            readonly resizable: boolean;
            readonly size: number | undefined;
            readonly widgets: readonly string[];
            readonly maxWidgetCount: number;
        };
        readonly left: {
            readonly side: import("@bentley/ui-ninezone").VerticalPanelSide;
            readonly collapseOffset: number;
            readonly collapsed: boolean;
            readonly maxSize: number;
            readonly minSize: number;
            readonly pinned: boolean;
            readonly resizable: boolean;
            readonly size: number | undefined;
            readonly widgets: readonly string[];
            readonly maxWidgetCount: number;
        };
        readonly right: {
            readonly side: import("@bentley/ui-ninezone").VerticalPanelSide;
            readonly collapseOffset: number;
            readonly collapsed: boolean;
            readonly maxSize: number;
            readonly minSize: number;
            readonly pinned: boolean;
            readonly resizable: boolean;
            readonly size: number | undefined;
            readonly widgets: readonly string[];
            readonly maxWidgetCount: number;
        };
        readonly top: {
            readonly span: boolean;
            readonly side: import("@bentley/ui-ninezone").HorizontalPanelSide;
            readonly collapseOffset: number;
            readonly collapsed: boolean;
            readonly maxSize: number;
            readonly minSize: number;
            readonly pinned: boolean;
            readonly resizable: boolean;
            readonly size: number | undefined;
            readonly widgets: readonly string[];
            readonly maxWidgetCount: number;
        };
    };
    readonly tabs: {
        readonly [x: string]: {
            readonly id: string;
            readonly label: string;
            readonly preferredFloatingWidgetSize?: {
                readonly width: number;
                readonly height: number;
            } | undefined;
            readonly preferredPopoutWidgetSize?: {
                readonly width: number;
                readonly height: number;
                readonly x: number;
                readonly y: number;
            } | undefined;
            readonly preferredPanelWidgetSize?: "fit-content" | undefined;
            readonly allowedPanelTargets?: readonly PanelSide[] | undefined;
            readonly canPopout?: boolean | undefined;
        };
    };
    readonly toolSettings: {
        readonly type: "docked";
    } | {
        readonly type: "widget";
    };
    readonly widgets: {
        readonly [x: string]: {
            readonly activeTabId: string;
            readonly id: string;
            readonly minimized: boolean;
            readonly tabs: readonly string[];
        };
    };
    readonly size: {
        readonly width: number;
        readonly height: number;
    };
}, id: string) => import("immer/dist/internal").WritableDraft<NineZoneState>;
/** @internal */
export declare const setWidgetLabel: (base: {
    readonly draggedTab: {
        readonly tabId: string;
        readonly position: {
            readonly x: number;
            readonly y: number;
        };
        readonly home: {
            readonly widgetIndex: number;
            readonly widgetId: string | undefined;
            readonly side: PanelSide;
        };
    } | undefined;
    readonly floatingWidgets: {
        readonly byId: {
            readonly [x: string]: {
                readonly bounds: {
                    readonly left: number;
                    readonly top: number;
                    readonly right: number;
                    readonly bottom: number;
                };
                readonly id: string;
                readonly home: {
                    readonly widgetIndex: number;
                    readonly widgetId: string | undefined;
                    readonly side: PanelSide;
                };
            };
        };
        readonly allIds: readonly string[];
    };
    readonly popoutWidgets: {
        readonly byId: {
            readonly [x: string]: {
                readonly bounds: {
                    readonly left: number;
                    readonly top: number;
                    readonly right: number;
                    readonly bottom: number;
                };
                readonly id: string;
                readonly home: {
                    readonly widgetIndex: number;
                    readonly widgetId: string | undefined;
                    readonly side: PanelSide;
                };
            };
        };
        readonly allIds: readonly string[];
    };
    readonly panels: {
        readonly bottom: {
            readonly span: boolean;
            readonly side: import("@bentley/ui-ninezone").HorizontalPanelSide;
            readonly collapseOffset: number;
            readonly collapsed: boolean;
            readonly maxSize: number;
            readonly minSize: number;
            readonly pinned: boolean;
            readonly resizable: boolean;
            readonly size: number | undefined;
            readonly widgets: readonly string[];
            readonly maxWidgetCount: number;
        };
        readonly left: {
            readonly side: import("@bentley/ui-ninezone").VerticalPanelSide;
            readonly collapseOffset: number;
            readonly collapsed: boolean;
            readonly maxSize: number;
            readonly minSize: number;
            readonly pinned: boolean;
            readonly resizable: boolean;
            readonly size: number | undefined;
            readonly widgets: readonly string[];
            readonly maxWidgetCount: number;
        };
        readonly right: {
            readonly side: import("@bentley/ui-ninezone").VerticalPanelSide;
            readonly collapseOffset: number;
            readonly collapsed: boolean;
            readonly maxSize: number;
            readonly minSize: number;
            readonly pinned: boolean;
            readonly resizable: boolean;
            readonly size: number | undefined;
            readonly widgets: readonly string[];
            readonly maxWidgetCount: number;
        };
        readonly top: {
            readonly span: boolean;
            readonly side: import("@bentley/ui-ninezone").HorizontalPanelSide;
            readonly collapseOffset: number;
            readonly collapsed: boolean;
            readonly maxSize: number;
            readonly minSize: number;
            readonly pinned: boolean;
            readonly resizable: boolean;
            readonly size: number | undefined;
            readonly widgets: readonly string[];
            readonly maxWidgetCount: number;
        };
    };
    readonly tabs: {
        readonly [x: string]: {
            readonly id: string;
            readonly label: string;
            readonly preferredFloatingWidgetSize?: {
                readonly width: number;
                readonly height: number;
            } | undefined;
            readonly preferredPopoutWidgetSize?: {
                readonly width: number;
                readonly height: number;
                readonly x: number;
                readonly y: number;
            } | undefined;
            readonly preferredPanelWidgetSize?: "fit-content" | undefined;
            readonly allowedPanelTargets?: readonly PanelSide[] | undefined;
            readonly canPopout?: boolean | undefined;
        };
    };
    readonly toolSettings: {
        readonly type: "docked";
    } | {
        readonly type: "widget";
    };
    readonly widgets: {
        readonly [x: string]: {
            readonly activeTabId: string;
            readonly id: string;
            readonly minimized: boolean;
            readonly tabs: readonly string[];
        };
    };
    readonly size: {
        readonly width: number;
        readonly height: number;
    };
}, id: string, label: string) => import("immer/dist/internal").WritableDraft<NineZoneState>;
/** @internal */
export declare function useSavedFrontstageState(frontstageDef: FrontstageDef): void;
/** @internal */
export declare function useSaveFrontstageSettings(frontstageDef: FrontstageDef): void;
/** @internal */
export declare const FRONTSTAGE_SETTINGS_NAMESPACE = "uifw-frontstageSettings";
/** @internal */
export declare function getFrontstageStateSettingName(frontstageId: WidgetPanelsFrontstageState["id"]): string;
/** @internal */
export declare function useFrontstageManager(frontstageDef: FrontstageDef): void;
/** @internal */
export declare function useItemsManager(frontstageDef: FrontstageDef): void;
/** @internal */
export declare function useSyncDefinitions(frontstageDef: FrontstageDef): void;
/** @internal */
export declare function saveFrontstagePopoutWidgetSizeAndPosition(state: NineZoneState, stageId: string, stageVersion: number, childWindowId: string, childWindow: Window): Promise<NineZoneState>;
export {};
//# sourceMappingURL=Frontstage.d.ts.map