"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModalFrontstageComposer = exports.useActiveModalFrontstageInfo = void 0;
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Frontstage
 */
const React = require("react");
const FrontstageManager_1 = require("../frontstage/FrontstageManager");
const ModalFrontstage_1 = require("../frontstage/ModalFrontstage");
/** @internal */
function useActiveModalFrontstageInfo() {
    const [activeModalFrontstageInfo, setActiveModalFrontstageInfo] = React.useState(FrontstageManager_1.FrontstageManager.activeModalFrontstage);
    React.useEffect(() => {
        const handleModalFrontstageChangedEvent = (args) => {
            setActiveModalFrontstageInfo(args.modalFrontstageCount === 0 ? undefined : FrontstageManager_1.FrontstageManager.activeModalFrontstage);
        };
        FrontstageManager_1.FrontstageManager.onModalFrontstageChangedEvent.addListener(handleModalFrontstageChangedEvent);
        return () => {
            FrontstageManager_1.FrontstageManager.onModalFrontstageChangedEvent.removeListener(handleModalFrontstageChangedEvent);
        };
    }, [setActiveModalFrontstageInfo]);
    return activeModalFrontstageInfo;
}
exports.useActiveModalFrontstageInfo = useActiveModalFrontstageInfo;
/** @internal */
function ModalFrontstageComposer({ stageInfo }) {
    const handleCloseModal = React.useCallback(/* istanbul ignore next */ () => FrontstageManager_1.FrontstageManager.closeModalFrontstage(), []);
    // istanbul ignore next
    if (!stageInfo)
        return null;
    const { title, content, appBarRight } = stageInfo;
    return React.createElement(ModalFrontstage_1.ModalFrontstage, { isOpen: true, title: title, closeModal: handleCloseModal, appBarRight: appBarRight }, content);
}
exports.ModalFrontstageComposer = ModalFrontstageComposer;
//# sourceMappingURL=ModalFrontstageComposer.js.map