"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Widget
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getBadgeClassName = exports.WidgetPanelsTab = void 0;
require("./Tab.scss");
const React = require("react");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
const Content_1 = require("./Content");
const ui_core_1 = require("@bentley/ui-core");
const ui_abstract_1 = require("@bentley/ui-abstract");
/** @internal */
function WidgetPanelsTab() {
    const widgetDef = Content_1.useWidgetDef();
    const badgeType = widgetDef === null || widgetDef === void 0 ? void 0 : widgetDef.badgeType;
    const badgeClassName = getBadgeClassName(badgeType);
    const badge = React.useMemo(() => ui_core_1.BadgeUtilities.getComponentForBadgeType(badgeType), [badgeType]);
    return (React.createElement(ui_ninezone_1.WidgetTab, { className: badgeClassName, badge: badge }));
}
exports.WidgetPanelsTab = WidgetPanelsTab;
/** @internal */
function getBadgeClassName(badgeType) {
    if (badgeType === ui_abstract_1.BadgeType.New)
        return "uifw-badge-new";
    else if (badgeType === ui_abstract_1.BadgeType.TechnicalPreview)
        return "uifw-badge-tp";
    return undefined;
}
exports.getBadgeClassName = getBadgeClassName;
//# sourceMappingURL=Tab.js.map