"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Widget
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.useWidgetDirection = void 0;
const React = require("react");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
const useFrameworkVersion_1 = require("../hooks/useFrameworkVersion");
/** Returns widget direction.
 * I.e. "horizontal" when widget is in bottom/top stage panel.
 * @alpha
 */
function useWidgetDirection() {
    const version = useFrameworkVersion_1.useFrameworkVersion();
    const tabId = React.useContext(ui_ninezone_1.TabIdContext);
    const nineZone = React.useContext(ui_ninezone_1.NineZoneContext);
    if (version === "2") {
        const tabLocation = ui_ninezone_1.findTab(nineZone, tabId);
        if (tabLocation && ("side" in tabLocation) && ui_ninezone_1.isHorizontalPanelSide(tabLocation.side)) {
            return "horizontal";
        }
    }
    return "vertical";
}
exports.useWidgetDirection = useWidgetDirection;
//# sourceMappingURL=useWidgetDirection.js.map