"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Widget
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ToolSettingsContentContext = exports.ToolSettingsContent = void 0;
require("./ToolSettingsContent.scss");
const classnames = require("classnames");
const React = require("react");
const ui_core_1 = require("@bentley/ui-core");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
/**  @internal */
class ToolSettingsContent extends React.PureComponent {
    constructor() {
        super(...arguments);
        this._container = React.createRef();
        this._measurer = React.createRef();
        this.state = {
            availableContentWidth: 0,
        };
        this._handleResize = () => {
            const container = this._container.current;
            const measurer = this._measurer.current;
            // istanbul ignore next
            if (!container || !measurer)
                return;
            container.classList.add("uifw-measure");
            const measurerBounds = measurer.getBoundingClientRect();
            container.classList.remove("uifw-measure");
            this.setState({ availableContentWidth: measurerBounds.width });
        };
    }
    render() {
        const className = classnames("uifw-tool-settings-content", this.props.mode === ui_ninezone_1.ToolSettingsWidgetMode.TitleBar && "uifw-title-bar", this.props.mode === ui_ninezone_1.ToolSettingsWidgetMode.Tab && "uifw-tab");
        return (React.createElement(ui_ninezone_1.WidgetContent, { anchor: this.props.anchor, className: className, containerRef: this._container, content: React.createElement(exports.ToolSettingsContentContext.Provider, { value: {
                    availableContentWidth: this.state.availableContentWidth,
                } },
                this.props.children,
                React.createElement("div", { className: "uifw-zone-measurer" },
                    React.createElement(ui_core_1.ResizableContainerObserver, { onResize: this._handleResize })),
                React.createElement("div", { className: "uifw-measurer", ref: this._measurer }),
                React.createElement("div", { className: "uifw-expander" })) }));
    }
}
exports.ToolSettingsContent = ToolSettingsContent;
/** @internal */
exports.ToolSettingsContentContext = React.createContext({
    availableContentWidth: 0,
});
//# sourceMappingURL=ToolSettingsContent.js.map