"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Widget
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ToolWidget = exports.ToolWidgetDef = void 0;
const React = require("react");
const ui_core_1 = require("@bentley/ui-core");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
const FrontstageManager_1 = require("../frontstage/FrontstageManager");
const UiShowHideManager_1 = require("../utils/UiShowHideManager");
const ToolbarWidgetBase_1 = require("./ToolbarWidgetBase");
const WidgetDef_1 = require("./WidgetDef");
const UiFramework_1 = require("../UiFramework");
/** Definition of a Tool Widget normally displayed in the top left zone in the 9-Zone Layout system.
 *  @public @deprecated use ToolWidgetComposer instead
 */
class ToolWidgetDef extends ToolbarWidgetBase_1.ToolbarWidgetDefBase {
    constructor(props) {
        super(props);
        this._backstageLabel = UiFramework_1.UiFramework.translate("buttons.openBackstageMenu");
        this._appButton = props.appButton;
        this.widgetType = WidgetDef_1.WidgetType.Tool;
        this.verticalDirection = (props.verticalDirection !== undefined) ? props.verticalDirection : ui_ninezone_1.Direction.Right;
        const activeStageName = FrontstageManager_1.FrontstageManager.activeFrontstageDef ? FrontstageManager_1.FrontstageManager.activeFrontstageDef.id : /* istanbul ignore next */ "";
        this.widgetBaseName = `[${activeStageName}]ToolWidget`;
    }
    get reactNode() {
        // istanbul ignore else
        if (!this._reactNode)
            this._reactNode = React.createElement(ToolWidgetWithDef, { toolWidgetDef: this });
        return this._reactNode;
    }
    /** @deprecated use reactNode */
    // istanbul ignore next
    get reactElement() {
        return this.reactNode;
    }
    renderCornerItem() {
        if (this._appButton) {
            return (React.createElement(ui_ninezone_1.AppButton, { onClick: this._appButton.execute, icon: React.createElement(ui_core_1.Icon, { iconSpec: this._appButton.iconSpec }), title: this._appButton.tooltip || this._backstageLabel }));
        }
        return undefined;
    }
}
exports.ToolWidgetDef = ToolWidgetDef;
/** ToolWidget React component.
 *  @public @deprecated use ToolWidgetComposer instead
 */
class ToolWidget extends React.Component {
    constructor(props) {
        super(props);
        this.state = { toolWidgetDef: new ToolWidgetDef(props) }; // eslint-disable-line deprecation/deprecation
    }
    componentDidUpdate(prevProps, _prevState) {
        if (this.props !== prevProps) {
            this.setState((_, props) => ({ toolWidgetDef: new ToolWidgetDef(props) })); // eslint-disable-line deprecation/deprecation
        }
    }
    render() {
        return (React.createElement(ToolWidgetWithDef, { className: this.props.className, style: this.props.style, toolWidgetDef: this.state.toolWidgetDef, button: this.props.button, horizontalToolbar: this.props.horizontalToolbar, verticalToolbar: this.props.verticalToolbar }));
    }
}
exports.ToolWidget = ToolWidget;
/** Tool Widget React component.
 */
class ToolWidgetWithDef extends React.Component {
    constructor(props) {
        super(props);
        const horizontalToolbar = (this.props.horizontalToolbar) ? this.props.horizontalToolbar : this.props.toolWidgetDef.renderHorizontalToolbar();
        const verticalToolbar = (this.props.verticalToolbar) ? this.props.verticalToolbar : this.props.toolWidgetDef.renderVerticalToolbar();
        const cornerItem = (this.props.button !== undefined) ? this.props.button : this.props.toolWidgetDef.renderCornerItem();
        this.state = { horizontalToolbar, verticalToolbar, cornerItem };
    }
    reloadToolbars() {
        const horizontalToolbar = (this.props.horizontalToolbar) ? this.props.horizontalToolbar : /* istanbul ignore next */ this.props.toolWidgetDef.renderHorizontalToolbar();
        const verticalToolbar = (this.props.verticalToolbar) ? /* istanbul ignore next */ this.props.verticalToolbar : this.props.toolWidgetDef.renderVerticalToolbar();
        this.setState({ horizontalToolbar, verticalToolbar });
    }
    componentDidUpdate(prevProps) {
        if (this.props !== prevProps)
            this.reloadToolbars();
    }
    render() {
        return (React.createElement(ui_ninezone_1.Tools, { className: this.props.className, style: this.props.style, button: this.state.cornerItem, horizontalToolbar: this.state.horizontalToolbar, verticalToolbar: this.state.verticalToolbar, preserveSpace: true, onMouseEnter: UiShowHideManager_1.UiShowHideManager.handleWidgetMouseEnter }));
    }
}
//# sourceMappingURL=ToolWidget.js.map