"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Widget
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ToolWidgetComposer = exports.BackstageAppButton = void 0;
const React = require("react");
const home_svg_sprite_1 = require("@bentley/icons-generic/icons/home.svg?sprite");
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const ui_ninezone_1 = require("@bentley/ui-ninezone");
const BackstageManager_1 = require("../backstage/BackstageManager");
const useFrameworkVersion_1 = require("../hooks/useFrameworkVersion");
const UiFramework_1 = require("../UiFramework");
const UiShowHideManager_1 = require("../utils/UiShowHideManager");
/**
 * BackstageAppButton used to toggle display of Backstage.
 * @public
 */
function BackstageAppButton(props) {
    const backstageLabel = React.useRef(UiFramework_1.UiFramework.translate("buttons.openBackstageMenu"));
    const backstageToggleCommand = BackstageManager_1.BackstageManager.getBackstageToggleCommand(props.icon);
    const [icon, setIcon] = React.useState(props.icon ? props.icon : ui_abstract_1.IconSpecUtilities.createSvgIconSpec(home_svg_sprite_1.default));
    const isInitialMount = React.useRef(true);
    const useSmallAppButton = "1" !== useFrameworkVersion_1.useFrameworkVersion();
    const divClassName = useSmallAppButton ? "uifw-app-button-small" : undefined;
    const { onElementRef, proximityScale } = ui_core_1.useWidgetOpacityContext();
    const ref = React.useRef(null);
    React.useEffect(() => {
        if (isInitialMount.current) {
            isInitialMount.current = false;
            onElementRef(ref);
        }
        else {
            setIcon(props.icon ? props.icon : ui_abstract_1.IconSpecUtilities.createSvgIconSpec(home_svg_sprite_1.default));
        }
    }, [props.icon, onElementRef]);
    let buttonProximityScale;
    if ("1" !== useFrameworkVersion_1.useFrameworkVersion() && UiShowHideManager_1.UiShowHideManager.useProximityOpacity && !UiFramework_1.UiFramework.isMobile()) {
        buttonProximityScale = proximityScale;
    }
    return (React.createElement("div", { ref: ref, className: divClassName },
        React.createElement(ui_ninezone_1.AppButton, { small: useSmallAppButton, mouseProximity: buttonProximityScale, onClick: backstageToggleCommand.execute, icon: React.createElement(ui_core_1.Icon, { iconSpec: icon }), title: backstageToggleCommand.tooltip || backstageLabel.current })));
}
exports.BackstageAppButton = BackstageAppButton;
/**
 * ToolWidget component that supports use of ToolbarComposer-based Toolbars. The ToolWidget is shown in the top left of the content area
 * and typically holds tools to manipulate or interrogate content. The horizontal toolbar often includes context specific tools based on
 * selected items. The vertical toolbar typically contains a more fixed list of tools.
 * @public
 */
function ToolWidgetComposer(props) {
    const { cornerItem, horizontalToolbar, verticalToolbar } = props, otherProps = __rest(props, ["cornerItem", "horizontalToolbar", "verticalToolbar"]);
    const [elementSet] = React.useState(new ui_core_1.WidgetElementSet());
    const handleChildRef = React.useCallback((elementRef) => {
        elementSet.add(elementRef);
    }, [elementSet]);
    const proximityScale = ui_core_1.useProximityToMouse(elementSet, UiShowHideManager_1.UiShowHideManager.snapWidgetOpacity);
    return (React.createElement(ui_core_1.WidgetOpacityContext.Provider, { value: {
            onElementRef: handleChildRef,
            proximityScale,
        } },
        React.createElement(ui_ninezone_1.ToolsArea, Object.assign({ button: cornerItem, horizontalToolbar: horizontalToolbar, verticalToolbar: verticalToolbar }, otherProps, { onMouseEnter: UiShowHideManager_1.UiShowHideManager.handleWidgetMouseEnter }))));
}
exports.ToolWidgetComposer = ToolWidgetComposer;
//# sourceMappingURL=ToolWidgetComposer.js.map