/** @packageDocumentation
 * @module WorkflowTask
 */
import { ItemDefBase } from "../shared/ItemDefBase";
import { ItemProps } from "../shared/ItemProps";
/** Properties for a [[Task]]
 * @public
 */
export interface TaskProps extends ItemProps {
    id: string;
    primaryStageId: string;
}
/** List of Task Properties
 * @public
 */
export interface TaskPropsList {
    tasks: TaskProps[];
}
/** Task class.
 * A Task is a specific piece of work to accomplish.
 * A Task refers to a Frontstage to activate.
 * @public
 */
export declare class Task extends ItemDefBase {
    taskId: string;
    primaryStageId: string;
    constructor(taskProps: TaskProps);
    get id(): string;
    get isActive(): boolean;
    set isActive(_: boolean);
    onActivated(): Promise<void>;
}
/** Task Manager class.
 * @public
 */
export declare class TaskManager {
    private static _tasks;
    static loadTasks(taskListDef: TaskPropsList): void;
    static loadTaskDefs(taskDefs: TaskProps[]): void;
    static loadTaskDef(taskDef: TaskProps): void;
    static findTask(taskId: string): Task | undefined;
    static addTask(taskId: string, task: Task): void;
}
//# sourceMappingURL=Task.d.ts.map