"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module WorkflowTask
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TaskManager = exports.Task = void 0;
const FrontstageManager_1 = require("../frontstage/FrontstageManager");
const ItemDefBase_1 = require("../shared/ItemDefBase");
const Workflow_1 = require("./Workflow");
/** Task class.
 * A Task is a specific piece of work to accomplish.
 * A Task refers to a Frontstage to activate.
 * @public
 */
class Task extends ItemDefBase_1.ItemDefBase {
    constructor(taskProps) {
        super(taskProps);
        this.taskId = taskProps.id;
        this.primaryStageId = taskProps.primaryStageId;
    }
    get id() {
        return this.taskId;
    }
    get isActive() {
        let isActive = false;
        if (Workflow_1.WorkflowManager.activeWorkflow && Workflow_1.WorkflowManager.activeWorkflow.activeTask === this)
            isActive = true;
        return isActive;
    }
    set isActive(_) {
        // do nothing - needed because subclassing from ItemDefBase
    }
    async onActivated() {
        const frontstage = FrontstageManager_1.FrontstageManager.findFrontstageDef(this.primaryStageId);
        if (frontstage)
            await FrontstageManager_1.FrontstageManager.setActiveFrontstageDef(frontstage);
    }
}
exports.Task = Task;
// -----------------------------------------------------------------------------
/** Task Manager class.
 * @public
 */
class TaskManager {
    static loadTasks(taskListDef) {
        this.loadTaskDefs(taskListDef.tasks);
    }
    static loadTaskDefs(taskDefs) {
        taskDefs.map((taskDef, _index) => {
            this.loadTaskDef(taskDef);
        });
    }
    static loadTaskDef(taskDef) {
        const task = new Task(taskDef);
        this.addTask(taskDef.id, task);
    }
    static findTask(taskId) {
        return this._tasks.get(taskId);
    }
    static addTask(taskId, task) {
        this._tasks.set(taskId, task);
    }
}
exports.TaskManager = TaskManager;
TaskManager._tasks = new Map();
//# sourceMappingURL=Task.js.map