/** @packageDocumentation
 * @module Zone
 */
import { WidgetHost } from "../widgets/WidgetHost";
import { ZoneLocation, ZoneProps } from "./Zone";
/** Zone State enum.
 * @public
 */
export declare enum ZoneState {
    Off = 0,
    Minimized = 1,
    Open = 2,
    Popup = 3,
    Floating = 4
}
/**
 * A ZoneDef represents each zone within a Frontstage.
 * @public
 */
export declare class ZoneDef extends WidgetHost {
    private _initialWidth;
    private _zoneState;
    private _allowsMerging;
    private _applicationData?;
    private _mergeWithZone?;
    private _zoneLocation;
    /** Zone state.  Defaults to ZoneState.Open. */
    get zoneState(): ZoneState;
    /** Indicates if other Zones may be merged with this Zone. Defaults to false.  */
    get allowsMerging(): boolean;
    /** Any application data to attach to this Zone. */
    get applicationData(): any | undefined;
    /** Indicates with which other zone to merge. */
    get mergeWithZone(): ZoneLocation | undefined;
    /** The Zone's location.
     * @internal
     */
    get zoneLocation(): ZoneLocation;
    set zoneLocation(zoneLocation: ZoneLocation);
    /** Initial zone width. */
    get initialWidth(): number | undefined;
    /** Constructor for ZoneDef.
     */
    constructor();
    /** Determines if this Zone is for Tool Settings. */
    get isToolSettings(): boolean;
    /** Determines if this Zone is for the Status Bar. */
    get isStatusBar(): boolean;
    /** Determines if the Zone should fill the available space. */
    get shouldFillZone(): boolean;
    /** @internal */
    setInitialWidth(width: number | undefined): void;
    /** @internal */
    initializeFromProps(props: ZoneProps): void;
}
//# sourceMappingURL=ZoneDef.d.ts.map