"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Item
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ToolInformation = void 0;
const ui_abstract_1 = require("@bentley/ui-abstract");
const ConfigurableUiControl_1 = require("../../configurableui/ConfigurableUiControl");
const ConfigurableUiManager_1 = require("../../configurableui/ConfigurableUiManager");
const UiFramework_1 = require("../../UiFramework");
const ToolSettingsManager_1 = require("./ToolSettingsManager");
/** Provides information about a tool with a given id, including the ToolUiProvider.
 * @public
 */
class ToolInformation {
    constructor(toolId) {
        this.toolId = toolId;
    }
    /** Get the ToolUiProvider registered for this tool */
    get toolUiProvider() {
        if (!this._toolUiProvider) {
            let provider;
            if (ConfigurableUiManager_1.ConfigurableUiManager.isControlRegistered(this.toolId)) {
                provider = ConfigurableUiManager_1.ConfigurableUiManager.createControl(this.toolId, this.toolId);
            }
            else {
                if (ToolSettingsManager_1.ToolSettingsManager.useDefaultToolSettingsProvider && this.toolId === ToolSettingsManager_1.ToolSettingsManager.toolIdForToolSettings)
                    provider = ConfigurableUiManager_1.ConfigurableUiManager.createControl("DefaultToolSettings", this.toolId);
            }
            // istanbul ignore else
            if (provider) {
                if (provider.getType() !== ConfigurableUiControl_1.ConfigurableUiControlType.ToolUiProvider) {
                    throw new ui_abstract_1.UiError(UiFramework_1.UiFramework.loggerCategory(this), `toolUiProvider: toolId '${this.toolId}' is registered to a control that is NOT a ToolUiProvider`);
                }
                this._toolUiProvider = provider;
            }
        }
        return this._toolUiProvider;
    }
}
exports.ToolInformation = ToolInformation;
//# sourceMappingURL=ToolInformation.js.map